# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
#
# Description
# ==============================================================================
#
#   Constants to compute the Y position of the CIP w.r.t. the GCRS.
#
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
#
# Obtained from the file:
#
#   ftp://tai.bipm.org/iers/conv2010/chapter5/tab5.2b.txt
#
# accessed on 16 Feb 2019.
#
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #

const coefs_iau2006_CIP_y0 = Float64[
    1        1538.18     9205236.26    0    0    0    0    1    0    0    0    0    0    0    0    0    0
    2        -458.66      573033.42    0    0    2   -2    2    0    0    0    0    0    0    0    0    0
    3         137.41       97846.69    0    0    2    0    2    0    0    0    0    0    0    0    0    0
    4         -29.05      -89618.24    0    0    0    0    2    0    0    0    0    0    0    0    0    0
    5         -17.40       22438.42    0    1    2   -2    2    0    0    0    0    0    0    0    0    0
    6          31.80       20069.50    0    0    2    0    1    0    0    0    0    0    0    0    0    0
    7          36.70       12902.66    1    0    2    0    2    0    0    0    0    0    0    0    0    0
    8         -13.20       -9592.72    0    1   -2    2   -2    0    0    0    0    0    0    0    0    0
    9        -192.40        7387.02    0    1    0    0    0    0    0    0    0    0    0    0    0    0
   10           3.92       -6918.22    0    0    2   -2    1    0    0    0    0    0    0    0    0    0
   11           0.40       -5331.13    1    0   -2    0   -2    0    0    0    0    0    0    0    0    0
   12          -0.90       -3323.89    1    0    0    0    1    0    0    0    0    0    0    0    0    0
   13           7.50        3143.98    1    0    0    0   -1    0    0    0    0    0    0    0    0    0
   14           7.80        2636.13    1    0    2    0    1    0    0    0    0    0    0    0    0    0
   15          -6.60        2554.51    1    0   -2   -2   -2    0    0    0    0    0    0    0    0    0
   16          -2.00       -2423.59    2    0   -2    0   -1    0    0    0    0    0    0    0    0    0
   17           6.80        1645.01    0    0    2    2    2    0    0    0    0    0    0    0    0    0
   18           0.00       -1387.00    0    2   -2    2   -2    0    0    0    0    0    0    0    0    0
   19           5.90        1323.81    2    0    2    0    2    0    0    0    0    0    0    0    0    0
   20          -0.30       -1233.89    1    0    2   -2    2    0    0    0    0    0    0    0    0    0
   21           0.30       -1075.60    1    0   -2    0   -1    0    0    0    0    0    0    0    0    0
   22          -4.48         852.85    0    1    0    0    1    0    0    0    0    0    0    0    0    0
   23           0.10        -800.34    1    0    0   -2   -1    0    0    0    0    0    0    0    0    0
   24          35.80        -674.99    1    0    0    0    0    0    0    0    0    0    0    0    0    0
   25          -1.40         695.54    1    0    0   -2    1    0    0    0    0    0    0    0    0    0
   26          -0.50         684.99    0    2    2   -2    2    0    0    0    0    0    0    0    0    0
   27          -2.62         643.75    0    1    0    0   -1    0    0    0    0    0    0    0    0    0
   28          -1.50         522.11    1    0   -2   -2   -1    0    0    0    0    0    0    0    0    0
   29         273.50         164.70    0    0    1   -1    1    0    0   -1    0   -2    5    0    0    0
   30           1.40         335.24    0    0    2    2    1    0    0    0    0    0    0    0    0    0
   31           1.90         326.60    1    0    2    2    2    0    0    0    0    0    0    0    0    0
   32           0.40         327.11    0    0    0    2    1    0    0    0    0    0    0    0    0    0
   33          -0.50        -325.03    0    1    2    0    2    0    0    0    0    0    0    0    0    0
   34          -0.40         307.03    0    1   -2    0   -2    0    0    0    0    0    0    0    0    0
   35           0.50         304.17    2    0    0   -2   -1    0    0    0    0    0    0    0    0    0
   36          -0.10        -304.46    1    0    2   -2    1    0    0    0    0    0    0    0    0    0
   37          -0.40        -276.81    2    0    2   -2    2    0    0    0    0    0    0    0    0    0
   38           0.90         272.05    0    0    0    2   -1    0    0    0    0    0    0    0    0    0
   39           0.30         272.22    0    1   -2    2   -1    0    0    0    0    0    0    0    0    0
   40           1.20         269.45    2    0    2    0    1    0    0    0    0    0    0    0    0    0
   41           0.10        -220.67    2    0    0   -2    1    0    0    0    0    0    0    0    0    0
   42         128.60         -77.10    0    0    0    0    0    0    0    0    0    2   -5    0    0   -1
   43           0.10        -190.79    0    1    2   -2    1    0    0    0    0    0    0    0    0    0
   44         167.90           0.00    0    1   -1    1   -1    0    0    0    0    0    0    0    0    0
   45          -8.20        -123.48    1    0    0   -2    0    0    0    0    0    0    0    0    0    0
   46           0.10         131.04    2    0   -2    0   -2    0    0    0    0    0    0    0    0    0
   47           0.40         126.64    2    0    0    0   -1    0    0    0    0    0    0    0    0    0
   48           2.90        -122.28    0    0    0    2    0    0    0    0    0    0    0    0    0    0
   49           0.70         123.20    3    0    2    0    2    0    0    0    0    0    0    0    0    0
   50           0.40         123.20    1   -1    2    0    2    0    0    0    0    0    0    0    0    0
   51          -0.30         120.70    1    1   -2   -2   -2    0    0    0    0    0    0    0    0    0
   52          -0.50         112.90    0    1   -2   -2   -2    0    0    0    0    0    0    0    0    0
   53          -0.20        -112.94    2    0    0    0    1    0    0    0    0    0    0    0    0    0
   54           0.20         107.31    1    0   -2    2   -1    0    0    0    0    0    0    0    0    0
   55          -0.30        -106.20    1    1    2    0    2    0    0    0    0    0    0    0    0    0
   56          31.90         -64.10    0    0    1   -1    1    0   -8   12    0    0    0    0    0    0
   57           0.00          89.50    0    0    0    0    0    0    3   -5    0    0    0    0    0   -2
   58          89.10           0.00    1    0   -1    0   -1    0    0    0    0    0    0    0    0    0
   59           0.00          85.32    1    0    0    0    2    0    0    0    0    0    0    0    0    0
   60          -0.20         -71.00    0    0    2    1    2    0    0    0    0    0    0    0    0    0
   61           0.00         -70.01    1   -1    0   -1   -1    0    0    0    0    0    0    0    0    0
   62          13.90         -55.30    1    0    0   -1    0    0    0    0    0    0    0    0    0    0
   63           0.00          67.25    0    2   -2    2   -1    0    0    0    0    0    0    0    0    0
   64           0.40          66.29    1    0    2    2    1    0    0    0    0    0    0    0    0    0
   65          -0.40          64.70    1    0   -2   -4   -2    0    0    0    0    0    0    0    0    0
   66           1.30         -60.90    2    0    0    0    0    0    0    0    0    0    0    0    0    0
   67          -0.20         -60.92    1    0    0    0   -2    0    0    0    0    0    0    0    0    0
   68           0.20         -59.20    2    0   -2   -2   -2    0    0    0    0    0    0    0    0    0
   69           1.10         -55.55    0    0    2    0    0    0    0    0    0    0    0    0    0    0
   70           0.00         -55.60    1    1    2   -2    2    0    0    0    0    0    0    0    0    0
   71          -0.10         -52.69    2    0    2   -2    1    0    0    0    0    0    0    0    0    0
   72          -0.20          51.80    2    0   -2   -4   -2    0    0    0    0    0    0    0    0    0
   73           1.00         -49.51    1    0    0   -1   -1    0    0    0    0    0    0    0    0    0
   74           0.00          50.50    0    0    0    0    0    0    0    0    0    2    0    0    0    2
   75           2.50          47.70    2    0    0   -2    0    0    0    0    0    0    0    0    0    0
   76           0.10          49.59    1    0    0    2    1    0    0    0    0    0    0    0    0    0
   77           0.10         -49.00    1    0   -4    0   -2    0    0    0    0    0    0    0    0    0
   78         -23.20          24.60    0    0    0    0    1    0    0   -1    2    0    0    0    0    0
   79           0.40          46.50    2    0    2    2    2    0    0    0    0    0    0    0    0    0
   80          -0.10         -44.04    0    0    2   -2   -1    0    0    0    0    0    0    0    0    0
   81          -0.10         -42.19    0    1    2    0    1    0    0    0    0    0    0    0    0    0
   82          13.30          26.90    0    0    0    0    0    0    8  -13    0    0    0    0    0   -1
   83          -0.10         -39.90    3    0    2   -2    2    0    0    0    0    0    0    0    0    0
   84          -0.10         -39.50    0    0    4   -2    2    0    0    0    0    0    0    0    0    0
   85           0.00         -39.11    1    1    0   -2   -1    0    0    0    0    0    0    0    0    0
   86          -0.10         -38.92    2    0   -2    0    1    0    0    0    0    0    0    0    0    0
   87           0.10          36.95    0    0    2    0   -1    0    0    0    0    0    0    0    0    0
   88          -0.10          34.59    0    1   -2    0   -1    0    0    0    0    0    0    0    0    0
   89           0.20         -32.55    0    1    0    0    2    0    0    0    0    0    0    0    0    0
   90          -0.10          31.61    1    1    0   -2    1    0    0    0    0    0    0    0    0    0
   91           0.00          30.40    0    0    2   -1    2    0    0    0    0    0    0    0    0    0
   92           0.20          29.40    0    0    2    4    2    0    0    0    0    0    0    0    0    0
   93           0.00         -27.91    1   -1    0    0    1    0    0    0    0    0    0    0    0    0
   94           0.10          27.50    1    0    0    2   -1    0    0    0    0    0    0    0    0    0
   95         -25.70          -1.70    0    0    1   -1    1    0    0   -1    0    2   -5    0    0    0
   96          19.90           5.90    0    0    0    0    0    0    0    2   -8    3    0    0    0   -2
   97           0.00          25.80    1   -1    0   -1   -2    0    0    0    0    0    0    0    0    0
   98           0.20          25.20    1   -1    2    2    2    0    0    0    0    0    0    0    0    0
   99           0.00         -25.31    0    1    0    0   -2    0    0    0    0    0    0    0    0    0
  100           0.20          25.00    3    0    2    0    1    0    0    0    0    0    0    0    0    0
  101          -0.10          24.40    1    0    2   -4    1    0    0    0    0    0    0    0    0    0
  102           0.10         -24.40    1   -1   -2   -2   -2    0    0    0    0    0    0    0    0    0
  103         -23.30           0.90    0    0    2   -2    1    0   -5    6    0    0    0    0    0    0
  104          -0.10          24.00    1    1   -2   -2   -1    0    0    0    0    0    0    0    0    0
  105         -18.00          -5.30    0    0    0    0    0    0    0    6   -8    3    0    0    0    2
  106          -0.10         -22.80    0    1    2    2    2    0    0    0    0    0    0    0    0    0
  107          -0.10          22.50    0    1   -2   -2   -1    0    0    0    0    0    0    0    0    0
  108           0.10          21.60    1   -1    2    0    1    0    0    0    0    0    0    0    0    0
  109           0.00         -21.30    0    0    0    0    0    0    4   -6    0    0    0    0    0   -2
  110           0.10          20.70    2   -1    2    0    2    0    0    0    0    0    0    0    0    0
  111           0.70         -20.10    0    0    0    0    0    0    0    3    0   -1    0    0    0    2
  112           0.00          20.51    0    0    0    1    1    0    0    0    0    0    0    0    0    0
  113          15.90          -4.50    0    0    0    0    1    0    0   -4    8   -3    0    0    0    0
  114           0.20         -19.94    1    0    0    2    0    0    0    0    0    0    0    0    0    0
  115           0.00          20.11    0    0    0    2    2    0    0    0    0    0    0    0    0    0
  116          15.60           4.40    0    0    0    0    1    0    0    4   -8    3    0    0    0    0
  117           0.00         -20.00    1   -1   -2    0   -2    0    0    0    0    0    0    0    0    0
  118           0.00          19.80    0    0    0    0    0    0    2   -4    0    0    0    0    0   -2
  119           0.00          18.91    1    1    0    0    1    0    0    0    0    0    0    0    0    0
  120           4.30         -14.60    0    0    1   -1    1    0    0    0   -2    0    0    0    0    0
  121          -0.10         -18.50    1    1    2    0    1    0    0    0    0    0    0    0    0    0
  122          -0.10          18.40    0    1    0   -2    1    0    0    0    0    0    0    0    0    0
  123           0.00          18.10    0    3    2   -2    2    0    0    0    0    0    0    0    0    0
  124           1.00          16.81    0    2    0    0    0    0    0    0    0    0    0    0    0    0
  125          -0.10         -17.60    2    1    2    0    2    0    0    0    0    0    0    0    0    0
  126         -17.60           0.00    1    0   -1    0   -2    0    0    0    0    0    0    0    0    0
  127          -1.30         -16.26    0    0    2   -2    0    0    0    0    0    0    0    0    0    0
  128           0.00         -17.41    0    0    0    1   -1    0    0    0    0    0    0    0    0    0
  129          14.50          -2.70    0    0    0    0    0    0    0    0    0    2    0    0    0    1
  130           0.00          17.08    1    0    0   -2   -2    0    0    0    0    0    0    0    0    0
  131           0.00          16.21    1   -1    0    0   -1    0    0    0    0    0    0    0    0    0
  132           0.00         -16.00    0    0    0    0    0    0    2    0    0    0    0    0    0    2
  133           0.00         -15.31    1    0   -2    2   -2    0    0    0    0    0    0    0    0    0
  134           0.00         -15.10    2    0    0   -2   -1    0    0   -2    0    2    0    0    0    0
  135           0.00          14.70    0    0    0    0    0    0    1    1    0    0    0    0    0    2
  136           0.00          14.40    1    0    2   -1    2    0    0    0    0    0    0    0    0    0
  137          -0.10         -14.30    1    0    2    1    2    0    0    0    0    0    0    0    0    0
  138           0.00         -14.40    0    0    2    1    1    0    0    0    0    0    0    0    0    0
  139           0.00         -13.81    1    0   -2    0    1    0    0    0    0    0    0    0    0    0
  140           4.50          -9.30    0    0    1   -1    1    0    0   -1    0    0   -1    0    0    0
  141         -13.80           0.00    0    0    1    0    1    0    0    0    0    0    0    0    0    0
  142           0.00         -13.38    1    0    0   -2    2    0    0    0    0    0    0    0    0    0
  143          -0.10          13.10    1    0   -2   -4   -1    0    0    0    0    0    0    0    0    0
  144          10.30           2.70    0    0    1   -1    1    0    0   -1    0   -1    0    0    0    0
  145           0.00          12.80    1    0   -2    1   -1    0    0    0    0    0    0    0    0    0
  146           0.00         -12.80    1    1    2   -2    1    0    0    0    0    0    0    0    0    0
  147          11.70           0.80    0    0    0    0    0    0    0    0    0    2   -5    0    0    1
  148           0.00         -12.00    2    0   -2   -2   -1    0    0    0    0    0    0    0    0    0
  149          11.30           0.50    0    0    0    0    0    0    5   -8    0    0    0    0    0   -2
  150           0.00          11.40    0    0    0    0    0    0    0    1    0    1    0    0    0    2
  151           0.00         -11.20    1    1    0    0   -1    0    0    0    0    0    0    0    0    0
  152           0.10          10.90    4    0    2    0    2    0    0    0    0    0    0    0    0    0
  153           0.10         -10.77    1    0    2    0    0    0    0    0    0    0    0    0    0    0
  154           0.00         -10.80    2    1    2   -2    2    0    0    0    0    0    0    0    0    0
  155          -0.20          10.47    2    0   -2    0    0    0    0    0    0    0    0    0    0    0
  156           0.00          10.50    2    0   -2   -4   -1    0    0    0    0    0    0    0    0    0
  157           0.00         -10.40    1    0    4   -2    2    0    0    0    0    0    0    0    0    0
  158           0.00          10.40    0    1    2    1    2    0    0    0    0    0    0    0    0    0
  159           0.00         -10.20    0    1    0    2    1    0    0    0    0    0    0    0    0    0
  160           0.00         -10.00    1    0   -4    0   -1    0    0    0    0    0    0    0    0    0
  161           0.00           9.60    1    0    0   -4   -1    0    0    0    0    0    0    0    0    0
  162           0.10           9.40    2    0    2    2    1    0    0    0    0    0    0    0    0    0
  163          -7.60           1.70    0    0    0    0    0    0    8  -13    0    0    0    0    0   -2
  164          -7.70           1.40    0    0    1   -1    1    0    0   -1    0    2    0    0    0    0
  165           1.40          -7.50    0    0    1   -1    1    0   -5    7    0    0    0    0    0    0
  166           6.10          -2.70    0    0    0    0    0    0    0    0    0    0    2    0    0    1
  167           0.00          -8.70    0    0    0    0    0    0    5   -7    0    0    0    0    0   -2
  168          -5.90           2.60    0    0    1   -1    1    0    0   -1    0    0    2    0    0    0
  169           0.00           8.40    0    0    2   -4    1    0    0    0    0    0    0    0    0    0
  170          -0.20          -8.11    0    1    0   -2    0    0    0    0    0    0    0    0    0    0
  171          -2.60          -5.70    1    0    2    0    2    0    0    1    0    0    0    0    0    0
  172           0.00           8.30    0    0    2   -3    2    0    0    0    0    0    0    0    0    0
  173           2.70           5.50    1    0   -2    0   -2    0    0    4   -8    3    0    0    0    0
  174           4.20          -4.00    0    0    0    0    0    0    0    8  -16    4    5    0    0   -2
  175          -0.10           8.00    0    0    0    0    0    0    0    4    0   -2    0    0    0    2
  176           0.00           8.09    0    1    0   -2   -1    0    0    0    0    0    0    0    0    0
  177          -1.30           6.70    0    0    0    0    0    0    0    2    0   -1    0    0    0    2
  178           0.00          -7.90    0    0    4    0    2    0    0    0    0    0    0    0    0    0
  179           0.00           7.80    0    0    0    4    1    0    0    0    0    0    0    0    0    0
  180          -7.50          -0.20    0    0    0    0    0    0    2   -1    0    0    0    0    0    2
  181          -0.50          -7.20    0    0    0    0    0    0    0    2    0    1    0    0    0    2
  182           4.90           2.70    0    0    0    0    0    0    8  -11    0    0    0    0    0   -2
  183           0.00           7.50    1    1   -2   -4   -2    0    0    0    0    0    0    0    0    0
  184           0.00          -7.50    3    0    2   -2    1    0    0    0    0    0    0    0    0    0
  185           0.00          -7.49    2    0    0   -2   -2    0    0    0    0    0    0    0    0    0
  186           0.00          -7.20    0    0    4   -2    1    0    0    0    0    0    0    0    0    0
  187           0.10           6.90    1    0    2    4    2    0    0    0    0    0    0    0    0    0
  188          -5.60           1.40    0    0    0    0    0    0    4   -6    0    0    0    0    0   -1
  189          -5.70          -1.30    0    0    0    0    0    0    1   -1    0    0    0    0    0   -1
  190           0.00           6.90    2    1    0   -2   -1    0    0    0    0    0    0    0    0    0
  191           4.20          -2.70    0    0    0    0    0    0    8  -15    0    0    0    0    0   -2
  192           0.00           6.90    1    1   -2    0   -2    0    0    0    0    0    0    0    0    0
  193          -3.10           3.70    0    0    0    0    0    0    0    1    2    0    0    0    0    2
  194          -3.90          -2.90    0    0    0    0    0    0    0    3    0   -2    0    0    0    2
  195           0.00           6.60    3    0    0    0   -1    0    0    0    0    0    0    0    0    0
  196          -3.10          -3.50    0    0    0    0    0    0    0    3   -2    0    0    0    0    2
  197           1.10          -5.39    1    0    0   -1    1    0    0    0    0    0    0    0    0    0
  198           0.00          -6.40    2    0    0   -4   -1    0    0    0    0    0    0    0    0    0
  199           0.90           5.50    0    0    0    0    0    0    0    0    0    3    0    0    0    2
  200           0.00          -6.30    0    0    2   -2    1    0   -3    3    0    0    0    0    0    0
  201          -0.10          -6.20    0    0    0    0    0    0    0    4   -2    0    0    0    0    2
  202           0.00          -6.10    1    1    2    2    2    0    0    0    0    0    0    0    0    0
  203           0.00           6.10    0    0    1   -1    1    0    0    3   -8    3    0    0    0    0
  204           0.00           6.10    0    0    2   -1    1    0    0    0    0    0    0    0    0    0
  205           3.50          -2.50    0    0    0    0    1    0    8  -13    0    0    0    0    0    0
  206           0.00           6.00    0    0    2    4    1    0    0    0    0    0    0    0    0    0
  207           0.00           5.90    1   -1    0   -2   -1    0    0    0    0    0    0    0    0    0
  208          -0.90          -4.80    2    0    0   -2    1    0    0   -2    0    3    0    0    0    0
  209           0.00           5.70    1   -1   -2    2   -1    0    0    0    0    0    0    0    0    0
  210           0.10           5.60    3    0    2    2    2    0    0    0    0    0    0    0    0    0
  211           0.00           5.70    0    0    0    0    0    0    0    0    0    0    2    0    0    2
  212           0.00           5.70    2    0    0    2    1    0    0    0    0    0    0    0    0    0
  213           0.00           5.60    2    0    0   -4    1    0    0    0    0    0    0    0    0    0
  214           0.00           5.60    1    0    0   -4    1    0    0    0    0    0    0    0    0    0
  215           0.20          -5.40    2    1   -2    0   -1    0    0    0    0    0    0    0    0    0
  216          -0.90          -4.70    0    0    0    0    0    0    5   -8    0    0    0    0    0   -1
  217          -0.40          -5.10    1    1    0   -2    0    0    0    0    0    0    0    0    0    0
  218           0.00           5.50    0    2   -2   -2   -2    0    0    0    0    0    0    0    0    0
  219           0.00          -5.40    2    0    2   -4    1    0    0    0    0    0    0    0    0    0
  220           0.00          -5.40    0    0    0    0    0    0    0    8  -16    4    5    0    0    2
  221           1.80           3.60    1    0    0    0   -1    0  -18   16    0    0    0    0    0    0
  222           0.00           5.30    1   -1    0   -2   -2    0    0    0    0    0    0    0    0    0
  223           0.00          -5.30    0    0    1   -1    1    0    0   -5    8   -3    0    0    0    0
  224           0.00          -5.20    0    0    0    0    0    0    0    1    0   -3    0    0    0   -2
  225           0.00          -5.19    0    0    0    2   -2    0    0    0    0    0    0    0    0    0
  226           3.00           2.10    0    0    0    0    1    0   -8   13    0    0    0    0    0    0
  227           0.00          -5.10    0    0    0    0    0    0    6   -8    0    0    0    0    0   -2
  228           0.00           5.07    0    2    0    0    1    0    0    0    0    0    0    0    0    0
  229           0.90          -4.10    0    0    0    0    1    0    0    0    0   -2    5    0    0    0
  230          -5.00           0.00    0    0    0    0    0    0    3   -2    0    0    0    0    0    2
  231           0.00          -5.00    3    0    0    0    0    0    0    0    0    0    0    0    0    0
  232           0.00           5.00    1   -1    2    2    1    0    0    0    0    0    0    0    0    0
  233           0.00          -5.00    1   -1   -2    0   -1    0    0    0    0    0    0    0    0    0
  234           0.00          -4.90    4    0    2   -2    2    0    0    0    0    0    0    0    0    0
  235           4.90           0.00    0    0    0    0    0    0    2   -5    0    0    0    0    0   -2
  236           0.00          -4.90    0    0    0    0    0    0    1   -3    0    0    0    0    0   -2
  237           0.90           3.90    0    0    0    0    1    0    0    0    0    2   -5    0    0    0
  238           0.00           4.80    2    1   -2   -4   -2    0    0    0    0    0    0    0    0    0
  239          -3.70          -1.10    0    0    0    0    1    0    0    0    0    1    0    0    0    0
  240           0.00          -4.72    0    2    2   -2    1    0    0    0    0    0    0    0    0    0
  241           0.00           4.71    1    0    2    0   -1    0    0    0    0    0    0    0    0    0
  242           0.00          -4.50    2    1    0   -2    1    0    0    0    0    0    0    0    0    0
  243          -1.50          -3.00    1    0    0    0    1    0  -18   16    0    0    0    0    0    0
  244           0.00          -4.50    2   -1   -2    0   -1    0    0    0    0    0    0    0    0    0
  245           0.30          -4.11    1   -1    0    0    0    0    0    0    0    0    0    0    0    0
  246           0.00           4.40    1    2   -2   -2   -2    0    0    0    0    0    0    0    0    0
  247           0.00          -4.40    1   -1   -2   -2   -1    0    0    0    0    0    0    0    0    0
  248           0.00           4.39    2    0    0   -2    2    0    0    0    0    0    0    0    0    0
  249           0.00          -4.30    3    0    0    0    1    0    0    0    0    0    0    0    0    0
  250           0.00           4.30    2    0   -2    2   -1    0    0    0    0    0    0    0    0    0
  251           0.00          -4.30    0    1    2    2    1    0    0    0    0    0    0    0    0    0
  252           0.20           4.03    1    0   -2    0    0    0    0    0    0    0    0    0    0    0
  253           0.20           4.00    0    2   -2    0   -2    0    0    0    0    0    0    0    0    0
  254          -0.60           3.50    0    0    1   -1    1    0    0   -1    0    0    1    0    0    0
  255           0.00           4.10    3    0   -2    0   -1    0    0    0    0    0    0    0    0    0
  256           0.00           4.00    1    0   -4    2   -2    0    0    0    0    0    0    0    0    0
  257           0.00          -4.00    0    1   -2    1   -2    0    0    0    0    0    0    0    0    0
  258           0.00          -3.91    1    0    0   -4    0    0    0    0    0    0    0    0    0    0
  259           1.90           2.00    0    0    0    0    1    0    0    1   -2    0    0    0    0    0
  260           0.00           3.90    2   -1    2    2    2    0    0    0    0    0    0    0    0    0
  261           0.00           3.90    0    1   -2   -4   -2    0    0    0    0    0    0    0    0    0
  262           0.00          -3.90    1    0   -2   -3   -2    0    0    0    0    0    0    0    0    0
  263           3.10          -0.80    0    0    0    0    0    0    2   -4    0    0    0    0    0   -1
  264           0.00           3.90    2   -1    2    0    1    0    0    0    0    0    0    0    0    0
  265           0.00           3.90    2    0    0    0    2    0    0    0    0    0    0    0    0    0
  266           0.00           3.80    0    0    0    0    0    0    0    2    0    0    0    0    0    2
  267          -0.20           3.51    1    1    0    0    0    0    0    0    0    0    0    0    0    0
  268           0.00          -3.60    1    0   -2   -1   -2    0    0    0    0    0    0    0    0    0
  269          -2.10           1.50    0    0    0    0    0    0    0    1    0    2    0    0    0    2
  270           0.00          -3.60    1    1   -2    1   -1    0    0    0    0    0    0    0    0    0
  271           0.70           2.80    0    0    0    0    0    0    3   -7    0    0    0    0    0   -2
  272          -2.80           0.70    0    0    0    0    0    0    0    0    0    1    0    0    0   -1
  273           0.00          -3.50    0    0    0    0    0    0    0    2    0    0    0    0    0    0
  274          -2.90          -0.60    0    0    0    0    0    0    2   -2    0    0    0    0    0   -1
  275           0.00          -3.40    1   -1    0   -2    1    0    0    0    0    0    0    0    0    0
  276           0.00           3.40    2    0   -4    0   -2    0    0    0    0    0    0    0    0    0
  277           0.00           3.36    0    0    2    0    3    0    0    0    0    0    0    0    0    0
  278           0.50           2.80    2    0    0   -2   -1    0    0   -2    0    3    0    0    0    0
  279           2.60          -0.70    0    0    0    0    0    0    3   -5    0    0    0    0    0   -1
  280           1.00          -2.30    0    0    0    0    0    0    0    0    0    1    0    0    0    2
  281           0.00          -3.30    2    1    2    0    1    0    0    0    0    0    0    0    0    0
  282           0.00           3.30    1    1   -2    0   -1    0    0    0    0    0    0    0    0    0
  283           0.00           3.23    0    2    0    0   -1    0    0    0    0    0    0    0    0    0
  284           0.00           3.20    1   -1    2   -2    2    0    0    0    0    0    0    0    0    0
  285           0.00          -3.20    0    2    2    0    2    0    0    0    0    0    0    0    0    0
  286           0.00          -3.20    0    0    0    0    0    0    7   -9    0    0    0    0    0   -2
  287           0.00           3.20    0    0    0    0    0    0    0    0    2    0    0    0    0    2
  288           2.90          -0.30    0    0    0    0    0    0    0    0    0    1    0    0    0    1
  289           0.08           3.05    0    0    2   -2    3    0    0    0    0    0    0    0    0    0
  290          -0.70          -2.40    0    0    0    0    0    0    3   -3    0    0    0    0    0    2
  291           0.00          -3.08    1    0    2   -4    2    0    0    0    0    0    0    0    0    0
  292           0.00           3.00    2    0    2   -1    2    0    0    0    0    0    0    0    0    0
  293          -1.60           1.40    1    0    0   -1    1    0    0   -1    0    2    0    0    0    0
  294          -2.90          -0.10    0    0    0    0    0    0    4   -7    0    0    0    0    0   -2
  295           0.00          -2.90    2    0    0   -2    1    0    0   -2    0    2    0    0    0    0
  296          -2.50           0.40    0    0    1   -1    1    0    0   -2    2    0    0    0    0    0
  297           0.40          -2.50    0    0    0    0    0    0    0    0    0    0    1    0    0    1
  298           0.00          -2.90    1    0    2    1    1    0    0    0    0    0    0    0    0    0
  299           0.00           2.89    0    1   -2    2    0    0    0    0    0    0    0    0    0    0
  300           0.00          -2.80    2    1   -2   -2   -2    0    0    0    0    0    0    0    0    0
  301          -2.50           0.30    0    0    1   -1    1    0    0   -1    0    1    0    0    0    0
  302          -2.50          -0.30    0    0    0    0    0    0    0    1   -2    0    0    0    0   -1
  303           0.00          -2.70    0    0    2   -2    1    0    0   -2    0    2    0    0    0    0
  304           2.70           0.00    1    0   -1    0   -3    0    0    0    0    0    0    0    0    0
  305           0.00          -2.60    0    1    0    1    1    0    0    0    0    0    0    0    0    0
  306           0.00          -2.60    0    1    0    2   -1    0    0    0    0    0    0    0    0    0
  307           0.00           2.60    3   -1    2    0    2    0    0    0    0    0    0    0    0    0
  308           2.10           0.50    0    0    1   -1    1    0   -3    4    0    0    0    0    0    0
  309           0.00           2.50    0    1    0    1   -1    0    0    0    0    0    0    0    0    0
  310           0.80           1.70    0    0    0    0    0    0    0    0    0    0    1    0    0   -1
  311           1.90          -0.60    0    0    0    0    0    0    0    6  -16    4    5    0    0   -2
  312           0.00          -2.50    2    0    0    0   -2    0    0    0    0    0    0    0    0    0
  313           0.00          -2.40    2    0    0    2    0    0    0    0    0    0    0    0    0    0
  314           0.00           2.40    2    0    0    2   -1    0    0    0    0    0    0    0    0    0
  315           0.00          -2.40    1    1   -2    2   -1    0    0    0    0    0    0    0    0    0
  316           0.00           2.40    1    0    2   -3    1    0    0    0    0    0    0    0    0    0
  317          -1.90           0.50    0    0    0    0    0    0    5   -7    0    0    0    0    0   -1
  318          -0.10          -2.30    2    0    0   -4    0    0    0    0    0    0    0    0    0    0
  319           0.00           2.30    1    1    2   -4    1    0    0    0    0    0    0    0    0    0
  320           0.00          -2.30    3    1    2    0    2    0    0    0    0    0    0    0    0    0
  321          -1.40           0.90    0    0    0    0    0    0    0    0    4    0    0    0    0    2
  322          -0.10          -2.20    0    0    0    0    0    0    8  -10    0    0    0    0    0   -2
  323          -0.20          -2.00    0    0    0    1    0    0    0    0    0    0    0    0    0    0
  324           0.00           2.20    1   -2    2    0    2    0    0    0    0    0    0    0    0    0
  325           0.00          -2.20    2   -1    2   -2    2    0    0    0    0    0    0    0    0    0
  326           0.00           2.20    1    1    2    1    2    0    0    0    0    0    0    0    0    0
  327           0.00           2.20    0    0    0    0    0    0    0    2   -4    0    0    0    0   -2
  328          -1.80          -0.40    0    0    0    0    0    0    3   -3    0    0    0    0    0   -1
  329           0.00           2.20    0    1    2    1    1    0    0    0    0    0    0    0    0    0
  330           0.00           2.20    4    0    2    0    1    0    0    0    0    0    0    0    0    0
  331          -1.70           0.40    0    0    0    0    0    0    1   -1    0    0    0    0    0    1
  332          -0.80          -1.30    0    0    0    0    0    0    0    5   -4    0    0    0    0    2
  333          -1.30          -0.80    0    0    0    0    0    0    0    4   -4    0    0    0    0    2
  334           0.00           2.10    1    0   -2    1   -2    0    0    0    0    0    0    0    0    0
  335           0.00           2.10    1   -1    2   -2    1    0    0    0    0    0    0    0    0    0
  336           0.00          -2.10    1    0    4   -2    1    0    0    0    0    0    0    0    0    0
  337           0.00          -2.10    2    1    2   -2    1    0    0    0    0    0    0    0    0    0
  338           0.00           2.10    1    0    2   -1    1    0    0    0    0    0    0    0    0    0
  339           0.00          -2.00    1    0    2   -2   -1    0    0    0    0    0    0    0    0    0
  340           0.00           2.00    1    0   -2    2    1    0    0    0    0    0    0    0    0    0
  341           0.00           2.00    1   -1    0    2   -1    0    0    0    0    0    0    0    0    0
  342           0.00           2.00    2   -2    0   -2   -1    0    0    0    0    0    0    0    0    0
  343           0.00          -2.00    1    2    2   -2    2    0    0    0    0    0    0    0    0    0
  344           2.00           0.00    0    0    0    0    0    0    6   -9    0    0    0    0    0   -2
  345           1.10          -0.90    0    0    0    0    0    0    0    0    0    2   -5    0    0   -2
  346           1.60          -0.40    0    0    0    0    0    0    1   -3    0    0    0    0    0   -1
  347           0.00          -1.91    1    0   -2   -2    0    0    0    0    0    0    0    0    0    0
  348           0.00          -1.90    0    0    0    4    0    0    0    0    0    0    0    0    0    0
  349           0.00           1.90    0    0    4   -4    2    0    0    0    0    0    0    0    0    0
  350           0.00          -1.90    3    0   -2   -2   -2    0    0    0    0    0    0    0    0    0
  351           0.00           1.90    2   -1    0   -2    1    0    0    0    0    0    0    0    0    0
  352           1.50           0.40    0    0    1   -1    1    0   -4    5    0    0    0    0    0    0
  353          -1.50          -0.40    0    0    0    0    0    0    0    2    0    0    0    0    0    1
  354          -1.40          -0.50    0    0    1   -1    1    0    0   -1    0   -4   10    0    0    0
  355          -1.00           0.90    0    0    1   -1    1    0    0   -1    0    0    0    0    2    0
  356           0.00          -1.90    2    0    2    1    2    0    0    0    0    0    0    0    0    0
  357          -0.30           1.60    0    0    0    0    0    0    0    4    0   -3    0    0    0    2
  358           0.00           1.90    0    0    0    4   -1    0    0    0    0    0    0    0    0    0
  359           0.00           1.90    1   -1    0    2    1    0    0    0    0    0    0    0    0    0
  360           0.00          -1.80    2   -1    0    0    1    0    0    0    0    0    0    0    0    0
  361           0.00          -1.80    2    0   -4   -2   -2    0    0    0    0    0    0    0    0    0
  362          -1.10           0.70    0    0    0    0    0    0    0    2   -4    0    0    0    0   -1
  363           0.20          -1.60    0    0    0    0    0    0    2   -3    0    0    0    0    0   -1
  364           0.00           1.80    2    0   -2   -6   -2    0    0    0    0    0    0    0    0    0
  365           0.00          -1.71    0    0    2    2    0    0    0    0    0    0    0    0    0    0
  366          -1.20          -0.50    0    0    2   -2    1    0    0   -9   13    0    0    0    0    0
  367           1.50           0.20    0    0    1    1    1    0    0    1    0    0    0    0    0    0
  368          -0.60          -1.10    1    0    2    0    1    0    0   -2    0    3    0    0    0    0
  369           0.60           1.10    1    0   -2    0   -1    0    0   -1    0    0    0    0    0    0
  370          -0.60          -1.10    0    0    0    0    0    0    0    4   -3    0    0    0    0    2
  371          -1.10           0.60    0    0    0    0    1    0    0   -2    4    0    0    0    0    0
  372          -1.70           0.00    0    0    0    0    1    0    2   -3    0    0    0    0    0    0
  373           0.00           1.60    0    1   -2    2    1    0    0    0    0    0    0    0    0    0
  374           0.00          -1.60    2    0    4   -2    2    0    0    0    0    0    0    0    0    0
  375           0.00          -1.60    0    0    2    3    2    0    0    0    0    0    0    0    0    0
  376           1.20          -0.40    0    0    0    0    0    0    0    0    0    3    0    0    0    1
  377          -0.50          -1.10    2    0    2    0    2    0    0    2    0   -3    0    0    0    0
  378           0.60           1.00    0    0    0    0    0    0    0    3   -6    0    0    0    0   -2
  379          -1.30          -0.30    0    0    0    0    0    0    4   -4    0    0    0    0    0   -1
  380           0.30          -1.30    0    0    0    0    0    0    0    1   -2    0    0    0    0    1
  381           0.00           1.60    1    0    0    4    1    0    0    0    0    0    0    0    0    0
  382           0.00          -1.60    1    1    0    2    1    0    0    0    0    0    0    0    0    0
  383           0.00          -1.60    0    0    4    0    1    0    0    0    0    0    0    0    0    0
  384           1.10          -0.50    0    0    1   -1    2    0    0   -1    0    0    2    0    0    0
  385           0.00          -1.50    1   -1    0    2    0    0    0    0    0    0    0    0    0    0
  386           0.00          -1.50    0    1    2   -2   -1    0    0    0    0    0    0    0    0    0
  387           0.00           1.50    2   -1    0    0   -1    0    0    0    0    0    0    0    0    0
  388           0.00          -1.50    1    0    0    1   -1    0    0    0    0    0    0    0    0    0
  389           0.00          -1.50    1    2    0   -2   -1    0    0    0    0    0    0    0    0    0
  390           1.50           0.00    1    0    0   -1    1    0   -3    4    0    0    0    0    0    0
  391           0.00          -1.50    0    1    4   -2    2    0    0    0    0    0    0    0    0    0
  392           1.30          -0.20    0    0    0    0    1    0    0    0    0    0    1    0    0    0
  393           0.00          -1.50    0    0    0    0    0    0    9  -11    0    0    0    0    0   -2
  394          -1.20          -0.30    0    0    0    0    0    0    1    1    0    0    0    0    0    1
  395          -1.40           0.10    0    0    0    0    0    0    0    4    0   -1    0    0    0    2
  396          -0.50           1.00    0    0    2    0    2    0    0    1    0    0    0    0    0    0
  397          -0.50           1.00    0    0    0    0    0    0    0    1   -8    3    0    0    0   -2
  398           0.20          -1.30    0    0    0    0    0    0    0    1    0   -4    0    0    0   -2
  399           0.00           1.50    1    1   -2   -4   -1    0    0    0    0    0    0    0    0    0
  400           0.00           1.50    1    0    0   -1   -2    0    0    0    0    0    0    0    0    0
  401           0.00           1.50    0    0    0    0    1    0    1   -1    0    0    0    0    0    0
  402           0.00           1.49    2    0    2   -4    2    0    0    0    0    0    0    0    0    0
  403           0.00          -1.41    2    0    2    0    0    0    0    0    0    0    0    0    0    0
  404           0.00           1.41    0    1    0    2    0    0    0    0    0    0    0    0    0    0
  405           0.00          -1.40    0    0    2   -3    1    0    0    0    0    0    0    0    0    0
  406           0.00          -1.40    1   -2   -2   -2   -2    0    0    0    0    0    0    0    0    0
  407           0.00           1.40    1    0   -2   -6   -2    0    0    0    0    0    0    0    0    0
  408           0.00          -1.40    0    0    2   -2    1    0   -4    4    0    0    0    0    0    0
  409           1.10          -0.30    0    0    1   -1    1    0   -1    0    0    0    0    0    0    0
  410           0.00          -1.40    3    0   -2   -2   -1    0    0    0    0    0    0    0    0    0
  411           0.00           1.40    1    0    2    4    1    0    0    0    0    0    0    0    0    0
  412           1.40           0.00    0    0    1    0    2    0    0    0    0    0    0    0    0    0
  413          -0.30           1.10    0    0    0    0    1    0   -3    5    0    0    0    0    0    0
  414           0.20           1.20    2   -1    0   -2    0    0    0    0    0    0    0    0    0    0
  415          -1.30           0.00    1    0    0   -1   -1    0   -3    4    0    0    0    0    0    0
  416           0.00          -1.30    1   -1   -2   -4   -2    0    0    0    0    0    0    0    0    0
  417           0.00           1.30    1   -2    2    2    2    0    0    0    0    0    0    0    0    0
  418          -0.70          -0.60    0    0    1   -1    1    0    8  -14    0    0    0    0    0    0
  419          -0.80           0.50    0    0    1   -1    1    0    3   -6    0    0    0    0    0    0
  420          -0.20          -1.10    0    0    0    0    0    0    6  -10    0    0    0    0    0   -2
  421           1.10           0.20    0    0    0    0    0    0    0    2    0   -2    0    0    0    1
  422           0.00          -1.30    3    1    2   -2    2    0    0    0    0    0    0    0    0    0
  423           0.00          -1.30    1    0   -4   -2   -2    0    0    0    0    0    0    0    0    0
  424           0.00          -1.30    0    0    0    0    0    0    3   -1    0    0    0    0    0    2
  425           0.00          -1.30    0    0    0    0    0    0    0    3    0    0   -1    0    0    2
  426           0.00          -1.29    0    0    2   -4    2    0    0    0    0    0    0    0    0    0
  427           0.00           1.20    1    2    0   -2    1    0    0    0    0    0    0    0    0    0
  428           0.00          -1.20    2    1    0    0   -1    0    0    0    0    0    0    0    0    0
  429          -0.40          -0.80    0    0    0    0    1    0    0    8  -15    0    0    0    0    0
  430           0.00           1.20    2    0    2    4    2    0    0    0    0    0    0    0    0    0
  431           1.20           0.00    0    0    0    0    0    0    3   -6    0    0    0    0    0   -2
  432          -0.70          -0.50    0    0    1   -1    1    0    0   -3    4    0    0    0    0    0
  433          -1.00           0.20    0    0    0    0    0    0    6   -8    0    0    0    0    0   -1
  434          -1.00           0.20    0    0    0    0    0    0    2    1    0    0    0    0    0    2
  435           0.20          -1.00    0    0    0    0    0    0    2    1    0    0    0    0    0    1
  436           0.40           0.80    0    0    0    0    0    0    0    1   -4    0    0    0    0   -2
  437          -0.40           0.80    0    0    0    0    0    0    0    0    3    0    0    0    0    2
  438           0.00          -1.20    1    1    2    2    1    0    0    0    0    0    0    0    0    0
  439           0.00           1.15    0    0    0    0    3    0    0    0    0    0    0    0    0    0
  440           0.00           1.10    2    1    0    0    1    0    0    0    0    0    0    0    0    0
  441          -0.20           0.90    2    0    0   -2    1    0   -6    8    0    0    0    0    0    0
  442          -1.10           0.00    0    0    3    0    3    0    0    0    0    0    0    0    0    0
  443           0.00          -1.10    2    1    2    2    2    0    0    0    0    0    0    0    0    0
  444          -1.10           0.00    1    0    1    0    1    0    0    0    0    0    0    0    0    0
  445           0.00           1.10    2   -1   -2   -2   -2    0    0    0    0    0    0    0    0    0
  446           0.00           1.10    3    0    2   -4    2    0    0    0    0    0    0    0    0    0
  447           0.00           1.10    0    0    0    0    0    0    0    7   -8    3    0    0    0    2
  448           0.60          -0.50    0    0    0    0    0    0    0    0    0    0    0    0    2    1
  449          -0.90          -0.20    0    0    0    0    0    0    5   -5    0    0    0    0    0   -1
  450          -0.40          -0.70    0    0    0    0    0    0    0    4   -7    0    0    0    0   -2
  451          -0.50           0.60    1   -2    2   -2    1    0    0    0    0    0    0    0    0    0
  452           0.00           1.10    3    0    2    2    1    0    0    0    0    0    0    0    0    0
  453           0.00          -1.10    1   -1   -2    2   -2    0    0    0    0    0    0    0    0    0
  454           0.00           1.00    0    0    0    0    1    0   -1    1    0    0    0    0    0    0
  455           1.00           0.00    0    0    0    0    1    0   -2    3    0    0    0    0    0    0
  456           0.80          -0.20    0    0    0    0    1    0    0    0    0   -1    0    0    0    0
  457           0.00           1.00    1    0    0    1    1    0    0    0    0    0    0    0    0    0
  458           0.00           1.00    0    2    0   -2    1    0    0    0    0    0    0    0    0    0
  459           0.00          -1.00    3    0    0   -4   -1    0    0    0    0    0    0    0    0    0
  460          -1.00           0.00    1    0    1   -2    1    0    0    0    0    0    0    0    0    0
  461           0.00           1.00    1   -1    2    4    2    0    0    0    0    0    0    0    0    0
  462           1.00           0.00    0    0    1   -1    1    0    0   -9   15    0    0    0    0    0
  463           1.00           0.00    0    0    0    0    0    0    7  -10    0    0    0    0    0   -2
  464          -0.80          -0.20    0    0    0    0    0    0    2    0    0    0    0    0    0    1
  465           0.40           0.60    0    0    0    0    0    0    3   -5    4    0    0    0    0    2
  466          -0.40          -0.60    0    0    0    0    0    0    3   -9    4    0    0    0    0   -2
  467           0.00          -1.00    1    0    4    0    2    0    0    0    0    0    0    0    0    0
  468           0.00           1.00    0    1    2   -4    1    0    0    0    0    0    0    0    0    0
  469           0.00           1.00    1    0   -4    2   -1    0    0    0    0    0    0    0    0    0
  470           0.00           1.00    0    2   -2   -2   -1    0    0    0    0    0    0    0    0    0
  471           0.00           1.00    2    0   -2    0    2    0    0    0    0    0    0    0    0    0
  472           0.00          -1.00    1    0    0    2    2    0    0    0    0    0    0    0    0    0
  473           0.00           0.91    1    0    2   -2    0    0    0    0    0    0    0    0    0    0
  474           0.10           0.80    1   -1    0   -2    0    0    0    0    0    0    0    0    0    0
  475           0.00           0.90    1    0   -2   -2    1    0    0    0    0    0    0    0    0    0
  476           0.00           0.90    0    1    0   -2   -2    0    0    0    0    0    0    0    0    0
  477           0.00          -0.90    2    0    0   -2    1    0   -3    3    0    0    0    0    0    0
  478           0.00          -0.90    1    2    2    0    2    0    0    0    0    0    0    0    0    0
  479          -0.70          -0.20    0    0    0    0    0    0    6   -6    0    0    0    0    0   -1
  480           0.70          -0.20    0    0    0    0    0    0    1    2    0    0    0    0    0    2
  481          -0.30           0.60    0    0    0    0    0    0    0    8  -15    0    0    0    0   -2
  482           0.00           0.90    5    0    2    0    2    0    0    0    0    0    0    0    0    0
  483           0.00           0.90    3    0   -2   -6   -2    0    0    0    0    0    0    0    0    0
  484           0.00          -0.90    0    0    1   -1    1    0   -2    2    0    0    0    0    0    0
  485          -0.50          -0.40    0    0    0    0    0    0    0    3    0   -3    0    0    0    2
  486          -0.90           0.00    0    0    0    0    0    0    0    2    0    0   -1    0    0    2
  487           0.00          -0.90    1   -1    2   -1    2    0    0    0    0    0    0    0    0    0
  488           0.00           0.90    1    0   -2    4   -1    0    0    0    0    0    0    0    0    0
  489           0.00           0.90    2    1   -2   -4   -1    0    0    0    0    0    0    0    0    0
  490           0.00          -0.90    4    0    2   -2    1    0    0    0    0    0    0    0    0    0
  491           0.00          -0.90    1   -1    0   -1    0    0    0    0    0    0    0    0    0    0
  492           0.00          -0.80    2   -1    0    0    0    0    0    0    0    0    0    0    0    0
  493           0.00           0.80    3    0    0   -2   -1    0    0    0    0    0    0    0    0    0
  494           0.00          -0.80    2   -1   -2   -4   -2    0    0    0    0    0    0    0    0    0
  495           0.10           0.70    0    0    0    0    0    0    7  -11    0    0    0    0    0   -2
  496          -0.70           0.10    0    0    0    0    0    0    2   -2    0    0    0    0    0    1
  497          -0.60           0.20    0    0    0    0    0    0    7   -9    0    0    0    0    0   -1
  498           0.20           0.60    0    0    0    0    0    0    4   -7    0    0    0    0    0   -1
  499           0.00           0.80    0    0    4   -4    1    0    0    0    0    0    0    0    0    0
  500          -0.50           0.30    0    0    0    0    0    0    3   -5    0    0    0    0    0    1
  501          -0.50          -0.30    0    0    0    0    0    0    0    5   -5    0    0    0    0    2
  502          -0.50          -0.30    0    0    0    0    0    0    0    5   -9    0    0    0    0   -2
  503           0.00          -0.80    0    0    0    0    0    0    0    3   -1    0    0    0    0    2
  504          -0.30           0.50    0    0    0    0    0    0    0    2    0    2   -5    0    0    2
  505          -0.80           0.00    0    0    0    0    0    0    0    2    0    0    1    0    0    2
  506          -0.30          -0.50    0    0    0    0    0    0    0    2    0   -2    5    0    0    2
  507          -0.30           0.50    0    0    0    0    1    0   -3    7   -4    0    0    0    0    0
  508          -0.30          -0.50    0    0    0    0    1    0    3   -7    4    0    0    0    0    0
  509           0.00           0.80    0    1    0   -4   -1    0    0    0    0    0    0    0    0    0
  510           0.00          -0.80    3    0   -2    0   -2    0    0    0    0    0    0    0    0    0
  511           0.00          -0.80    1    0   -2   -3   -1    0    0    0    0    0    0    0    0    0
  512           0.00          -0.80    0    1   -2    1   -1    0    0    0    0    0    0    0    0    0
  513           0.00           0.80    1    2   -2   -2   -1    0    0    0    0    0    0    0    0    0
  514           0.00           0.80    1    1    0   -2   -2    0    0    0    0    0    0    0    0    0
  515           0.00          -0.80    0    0    0    0    1    0    0    1    0   -1    0    0    0    0
  516           0.00           0.76    1    0    2    0    3    0    0    0    0    0    0    0    0    0
  517           0.00           0.70    3    0    0   -4    1    0    0    0    0    0    0    0    0    0
  518           0.10          -0.60    2    0    0   -2   -1    0   -6    8    0    0    0    0    0    0
  519           0.00           0.70    0    1   -4    2   -2    0    0    0    0    0    0    0    0    0
  520           0.70           0.00    0    0    1   -1    1    0    0   -1    0   -1    1    0    0    0
  521           0.00          -0.70    0    0    0    0    1    0    3   -5    0    2    0    0    0    0
  522           0.00          -0.70    0    1    2    4    2    0    0    0    0    0    0    0    0    0
  523           0.00           0.70    4    0    2    2    2    0    0    0    0    0    0    0    0    0
  524           0.00          -0.70    2    0   -2   -3   -2    0    0    0    0    0    0    0    0    0
  525          -0.70           0.00    0    0    1   -1    1    0    2   -4    0   -3    0    0    0    0
  526          -0.50           0.20    0    0    1   -1    1    0    0   -1    0    3    0    0    0    0
  527          -0.20          -0.50    0    0    0    0    0    0    9   -9    0    0    0    0    0   -1
  528           0.50          -0.20    0    0    0    0    0    0    2   -3    0    0    0    0    0   -2
  529           0.20           0.50    0    0    0    0    0    0    0   11    0    0    0    0    0    2
  530          -0.20          -0.50    0    0    0    0    0    0    0    6  -15    0    0    0    0   -2
  531           0.50          -0.20    0    0    0    0    0    0    0    3    0    2   -5    0    0    2
  532          -0.50           0.20    0    0    0    0    0    0    0    3    0    1    0    0    0    2
  533           0.00          -0.70    0    0    0    0    0    0    0    3   -5    0    0    0    0   -2
  534           0.00          -0.70    0    0    0    0    0    0    0    2    0   -4    0    0    0   -2
  535           0.70           0.00    0    0    0    0    0    0    0    0    0    0    3    0    0    2
  536          -0.60          -0.10    0    0    0    0    0    0    3   -1    0    0    0    0    0    1
  537           0.60          -0.10    0    0    0    0    0    0    3   -3    0    0    0    0    0    1
  538           0.40           0.30    0    0    0    0    0    0    0    4   -8    0    0    0    0   -2
  539           0.00           0.70    1    0    0    1    0    0    0    0    0    0    0    0    0    0
  540           0.70           0.00    0    0    1   -1    2    0    0   -2    2    0    0    0    0    0
  541           0.00           0.70    2   -1    2    2    1    0    0    0    0    0    0    0    0    0
  542           0.00           0.70    0    1   -2   -4   -1    0    0    0    0    0    0    0    0    0
  543           0.00           0.70    1   -1    0    0    2    0    0    0    0    0    0    0    0    0
  544           0.00          -0.60    0    0    0    0    1    0    0   -1    0    1    0    0    0    0
  545           0.00           0.60    0    0    2    2   -1    0    0    0    0    0    0    0    0    0
  546           0.10          -0.50    0    0    1   -1   -1    0    0    0   -2    0    0    0    0    0
  547           0.00           0.60    2    1    0    0    0    0    0    0    0    0    0    0    0    0
  548           0.40           0.20    0    0    0    0    1    0    0    2   -4    0    0    0    0    0
  549           0.00           0.60    1    0    0   -4   -2    0    0    0    0    0    0    0    0    0
  550           0.00          -0.60    2    1    0   -4   -1    0    0    0    0    0    0    0    0    0
  551           0.00           0.60    1    1    0   -4    1    0    0    0    0    0    0    0    0    0
  552           0.00          -0.60    0    1    0    1    0    0    0    0    0    0    0    0    0    0
  553           0.00          -0.60    1   -1    2   -4    1    0    0    0    0    0    0    0    0    0
  554           0.50           0.10    0    0    1   -1    1    0   -2    3    0    0    0    0    0    0
  555          -0.50          -0.10    0    0    0    0    0    0    7   -7    0    0    0    0    0   -1
  556          -0.10          -0.50    0    0    0    0    0    0    4   -4    0    0    0    0    0    2
  557           0.10           0.50    0    0    0    0    0    0    1   -2    0    0    0    0    0    1
  558           0.50          -0.10    0    0    0    0    0    0    0    5    0   -2    0    0    0    2
  559          -0.10           0.50    0    0    0    0    0    0    0    3   -6    0    0    0    0   -1
  560           0.00          -0.60    2    0    0   -2   -1    0    0   -2    0    0    5    0    0    0
  561          -0.40           0.20    2    0   -1   -1   -1    0    0   -1    0    3    0    0    0    0
  562           0.00          -0.60    1    0   -2   -2   -2    0    0   -2    0    2    0    0    0    0
  563           0.60           0.00    0    0    2   -2    2    0   -8   11    0    0    0    0    0    0
  564           0.00          -0.60    0    0    2   -2    1    0   -2    2    0    0    0    0    0    0
  565           0.20           0.40    0    0    1   -1    1    0    0   -1    0    0    3    0    0    0
  566          -0.40           0.20    0    0    0    0    0    1    0   -4    0    0    0    0    0   -2
  567           0.30           0.30    0    0    0    0    0    0    8  -13    0    0    0    0    0    1
  568           0.40          -0.20    0    0    0    0    0    0    0    6    0    0    0    0    0    2
  569          -0.40          -0.20    0    0    0    0    0    0    0    6   -6    0    0    0    0    2
  570           0.00           0.60    0    0    0    0    0    0    0    1    1    0    0    0    0    2
  571           0.00           0.60    0    0    0    0    0    0    0    1    0    0    1    0    0    2
  572           0.40           0.20    0    0    0    0    0    0    0    1   -5    0    0    0    0   -2
  573          -0.20          -0.40    0    0    0    0    0    0    0    0    0    0    3    0    0    1
  574           0.00           0.60    4    0   -2   -2   -1    0    0    0    0    0    0    0    0    0
  575           0.00          -0.60    0    0    0    3    1    0    0    0    0    0    0    0    0    0
  576           0.00           0.60    3    0    0    2    1    0    0    0    0    0    0    0    0    0
  577           0.00           0.60    1    1    0   -4   -1    0    0    0    0    0    0    0    0    0
  578           0.00          -0.60    0    0    0    1    2    0    0    0    0    0    0    0    0    0
  579           0.00          -0.60    1    1    0   -2    2    0    0    0    0    0    0    0    0    0
  580           0.00          -0.60    2    0   -2    2   -2    0    0    0    0    0    0    0    0    0
  581           0.00          -0.50    1    1    0   -4    0    0    0    0    0    0    0    0    0    0
  582           0.00           0.50    2    0    2    0   -1    0    0    0    0    0    0    0    0    0
  583           0.10           0.40    2    1    0   -2    0    0    0    0    0    0    0    0    0    0
  584           0.00          -0.50    0    1    0    2    2    0    0    0    0    0    0    0    0    0
  585           0.10           0.40    0    0    0    0    1    0    3   -5    0    0    0    0    0    0
  586           0.00           0.50    1   -2    2   -2    2    0    0    0    0    0    0    0    0    0
  587           0.00           0.50    2    1    0   -4    1    0    0    0    0    0    0    0    0    0
  588           0.00          -0.50    1   -2    0    0    1    0    0    0    0    0    0    0    0    0
  589           0.30          -0.20    2    0    0   -2    1    0    0   -6    8    0    0    0    0    0
  590          -0.20           0.30    2    0    0   -2   -1    0    0   -5    6    0    0    0    0    0
  591           0.20           0.30    2    0   -1   -1   -1    0    0    3   -7    0    0    0    0    0
  592           0.40          -0.10    0    0    2    0    2    0    0   -4    8   -3    0    0    0    0
  593           0.40           0.10    0    0    2    0    2    0    0    4   -8    3    0    0    0    0
  594           0.00          -0.50    0    1   -2   -1   -2    0    0    0    0    0    0    0    0    0
  595           0.00          -0.50    3   -1    2   -2    2    0    0    0    0    0    0    0    0    0
  596           0.30           0.20    0    0    0    0    0    0    1    0    0    0    0    0    0    2
  597          -0.30           0.20    0    0    0    0    0    0    0    7  -13    0    0    0    0   -2
  598           0.20           0.30    0    0    0    0    0    0    0    2   -5    0    0    0    0   -2
  599          -0.30           0.20    0    0    0    0    0    0    0    1    0    3    0    0    0    2
  600           0.00           0.50    3   -1    2    2    2    0    0    0    0    0    0    0    0    0
  601           0.00           0.50    3   -1   -2   -1   -2    0    0    0    0    0    0    0    0    0
  602           0.00           0.50    0    0    2    6    2    0    0    0    0    0    0    0    0    0
  603          -0.50           0.00    0    0    1   -1    1    0    0    1    0    0    0    0    0    0
  604           0.50           0.00    0    0    0    0    0    0    9  -12    0    0    0    0    0   -2
  605           0.00          -0.50    0    0    0    0    0    0    6   -9    0    0    0    0    0   -1
  606          -0.50           0.00    0    0    0    0    0    0    4   -4    0    0    0    0    0    1
  607          -0.50           0.00    0    0    0    0    0    0    0    6  -11    0    0    0    0   -2
  608           0.00           0.50    0    0    0    0    0    0    0    1   -3    0    0    0    0   -2
  609           0.40           0.10    0    0    2   -2    1   -1    0    2    0    0    0    0    0    0
  610          -0.40          -0.10    0    0    1   -1    1    0    0   -1    0    0    0    2    0    0
  611           0.40          -0.10    0    0    0    0    0    0    5   -6    0    0    0    0    0    2
  612          -0.40           0.10    0    0    0    0    0    0    5  -10    0    0    0    0    0   -2
  613           0.10           0.40    0    0    0    0    0    0    0    5    0   -3    0    0    0    2
  614           0.10           0.40    0    0    0    0    0    0    0    0    0    4    0    0    0    2
  615          -0.50           0.00    0    0    3    0    2    0    0    0    0    0    0    0    0    0
  616           0.00           0.50    2    0   -4    0   -1    0    0    0    0    0    0    0    0    0
  617           0.00          -0.50    2    1   -2   -2   -1    0    0    0    0    0    0    0    0    0
  618           0.00           0.50    0    0    2   -2    2    0   -3    3    0    0    0    0    0    0
  619           0.00           0.50    1    0    0   -1    2    0    0    0    0    0    0    0    0    0
  620           0.00          -0.50    1    1    0    0    2    0    0    0    0    0    0    0    0    0
  621           0.50           0.00    0    0    2   -2    2    0   -5    6    0    0    0    0    0    0
  622           0.00          -0.50    1    0    0    2   -2    0    0    0    0    0    0    0    0    0
  623           0.00           0.50    1    0   -2    2    0    0    0    0    0    0    0    0    0    0
  624           0.00          -0.40    1    0    2    2    0    0    0    0    0    0    0    0    0    0
  625          -0.20           0.20    0    0    0    0    2    0    0   -1    2    0    0    0    0    0
  626          -0.10           0.30    1    1    0    2    0    0    0    0    0    0    0    0    0    0
  627           0.00          -0.40    1    0    0    4    0    0    0    0    0    0    0    0    0    0
  628           0.40           0.00    1    0   -1    0    1    0    0    0    0    0    0    0    0    0
  629           0.00          -0.40    0    2    0   -2    0    0    0    0    0    0    0    0    0    0
  630           0.00          -0.40    1    0    0   -3    1    0    0    0    0    0    0    0    0    0
  631           0.00           0.40    4    0    0    0   -1    0    0    0    0    0    0    0    0    0
  632           0.00           0.40    1   -2    0   -2   -1    0    0    0    0    0    0    0    0    0
  633          -0.10           0.30    0    0    0    0    1    0    0   -8   15    0    0    0    0    0
  634           0.00           0.40    1    0    4   -4    2    0    0    0    0    0    0    0    0    0
  635           0.00          -0.40    1    1    0   -1    1    0    0    0    0    0    0    0    0    0
  636           0.00          -0.40    0    0    2    0    2    0    1   -1    0    0    0    0    0    0
  637           0.00          -0.40    1    1    0    2   -1    0    0    0    0    0    0    0    0    0
  638           0.00           0.40    2   -2    2    0    2    0    0    0    0    0    0    0    0    0
  639          -0.20          -0.20    0    0    1   -1    1    0    0   -1    0    0   -2    0    0    0
  640           0.20          -0.20    0    0    1   -1    1    0    0   -1    0   -2    4    0    0    0
  641           0.20           0.20    0    0    0    0    0    0    0    2    2    0    0    0    0    2
  642          -0.10           0.30    2   -2    2   -2    2    0    0    0    0    0    0    0    0    0
  643          -0.30           0.10    0    0    0    0    0    0    6  -10    0    0    0    0    0   -1
  644           0.10           0.30    0    0    0    0    0    0    0    6   -5    0    0    0    0    2
  645          -0.10           0.30    0    0    0    0    0    0    0    2    0   -2    0    0    0    2
  646           0.00          -0.40    5    0    2   -2    2    0    0    0    0    0    0    0    0    0
  647           0.00           0.40    3    0    2   -1    2    0    0    0    0    0    0    0    0    0
  648           0.00           0.40    1    2   -2   -4   -2    0    0    0    0    0    0    0    0    0
  649           0.00           0.40    1   -1   -2   -3   -2    0    0    0    0    0    0    0    0    0
  650           0.00           0.40    0    0    4   -1    2    0    0    0    0    0    0    0    0    0
  651           0.00          -0.40    0    0    2   -2    1    0    0   -2    0    3    0    0    0    0
  652           0.00          -0.40    0    0    2   -2    1    0    0   -2    0    0    2    0    0    0
  653           0.40           0.00    0    0    2   -2    1    0    0   -8   11    0    0    0    0    0
  654          -0.40           0.00    0    0    1   -1    1    0    0   -1    0   -1    2    0    0    0
  655          -0.40           0.00    0    0    0    0    0    0    8   -8    0    0    0    0    0   -1
  656          -0.40           0.00    0    0    0    0    0    0    8  -10    0    0    0    0    0   -1
  657           0.00           0.40    0    0    0    0    0    0    5   -5    0    0    0    0    0    2
  658           0.00          -0.40    0    0    0    0    0    0    5   -9    0    0    0    0    0   -2
  659           0.00          -0.40    0    0    0    0    0    0    4   -2    0    0    0    0    0    2
  660          -0.40           0.00    0    0    0    0    0    0    4   -2    0    0    0    0    0    1
  661           0.40           0.00    0    0    0    0    0    0    4   -3    0    0    0    0    0    2
  662           0.00          -0.40    0    0    0    0    0    0    3   -4    0    0    0    0    0   -1
  663           0.00           0.40    0    0    0    0    0    0    3   -6    0    0    0    0    0   -1
  664           0.00           0.40    0    0    0    0    0    0    2   -6    0    0    0    0    0   -2
  665           0.40           0.00    0    0    0    0    0    0    0    8  -15    0    0    0    0   -1
  666           0.00          -0.40    0    0    0    0    0    0    0    6    0    0    0    0    0    0
  667          -0.40           0.00    0    0    0    0    0    0    0    5   -2    0    0    0    0    2
  668           0.00           0.40    0    0    0    0    0    0    0    5   -3    0    0    0    0    2
  669           0.40           0.00    0    0    0    0    0    0    0    0    0    0    1    0    0    2
  670           0.00          -0.40    4    0    0    0    0    0    0    0    0    0    0    0    0    0
  671           0.00          -0.40    1   -2   -2    0   -2    0    0    0    0    0    0    0    0    0
  672           0.00          -0.40    1    2    2   -2    1    0    0    0    0    0    0    0    0    0
  673           0.00          -0.40    0    2    2    0    1    0    0    0    0    0    0    0    0    0
  674           0.00          -0.40    3    1    2    0    1    0    0    0    0    0    0    0    0    0
  675          -0.10           0.30    0    2   -2    0   -1    0    0    0    0    0    0    0    0    0
  676           0.00           0.40    1    1    2    1    1    0    0    0    0    0    0    0    0    0
  677           0.00           0.40    3   -1    2    0    1    0    0    0    0    0    0    0    0    0
  678           0.00           0.40    2    0    2   -1    1    0    0    0    0    0    0    0    0    0
  679           0.00          -0.40    2    0    0    2    2    0    0    0    0    0    0    0    0    0
  680           0.40           0.00    0    0    1   -1    2    0    0   -1    0    2    0    0    0    0
  681           0.00           0.40    0    0    2   -2   -2    0    0    0    0    0    0    0    0    0
  682           0.21           0.10    0    0    1   -1    2    0    0   -1    0   -2    5    0    0    0
  683           0.00           0.30    2    0   -4    2   -2    0    0    0    0    0    0    0    0    0
  684          -0.30           0.00    0    0    2   -2   -1    0   -5    6    0    0    0    0    0    0
  685           0.00          -0.30    2   -2    0   -2    1    0    0    0    0    0    0    0    0    0
  686           0.00           0.30    0    0    0    4    2    0    0    0    0    0    0    0    0    0
  687           0.00           0.30    2    0    0   -2   -1    0   -3    3    0    0    0    0    0    0
  688           0.20           0.10    0    0    1   -1   -1    0    0   -1    0   -1    0    0    0    0
  689           0.00          -0.30    1   -2    0   -2    1    0    0    0    0    0    0    0    0    0
  690           0.00           0.30    1   -2    0    0   -1    0    0    0    0    0    0    0    0    0
  691           0.30           0.00    0    0    0    0    1    0    0    0    0    0   -1    0    0    0
  692           0.00           0.30    2    0    0   -3   -1    0    0    0    0    0    0    0    0    0
  693           0.00          -0.30    2    1   -2    0    1    0    0    0    0    0    0    0    0    0
  694          -0.20           0.10    2    0    0   -2   -1    0    0   -6    8    0    0    0    0    0
  695          -0.10          -0.20    2    0   -1   -1    1    0    0    3   -7    0    0    0    0    0
  696           0.00          -0.30    2    1    2   -4    1    0    0    0    0    0    0    0    0    0
  697           0.10          -0.20    1    0    0   -1    1    0    0   -3    4    0    0    0    0    0
  698           0.00           0.30    2   -1   -2    0   -2    0    0    0    0    0    0    0    0    0
  699           0.00           0.30    0    0    2    0    2    0   -1    1    0    0    0    0    0    0
  700           0.00          -0.30    0    0    2    0    2    0    0   -1    0    1    0    0    0    0
  701           0.00           0.30    0    0    2    0    2    0    0    1    0   -1    0    0    0    0
  702           0.00           0.30    0    1    0   -4    1    0    0    0    0    0    0    0    0    0
  703          -0.20           0.10    0    0    0    0    1    0    0   -9   17    0    0    0    0    0
  704           0.00          -0.30    1    1    4   -2    2    0    0    0    0    0    0    0    0    0
  705          -0.10          -0.20    2    0    2    0    1    0    0    1    0    0    0    0    0    0
  706          -0.10           0.20    1    0   -2    0   -2    0  -10    3    0    0    0    0    0    0
  707           0.20          -0.10    0    0    2   -2    1    0    0   -7    9    0    0    0    0    0
  708          -0.10          -0.20    0    0    0    0    0    0    2   -3    0    0    0    0    0    1
  709           0.20           0.10    0    0    0    0    0    0    1   -2    0    0    0    0    0   -2
  710           0.20          -0.10    0    0    0    0    0    0    1   -4    0    0    0    0    0   -2
  711          -0.20          -0.10    0    0    0    0    0    0    0    6  -10    0    0    0    0   -2
  712          -0.10          -0.20    0    0    0    0    0    0    0    5   -8    0    0    0    0   -2
  713           0.20          -0.10    0    0    0    0    0    0    0    3   -5    0    0    0    0   -1
  714           0.20           0.10    0    0    0    0    0    0    0    2   -6    0    0    0    0   -2
  715           0.00           0.30    4    0    2   -4    2    0    0    0    0    0    0    0    0    0
  716           0.00          -0.30    2    2    2   -2    2    0    0    0    0    0    0    0    0    0
  717           0.00           0.30    2    1    2    1    2    0    0    0    0    0    0    0    0    0
  718           0.00           0.30    2    0    0   -2   -1    0    0   -2    0    4   -5    0    0    0
  719           0.00          -0.30    2    0    0   -2   -2    0   -3    3    0    0    0    0    0    0
  720           0.30           0.00    2    0   -1   -1   -1    0    0   -1    0    0    0    0    0    0
  721           0.00          -0.30    1    0    2    3    2    0    0    0    0    0    0    0    0    0
  722           0.00           0.30    1    0    2   -2    2    0    0   -2    0    2    0    0    0    0
  723           0.30           0.00    1    0    1   -1    1    0    0   -1    0    0    0    0    0    0
  724           0.30           0.00    1    0   -1    1   -1    0  -18   17    0    0    0    0    0    0
  725           0.00          -0.30    1    0   -1   -1   -1    0   20  -20    0    0    0    0    0    0
  726           0.00          -0.30    1    0   -2   -2   -2    0   -3    3    0    0    0    0    0    0
  727           0.00          -0.30    0    2    2    2    2    0    0    0    0    0    0    0    0    0
  728           0.00           0.30    0    2   -2   -4   -2    0    0    0    0    0    0    0    0    0
  729           0.00           0.30    0    1    2    3    2    0    0    0    0    0    0    0    0    0
  730           0.00          -0.30    0    0    2   -2    1    0    0   -1    0    1    0    0    0    0
  731           0.30           0.00    0    0    1   -1    1    0    1   -2    0    0    0    0    0    0
  732           0.30           0.00    0    0    1   -1    1    0   -2    1    0    0    0    0    0    0
  733          -0.30           0.00    0    0    0    0    0    0    9  -11    0    0    0    0    0   -1
  734           0.00           0.30    0    0    0    0    0    0    8  -16    0    0    0    0    0   -2
  735          -0.30           0.00    0    0    0    0    0    0    5   -3    0    0    0    0    0    1
  736           0.30           0.00    0    0    0    0    0    0    0    6    0    0    0    0    0    1
  737          -0.30           0.00    0    0    0    0    0    0    0    6   -7    0    0    0    0    2
  738           0.00           0.30    0    0    0    0    0    0    0    4    0    0   -2    0    0    2
  739           0.30           0.00    0    0    0    0    0    0    0    4   -8    1    5    0    0   -2
  740          -0.30           0.00    0    0    0    0    0    0    0    3    0    0   -2    0    0    2
  741           0.30           0.00    0    0    0    0    0    0    0    1    0   -1    0    0    0    1
  742           0.30           0.00    0    0    0    0    0    0    0    1    0   -3    0    0    0   -1
  743           0.30           0.00    0    0    0    0    0    0    0    1   -6    0    0    0    0   -2
  744           0.00          -0.30    0    0    0    0    0    0    0    0    0    4   -5    0    0    2
  745           0.00           0.30    0    0    0    0    0    0    0    0    0    0    5    0    0    2
  746           0.00           0.30    0    0    0    0    0    0    0    0    0    0    0    2    0    2
  747           0.30           0.00    0    0    0    0    0    0    0    0    0    0    0    2    0    1
  748           0.00           0.30    0    0    0    0    0    0    0    0    0    0    0    0    2    2
  749           0.00          -0.30    1    0    0   -1   -1    0    0   -2    2    0    0    0    0    0
  750           0.00          -0.30    2   -1    2   -1    2    0    0    0    0    0    0    0    0    0
  751           0.30           0.00    2    0   -1   -1   -1    0    0   -1    0    2    0    0    0    0
  752           0.00           0.30    1    0    0   -6   -1    0    0    0    0    0    0    0    0    0
  753           0.00          -0.30    1   -1    0   -4   -1    0    0    0    0    0    0    0    0    0
  754           0.00           0.30    1    0    0    4   -1    0    0    0    0    0    0    0    0    0
  755           0.00          -0.30    3    0    0   -2    1    0    0    0    0    0    0    0    0    0
  756           0.30           0.00    0    0    0    0    1    0    5   -8    0    0    0    0    0    0
  757           0.00          -0.30    1   -2   -2   -2   -1    0    0    0    0    0    0    0    0    0
  758           0.00          -0.30    0    1    4   -2    1    0    0    0    0    0    0    0    0    0
  759           0.00          -0.30    2    0    4   -2    1    0    0    0    0    0    0    0    0    0
  760           0.00          -0.30    0    0    2    3    1    0    0    0    0    0    0    0    0    0
  761           0.30           0.00    0    0    1   -1    2    0    0   -1    0    1    0    0    0    0
  762           0.00           0.30    1   -2    2    0    1    0    0    0    0    0    0    0    0    0
  763           0.00          -0.30    2   -1    2   -2    1    0    0    0    0    0    0    0    0    0
  764           0.00           0.30    2    0   -2   -6   -1    0    0    0    0    0    0    0    0    0
  765           0.00          -0.30    2    0   -4   -2   -1    0    0    0    0    0    0    0    0    0
  766           0.00          -0.30    2    0    2    1    1    0    0    0    0    0    0    0    0    0
  767           0.00           0.30    0    0    1   -1    2    0    0    0   -2    0    0    0    0    0
  768          -0.30           0.00    0    0    0    0    2    0    0    4   -8    3    0    0    0    0
  769          -0.30           0.00    0    0    0    0    2    0    0   -4    8   -3    0    0    0    0
  770           0.00           0.30    0    0    0    1   -2    0    0    0    0    0    0    0    0    0
  771           0.00          -0.30    0    0    2    0   -2    0    0    0    0    0    0    0    0    0
  772           0.00          -0.30    0    1    0   -2    2    0    0    0    0    0    0    0    0    0
  773          -0.20          -0.10    0    0    0    0    1    0    0    1    0   -2    0    0    0    0
  774           0.00          -0.30    0    0    0    0    1    0    2   -2    0    0    0    0    0    0
  775           0.00          -0.30    1    1    2   -4    2    0    0    0    0    0    0    0    0    0
  776           0.00          -0.21    0    1    2   -2    3    0    0    0    0    0    0    0    0    0
  777           0.00           0.20    2    0    2   -2    0    0    0    0    0    0    0    0    0    0
  778           0.00          -0.20    0    0    0    0    1    0   -2    2    0    0    0    0    0    0
  779           0.00          -0.20    3    0    2    0    0    0    0    0    0    0    0    0    0    0
  780           0.00          -0.20    0    0    0    0    1    0    0   -2    2    0    0    0    0    0
  781           0.00          -0.20    0    1    0   -4    0    0    0    0    0    0    0    0    0    0
  782           0.20           0.00    0    0    0    0    1    0   -3    4    0    0    0    0    0    0
  783           0.00          -0.20    3    0    0    2    0    0    0    0    0    0    0    0    0    0
  784           0.00           0.20    0    3    0    0    0    0    0    0    0    0    0    0    0    0
  785           0.00           0.20    2    0   -2   -2    0    0    0    0    0    0    0    0    0    0
  786           0.20           0.00    2    0    2   -4    0    0    0    0    0    0    0    0    0    0
  787           0.00           0.20    1    0    0   -3   -1    0    0    0    0    0    0    0    0    0
  788           0.00          -0.20    2    0    2   -2   -1    0    0    0    0    0    0    0    0    0
  789           0.00           0.20    1    0    2   -4   -1    0    0    0    0    0    0    0    0    0
  790           0.00           0.20    0    0    1   -1    2    0    0   -1    0    0    1    0    0    0
  791           0.00           0.20    1    0   -2    1    1    0    0    0    0    0    0    0    0    0
  792           0.00          -0.20    1    2    0   -2    0    0    0    0    0    0    0    0    0    0
  793           0.00          -0.20    2    0   -2   -2    1    0    0    0    0    0    0    0    0    0
  794           0.00          -0.20    1    0    0   -1    1    0    0   -1    0    1    0    0    0    0
  795           0.00          -0.20    2    0    0   -3    1    0    0    0    0    0    0    0    0    0
  796           0.00          -0.20    1    1    0    1    1    0    0    0    0    0    0    0    0    0
  797           0.00           0.20    1    1    0    1   -1    0    0    0    0    0    0    0    0    0
  798           0.00          -0.20    2    0    0   -1    1    0    0    0    0    0    0    0    0    0
  799           0.00           0.20    1    2    0    0    1    0    0    0    0    0    0    0    0    0
  800           0.00          -0.20    2    0    0   -2    1    0    0   -5    6    0    0    0    0    0
  801           0.00           0.20    1    0    0   -2   -1    0    0   -2    0    2    0    0    0    0
  802           0.00          -0.20    1    0    0   -2    1    0    0   -2    0    2    0    0    0    0
  803           0.00           0.20    2    0   -4    2   -1    0    0    0    0    0    0    0    0    0
  804           0.20           0.00    0    0    2   -2    1    0    0    4   -8    3    0    0    0    0
  805           0.20           0.00    0    0    2   -2    1    0    0   -4    8   -3    0    0    0    0
  806           0.00           0.20    2   -1    0    2   -1    0    0    0    0    0    0    0    0    0
  807           0.00           0.20    1    0    0   -1   -1    0    0   -3    4    0    0    0    0    0
  808           0.10          -0.10    1   -2    0   -2    0    0    0    0    0    0    0    0    0    0
  809           0.00          -0.20    2    0    0   -2   -1    0    0   -2    0    3   -1    0    0    0
  810           0.00           0.20    1   -1   -4    2   -2    0    0    0    0    0    0    0    0    0
  811           0.00           0.20    3    0    0    2   -1    0    0    0    0    0    0    0    0    0
  812           0.00           0.20    1    0    0   -3    0    0    0    0    0    0    0    0    0    0
  813           0.00           0.20    2    0    2   -6    1    0    0    0    0    0    0    0    0    0
  814           0.00           0.20    2   -1   -2    2   -1    0    0    0    0    0    0    0    0    0
  815           0.00           0.20    1   -2   -2    2   -1    0    0    0    0    0    0    0    0    0
  816           0.00           0.20    2    0    4   -4    2    0    0    0    0    0    0    0    0    0
  817           0.20           0.00    2    0   -1   -1   -2    0    0   -1    0    2    0    0    0    0
  818           0.00          -0.20    4    1    2    0    2    0    0    0    0    0    0    0    0    0
  819           0.00           0.20    4   -1    2    0    2    0    0    0    0    0    0    0    0    0
  820           0.00          -0.20    4   -1   -2   -2   -2    0    0    0    0    0    0    0    0    0
  821           0.00          -0.20    3    0    4   -2    2    0    0    0    0    0    0    0    0    0
  822           0.00          -0.20    3    0    2    1    2    0    0    0    0    0    0    0    0    0
  823           0.00           0.20    3    0   -2    2   -1    0    0    0    0    0    0    0    0    0
  824           0.00          -0.20    3    0   -2   -1   -1    0    0    0    0    0    0    0    0    0
  825           0.00           0.20    2    2   -2   -4   -2    0    0    0    0    0    0    0    0    0
  826           0.00          -0.20    2    1    0   -4    0    0    0    0    0    0    0    0    0    0
  827           0.00           0.20    2    1   -2   -6   -2    0    0    0    0    0    0    0    0    0
  828           0.00           0.20    2    0    2   -3    2    0    0    0    0    0    0    0    0    0
  829           0.00           0.20    2   -2    2    2    2    0    0    0    0    0    0    0    0    0
  830           0.00          -0.20    1    1    2    4    2    0    0    0    0    0    0    0    0    0
  831           0.00          -0.20    1    1   -2   -3   -2    0    0    0    0    0    0    0    0    0
  832           0.00           0.20    1    1   -2   -6   -2    0    0    0    0    0    0    0    0    0
  833          -0.20           0.00    1    0    3    0    3    0    0    0    0    0    0    0    0    0
  834           0.20           0.00    1    0    1    1    1    0    0    1    0    0    0    0    0    0
  835           0.20           0.00    1    0   -1    1   -1    0    0    1    0    0    0    0    0    0
  836           0.00           0.20    1    0   -1    0   -1    0   -3    5    0    0    0    0    0    0
  837           0.20           0.00    1    0   -1   -2   -1    0    0    0    0    0    0    0    0    0
  838           0.00           0.20    1    0   -2   -2   -2    0    0   -2    0    3    0    0    0    0
  839           0.00          -0.20    1   -1    2    1    2    0    0    0    0    0    0    0    0    0
  840           0.00           0.20    1   -1   -2    1   -1    0    0    0    0    0    0    0    0    0
  841           0.00           0.20    0    3   -2   -2   -2    0    0    0    0    0    0    0    0    0
  842           0.00          -0.20    0    0    4    2    2    0    0    0    0    0    0    0    0    0
  843           0.00           0.20    0    0    2   -2    1    0    0    1    0   -1    0    0    0    0
  844           0.00           0.20    0    0    2   -2    1    0    0   -2    0    0    0    0    0    0
  845           0.00          -0.20    0    0    2   -2    1    0    0   -3    0    3    0    0    0    0
  846           0.00          -0.20    0    0    2   -2    1    0    0   -4    4    0    0    0    0    0
  847           0.00          -0.20    0    0    2   -2    1    0   -5    5    0    0    0    0    0    0
  848           0.00           0.20    0    0    1   -1    1    0    1   -3    0    0    0    0    0    0
  849           0.00          -0.20    0    0    1   -1    1    0    0    1   -4    0    0    0    0    0
  850           0.20           0.00    0    0    1   -1    1    0    0   -1    0    1   -3    0    0    0
  851           0.20           0.00    0    0    1   -1    1    0    0   -1    0    0    0   -1    0    0
  852           0.00          -0.20    0    0    1   -1    1    0    0   -4    6    0    0    0    0    0
  853           0.20           0.00    0    0    1   -1    1    0   -5    6    0    0    0    0    0    0
  854           0.00           0.20    0    0    0    0    0    0    8  -12    0    0    0    0    0   -2
  855           0.00          -0.20    0    0    0    0    0    0    7  -10    0    0    0    0    0   -1
  856           0.20           0.00    0    0    0    0    0    0    7  -11    0    0    0    0    0   -1
  857          -0.20           0.00    0    0    0    0    0    0    6   -4    0    0    0    0    0    1
  858          -0.20           0.00    0    0    0    0    0    0    6   -6    0    0    0    0    0    1
  859          -0.20           0.00    0    0    0    0    0    0    5   -5    0    0    0    0    0    1
  860           0.00          -0.20    0    0    0    0    0    0    5   -6    0    0    0    0    0   -1
  861          -0.20           0.00    0    0    0    0    0    0    4   -2    0    0    0    0    0    0
  862           0.00          -0.20    0    0    0    0    0    0    4   -5    0    0    0    0    0   -1
  863           0.20           0.00    0    0    0    0    0    0    4   -5    0    0    0    0    0   -2
  864           0.00          -0.20    0    0    0    0    0    0    3   -4    0    0    0    0    0    1
  865           0.20           0.00    0    0    0    0    0    0    3   -4    0    0    0    0    0   -2
  866          -0.20           0.00    0    0    0    0    0    0    3   -8    0    0    0    0    0   -2
  867           0.00           0.20    0    0    0    0    0    0    2   -5    0    0    0    0    0   -1
  868           0.00           0.20    0    0    0    0    0    0    1   -2    0    0    0    0    0   -1
  869           0.00           0.20    0    0    0    0    0    0    1   -4    0    0    0    0    0   -1
  870           0.00          -0.20    0    0    0    0    0    0    0    9  -17    0    0    0    0   -2
  871          -0.20           0.00    0    0    0    0    0    0    0    7   -7    0    0    0    0    2
  872          -0.20           0.00    0    0    0    0    0    0    0    7   -8    0    0    0    0    2
  873          -0.20           0.00    0    0    0    0    0    0    0    7   -9    0    0    0    0    2
  874          -0.20           0.00    0    0    0    0    0    0    0    5   -6    0    0    0    0    2
  875           0.20           0.00    0    0    0    0    0    0    0    5  -10    0    0    0    0   -2
  876           0.00           0.20    0    0    0    0    0    0    0    4    0   -4    0    0    0    2
  877           0.00          -0.20    0    0    0    0    0    0    0    4   -6    0    0    0    0   -2
  878           0.00          -0.20    0    0    0    0    0    0    0    4   -7    0    0    0    0   -1
  879           0.00          -0.20    0    0    0    0    0    0    0    4   -8    3    0    0    0    1
  880           0.00           0.20    0    0    0    0    0    0    0    4   -8    3    0    0    0   -1
  881           0.20           0.00    0    0    0    0    0    0    0    4   -8    1    5    0    0    2
  882           0.20           0.00    0    0    0    0    0    0    0    3    0    0    0    0    0    2
  883           0.00           0.20    0    0    0    0    0    0    0    3   -8    3    0    0    0   -2
  884           0.20           0.00    0    0    0    0    0    0    0    2    0    0   -2    0    0    1
  885           0.00          -0.20    0    0    0    0    0    0    0    2    0   -5    0    0    0   -2
  886           0.00          -0.20    0    0    0    0    0    0    0    2   -4    0    0    0    0    1
  887           0.20           0.00    0    0    0    0    0    0    0    2   -7    0    0    0    0   -2
  888           0.20           0.00    0    0    0    0    0    0    0    1    0    1    0    0    0    1
  889           0.00           0.20    0    0    0    0    0    0    0    1    0    0    0    0    0   -1
  890           0.20           0.00    0    0    0    0    0    0    0    1    0   -1    0    0    0   -1
  891           0.20           0.00    0    0    0    0    0    0    0    1    0   -2    5    0    0    2
  892           0.00           0.20    0    0    0    0    0    0    0    1    0   -2    0    0    0   -2
  893           0.00          -0.20    0    0    0    0    0    0    0    1    0   -5    0    0    0   -2
  894           0.10          -0.10    0    0    0    0    0    0    0    2    1    0    0    0    0    2
  895           0.00          -0.20    1    0    4    0    1    0    0    0    0    0    0    0    0    0
  896           0.00           0.20    4    0   -2    0   -1    0    0    0    0    0    0    0    0    0
  897           0.00          -0.20    0    1    0    4    1    0    0    0    0    0    0    0    0    0
  898           0.00           0.20    2    0    0    4    1    0    0    0    0    0    0    0    0    0
  899           0.00           0.20    0    0    0    0    1    0    0    7  -13    0    0    0    0    0
  900           0.00          -0.20    2    1    0    2    1    0    0    0    0    0    0    0    0    0
  901           0.00           0.20    1   -1    0    4    1    0    0    0    0    0    0    0    0    0
  902           0.20           0.00    0    0    2   -2    1    0   -8   11    0    0    0    0    0    0
  903           0.00           0.20    1    0    2   -6    1    0    0    0    0    0    0    0    0    0
  904           0.00           0.20    0    0    2   -2    2    0    0   -2    0    2    0    0    0    0
  905           0.00          -0.20    1    2    2    0    1    0    0    0    0    0    0    0    0    0
  906           0.00           0.20    3    0   -2   -6   -1    0    0    0    0    0    0    0    0    0
  907           0.00           0.20    2    0    0   -6   -1    0    0    0    0    0    0    0    0    0
  908           0.00           0.20    1   -1    2    4    1    0    0    0    0    0    0    0    0    0
  909           0.00          -0.20    2    1    2    2    1    0    0    0    0    0    0    0    0    0
  910          -0.20           0.00    0    0    1    1    2    0    0    1    0    0    0    0    0    0
  911           0.00           0.20    2   -1   -2   -2   -1    0    0    0    0    0    0    0    0    0
  912           0.00          -0.20    0    1   -2    4   -1    0    0    0    0    0    0    0    0    0
  913           0.00           0.20    2    0    2    4    1    0    0    0    0    0    0    0    0    0
  914           0.00          -0.20    1   -1   -2   -4   -1    0    0    0    0    0    0    0    0    0
  915           0.00          -0.20    1    0   -4   -2   -1    0    0    0    0    0    0    0    0    0
  916           0.00           0.20    1   -2    2    2    1    0    0    0    0    0    0    0    0    0
  917           0.00           0.20    1    0   -2   -6   -1    0    0    0    0    0    0    0    0    0
  918           0.00          -0.20    3    1    2   -2    1    0    0    0    0    0    0    0    0    0
  919           0.00          -0.20    2   -2    0   -2   -2    0    0    0    0    0    0    0    0    0
  920           0.00           0.20    2   -1    0    2    1    0    0    0    0    0    0    0    0    0
  921           0.00           0.20    3    0    0    0    2    0    0    0    0    0    0    0    0    0
  922           0.00          -0.20    1   -1    2   -3    1    0    0    0    0    0    0    0    0    0
  923           0.00           0.20    0    0    1   -1    2    0   -5    7    0    0    0    0    0    0
  924           0.00          -0.20    2    1    0   -2   -2    0    0    0    0    0    0    0    0    0
  925          -0.20           0.00    0    0    1   -1    2    0    0   -1    0   -1    0    0    0    0
  926           0.00          -0.20    2    1   -2    0    0    0    0    0    0    0    0    0    0    0
  927           0.00           0.20    1    0   -2    0    2    0    0    0    0    0    0    0    0    0
  928           0.00          -0.20    1   -1    0    0   -2    0    0    0    0    0    0    0    0    0
  929           0.00          -0.20    0    2    0    0    2    0    0    0    0    0    0    0    0    0
  930          -0.20           0.00    0    0    0    0    1    0    3   -4    0    0    0    0    0    0
  931           0.00          -0.20    0    0    0    0    1    0    0    2   -2    0    0    0    0    0
  932           0.00           0.20    0    0    0    0    1    0    0    2    0   -2    0    0    0    0
  933           0.00          -0.20    0    1    2   -4    2    0    0    0    0    0    0    0    0    0
  934           0.00           0.20    0    0    1   -1    2    0   -8   12    0    0    0    0    0    0
  935           0.00           0.20    1    1   -2    2   -2    0    0    0    0    0    0    0    0    0
  936           0.00          -0.19    0    1    2   -2    0    0    0    0    0    0    0    0    0    0
  937           0.00           0.17    0    1   -2    2   -3    0    0    0    0    0    0    0    0    0
  938           0.00           0.11    1    0   -2    0   -3    0    0    0    0    0    0    0    0    0
  939           0.00          -0.10    1    1   -2   -2    0    0    0    0    0    0    0    0    0    0
  940           0.10           0.00    0    0    0    0    1    0    0   -1    0    2    0    0    0    0
  941           0.00          -0.10    0    1   -2   -2    0    0    0    0    0    0    0    0    0    0
  942           0.00           0.10    1    0    0    0   -1    0  -10    3    0    0    0    0    0    0
  943           0.00          -0.10    1    0    0    0    1    0  -10    3    0    0    0    0    0    0
  944           0.00          -0.10    1    0   -2   -4    0    0    0    0    0    0    0    0    0    0
  945           0.00          -0.10    2   -1    0    2    0    0    0    0    0    0    0    0    0    0
  946           0.00          -0.10    0    2    0    0   -2    0    0    0    0    0    0    0    0    0
  947           0.00          -0.10    1    0    0   -6    0    0    0    0    0    0    0    0    0    0
  948           0.00           0.10    0    1    4   -4    2    0    0    0    0    0    0    0    0    0
  949           0.00          -0.10    2    0    0   -6    0    0    0    0    0    0    0    0    0    0
  950          -0.10           0.00    0    0    0    0    2    0    0    0    0    1    0    0    0    0
  951           0.00          -0.10    3    0    0   -4    0    0    0    0    0    0    0    0    0    0
  952           0.00          -0.10    2   -1   -2    0    1    0    0    0    0    0    0    0    0    0
  953           0.00           0.10    2    2    0   -2   -1    0    0    0    0    0    0    0    0    0
  954           0.00          -0.10    0    0    0    3    2    0    0    0    0    0    0    0    0    0
  955           0.00          -0.10    3   -1    0    0    0    0    0    0    0    0    0    0    0    0
  956           0.10           0.00    0    0    2    0    2    0    2   -3    0    0    0    0    0    0
  957           0.10           0.00    0    0    2    0    2    0   -2    3    0    0    0    0    0    0
  958           0.00           0.10    0    0    2    0    2    0    2   -2    0    0    0    0    0    0
  959           0.00          -0.10    0    0    2    0    2    0   -2    2    0    0    0    0    0    0
  960           0.00          -0.10    2   -1   -2    0    0    0    0    0    0    0    0    0    0    0
  961           0.00           0.10    2    0   -2   -2   -2    0    0   -2    0    2    0    0    0    0
  962           0.00           0.10    1    2    2   -4    1    0    0    0    0    0    0    0    0    0
]'

const coefs_iau2006_CIP_y1 = Float64[
  963      153041.79         853.32    0    0    0    0    1    0    0    0    0    0    0    0    0    0
  964       11714.49        -290.91    0    0    2   -2    2    0    0    0    0    0    0    0    0    0
  965        2024.68         -51.26    0    0    2    0    2    0    0    0    0    0    0    0    0    0
  966       -1837.32          48.00    0    0    0    0    2    0    0    0    0    0    0    0    0    0
  967       -1312.21         -28.93    0    1    0    0    0    0    0    0    0    0    0    0    0    0
  968        -632.54           0.78    1    0    0    0    0    0    0    0    0    0    0    0    0    0
  969         459.68         -67.30    0    1    2   -2    2    0    0    0    0    0    0    0    0    0
  970         344.50           1.41    0    0    2    0    1    0    0    0    0    0    0    0    0    0
  971         268.14          -7.06    1    0    2    0    2    0    0    0    0    0    0    0    0    0
  972         192.06          29.83    0    1   -2    2   -2    0    0    0    0    0    0    0    0    0
  973         139.64           0.15    1    0    0   -2    0    0    0    0    0    0    0    0    0    0
  974        -113.94          -1.04    0    0    2   -2    1    0    0    0    0    0    0    0    0    0
  975         109.81           3.20    1    0   -2    0   -2    0    0    0    0    0    0    0    0    0
  976         -56.37           0.13    0    0    0    2    0    0    0    0    0    0    0    0    0    0
  977         -56.17          -0.01    1    0    0    0    1    0    0    0    0    0    0    0    0    0
  978         -53.05          -1.24    1    0   -2   -2   -2    0    0    0    0    0    0    0    0    0
  979         -51.60           0.16    1    0    0    0   -1    0    0    0    0    0    0    0    0    0
  980          45.91          -0.12    1    0    2    0    1    0    0    0    0    0    0    0    0    0
  981         -42.45           0.02    2    0    0   -2    0    0    0    0    0    0    0    0    0    0
  982          40.82          -1.02    2    0   -2    0   -1    0    0    0    0    0    0    0    0    0
  983          34.30          -1.25    0    0    2    2    2    0    0    0    0    0    0    0    0    0
  984          28.89           0.00    0    2   -2    2   -2    0    0    0    0    0    0    0    0    0
  985          27.61          -1.22    2    0    2    0    2    0    0    0    0    0    0    0    0    0
  986         -25.43           1.00    1    0    2   -2    2    0    0    0    0    0    0    0    0    0
  987         -26.01           0.07    2    0    0    0    0    0    0    0    0    0    0    0    0    0
  988         -23.02           0.06    0    0    2    0    0    0    0    0    0    0    0    0    0    0
  989          19.37          -0.01    0    0    2   -2    0    0    0    0    0    0    0    0    0    0
  990          14.05          -4.19    0    2    2   -2    2    0    0    0    0    0    0    0    0    0
  991          18.18          -0.01    1    0   -2    0   -1    0    0    0    0    0    0    0    0    0
  992         -14.86          -0.09    0    2    0    0    0    0    0    0    0    0    0    0    0    0
  993          13.49          -0.01    1    0    0   -2   -1    0    0    0    0    0    0    0    0    0
  994          12.44          -0.27    0    1    0    0    1    0    0    0    0    0    0    0    0    0
  995          11.46           0.03    1    0    0   -2    1    0    0    0    0    0    0    0    0    0
  996         -11.33          -0.06    0    1    0    0   -1    0    0    0    0    0    0    0    0    0
  997          -9.81           0.01    2    0   -2    0    0    0    0    0    0    0    0    0    0    0
  998          -9.08          -0.02    1    0   -2   -2   -1    0    0    0    0    0    0    0    0    0
  999           2.74          -4.56    0    0    1   -1    1    0    0   -1    0   -2    5    0    0    0
 1000           6.84          -0.04    1    0    2    2    2    0    0    0    0    0    0    0    0    0
 1001          -6.73           0.01    0    1    2    0    2    0    0    0    0    0    0    0    0    0
 1002           6.54           0.01    1    1    0   -2    0    0    0    0    0    0    0    0    0    0
 1003          -6.35          -0.01    0    1   -2    0   -2    0    0    0    0    0    0    0    0    0
 1004           5.90          -0.02    0    0    2    2    1    0    0    0    0    0    0    0    0    0
 1005          -5.85           0.02    1    0    0    2    0    0    0    0    0    0    0    0    0    0
 1006          -5.73           0.01    2    0    2   -2    2    0    0    0    0    0    0    0    0    0
 1007           5.60           0.00    0    0    0    2    1    0    0    0    0    0    0    0    0    0
 1008          -5.16           0.00    1    0    2   -2    1    0    0    0    0    0    0    0    0    0
 1009          -5.14           0.01    2    0    0   -2   -1    0    0    0    0    0    0    0    0    0
 1010           4.76          -0.02    2    0    2    0    1    0    0    0    0    0    0    0    0    0
 1011          -4.40           0.02    0    0    0    2   -1    0    0    0    0    0    0    0    0    0
 1012          -4.22           0.00    0    1   -2    2   -1    0    0    0    0    0    0    0    0    0
 1013          -4.20           0.01    1   -1    0    0    0    0    0    0    0    0    0    0    0    0
 1014           3.58           0.31    1    0    0   -1    0    0    0    0    0    0    0    0    0    0
 1015           3.87           0.01    0    1    0   -2    0    0    0    0    0    0    0    0    0    0
 1016           3.76           0.00    0    0    0    1    0    0    0    0    0    0    0    0    0    0
 1017          -3.62           0.00    2    0    0   -2    1    0    0    0    0    0    0    0    0    0
 1018          -3.61           0.00    1    0   -2    0    0    0    0    0    0    0    0    0    0    0
 1019          -1.28          -2.14    0    0    0    0    0    0    0    0    0    2   -5    0    0   -1
 1020          -3.18           0.00    0    1    2   -2    1    0    0    0    0    0    0    0    0    0
 1021           3.01           0.00    1    1    0    0    0    0    0    0    0    0    0    0    0    0
 1022          -2.97           0.01    1    0    2    0    0    0    0    0    0    0    0    0    0    0
 1023           2.91           0.00    1   -1    0   -1    0    0    0    0    0    0    0    0    0    0
 1024          -2.73           0.00    2    0   -2    0   -2    0    0    0    0    0    0    0    0    0
 1025           2.58          -0.01    3    0    2    0    2    0    0    0    0    0    0    0    0    0
 1026           2.56          -0.01    1   -1    2    0    2    0    0    0    0    0    0    0    0    0
 1027          -2.51          -0.01    1    1   -2   -2   -2    0    0    0    0    0    0    0    0    0
 1028          -2.35          -0.01    0    1   -2   -2   -2    0    0    0    0    0    0    0    0    0
 1029          -2.21           0.01    1    1    2    0    2    0    0    0    0    0    0    0    0    0
 1030          -2.04           0.01    2    0    0    0   -1    0    0    0    0    0    0    0    0    0
 1031          -1.94           0.00    2    0    0    0    1    0    0    0    0    0    0    0    0    0
 1032           0.41          -1.43    0    0    0    0    0    0    0    4   -8    3    0    0    0    0
 1033          -1.84           0.00    0    0    0    0    0    0    3   -5    0    0    0    0    0   -2
 1034          -1.77           0.01    1    0   -2    2   -1    0    0    0    0    0    0    0    0    0
 1035           0.00           1.77    0    1   -1    1   -1    0    0    0    0    0    0    0    0    0
 1036           1.76           0.00    1    0    0    0    2    0    0    0    0    0    0    0    0    0
 1037          -1.07          -0.53    0    0    1   -1    1    0   -8   12    0    0    0    0    0    0
 1038          -1.48           0.00    0    0    2    1    2    0    0    0    0    0    0    0    0    0
 1039          -1.40           0.01    3    0    0    0    0    0    0    0    0    0    0    0    0    0
 1040          -1.35          -0.01    1    0   -2   -4   -2    0    0    0    0    0    0    0    0    0
 1041          -1.32           0.00    0    0    0    0    0    0    1   -1    0    0    0    0    0    0
 1042          -1.28           0.00    0    0    0    0    0    0    0    8  -16    4    5    0    0    0
 1043           1.24           0.00    1    0    0    0   -2    0    0    0    0    0    0    0    0    0
 1044           1.23           0.00    2    0   -2   -2   -2    0    0    0    0    0    0    0    0    0
 1045           1.19           0.00    1    0    0   -4    0    0    0    0    0    0    0    0    0    0
 1046           1.18          -0.01    1    0    2    2    1    0    0    0    0    0    0    0    0    0
 1047           1.17           0.00    1   -1    0   -1   -1    0    0    0    0    0    0    0    0    0
 1048          -1.15           0.00    1    1    2   -2    2    0    0    0    0    0    0    0    0    0
 1049           1.14           0.00    2    0    0   -4    0    0    0    0    0    0    0    0    0    0
 1050          -1.14           0.00    0    2   -2    2   -1    0    0    0    0    0    0    0    0    0
 1051           1.09           0.03    0    0    0    0    0    0    0    1    0   -1    0    0    0    0
 1052          -1.08           0.00    2    0   -2   -4   -2    0    0    0    0    0    0    0    0    0
 1053           1.04           0.00    0    0    0    0    0    0    0    0    0    2    0    0    0    2
 1054           1.02           0.00    1    0   -4    0   -2    0    0    0    0    0    0    0    0    0
 1055           0.98          -0.01    2    0    2    2    2    0    0    0    0    0    0    0    0    0
 1056           0.91           0.02    1    0    0   -1   -1    0    0    0    0    0    0    0    0    0
 1057           0.00           0.93    1    0   -1    0   -1    0    0    0    0    0    0    0    0    0
 1058          -0.91           0.00    2    0    2   -2    1    0    0    0    0    0    0    0    0    0
 1059          -0.90           0.00    2    1    0   -2    0    0    0    0    0    0    0    0    0    0
 1060           0.86           0.00    1    0    0    2    1    0    0    0    0    0    0    0    0    0
 1061          -0.84           0.00    1   -1    0   -2    0    0    0    0    0    0    0    0    0    0
 1062          -0.83           0.00    3    0    2   -2    2    0    0    0    0    0    0    0    0    0
 1063          -0.82           0.00    0    0    4   -2    2    0    0    0    0    0    0    0    0    0
 1064           0.41           0.39    0    0    0    0    1    0    0   -1    2    0    0    0    0    0
 1065           0.40          -0.38    0    0    0    0    0    0    0    1   -2    0    0    0    0    0
 1066           0.78           0.00    0    1   -2    2    0    0    0    0    0    0    0    0    0    0
 1067           0.74           0.00    0    0    2   -2   -1    0    0    0    0    0    0    0    0    0
 1068          -0.73           0.00    0    1    2    0    1    0    0    0    0    0    0    0    0    0
 1069           0.68           0.00    1    0    2   -2    0    0    0    0    0    0    0    0    0    0
 1070           0.66           0.00    1    1    0   -2   -1    0    0    0    0    0    0    0    0    0
 1071          -0.64           0.00    2    0   -2    0    1    0    0    0    0    0    0    0    0    0
 1072          -0.63           0.00    0    1    0    0    2    0    0    0    0    0    0    0    0    0
 1073           0.63           0.00    0    0    2   -1    2    0    0    0    0    0    0    0    0    0
 1074           0.62           0.00    0    0    2    4    2    0    0    0    0    0    0    0    0    0
 1075           0.60           0.00    0    1    0    2    0    0    0    0    0    0    0    0    0    0
 1076          -0.59           0.00    0    0    2    0   -1    0    0    0    0    0    0    0    0    0
 1077          -0.59           0.00    0    1   -2    0   -1    0    0    0    0    0    0    0    0    0
 1078           0.59           0.00    0    1    2   -2    0    0    0    0    0    0    0    0    0    0
 1079           0.57           0.00    1    0   -2   -2    0    0    0    0    0    0    0    0    0    0
 1080           0.38          -0.19    0    0    0    0    0    0    8  -13    0    0    0    0    0   -1
 1081          -0.01          -0.55    0    0    0    0    0    0    2   -3    0    0    0    0    0    0
 1082           0.44          -0.11    0    0    0    0    0    0    0    0    0    2   -5    0    0    0
 1083           0.53           0.00    0    0    0    0    0    0    2   -2    0    0    0    0    0    0
 1084          -0.53           0.00    1   -1    0   -1   -2    0    0    0    0    0    0    0    0    0
 1085           0.52           0.00    1   -1    2    2    2    0    0    0    0    0    0    0    0    0
 1086          -0.52           0.00    2    0    0    2    0    0    0    0    0    0    0    0    0    0
 1087           0.53           0.00    0    1    0    0   -2    0    0    0    0    0    0    0    0    0
 1088           0.52           0.00    1    1    0   -2    1    0    0    0    0    0    0    0    0    0
 1089           0.51           0.00    1    0   -2    2    0    0    0    0    0    0    0    0    0    0
 1090           0.51           0.00    1   -1   -2   -2   -2    0    0    0    0    0    0    0    0    0
 1091          -0.21          -0.30    0    0    0    0    0    0    8  -13    0    0    0    0    0    0
 1092          -0.50           0.00    0    1    0    1    0    0    0    0    0    0    0    0    0    0
 1093          -0.11           0.37    0    0    0    0    0    0    0    2   -8    3    0    0    0   -2
 1094          -0.11           0.37    0    0    0    0    0    0    0    6   -8    3    0    0    0    2
 1095          -0.48           0.00    0    1    2    2    2    0    0    0    0    0    0    0    0    0
 1096          -0.46          -0.01    0    0    0    0    0    0    0    3    0   -1    0    0    0    2
 1097          -0.47           0.00    1   -1    0    0    1    0    0    0    0    0    0    0    0    0
 1098          -0.03           0.43    0    0    1   -1    1    0    0   -1    0    2   -5    0    0    0
 1099           0.45           0.00    3    0    2    0    1    0    0    0    0    0    0    0    0    0
 1100          -0.44           0.00    0    0    0    4    0    0    0    0    0    0    0    0    0    0
 1101          -0.44           0.00    1    0    0    2   -1    0    0    0    0    0    0    0    0    0
 1102          -0.44           0.00    1   -1    0    2    0    0    0    0    0    0    0    0    0    0
 1103           0.43           0.00    2   -1    2    0    2    0    0    0    0    0    0    0    0    0
 1104           0.44           0.00    0    0    0    0    0    0    4   -6    0    0    0    0    0   -2
 1105           0.42           0.00    0    0    0    2    2    0    0    0    0    0    0    0    0    0
 1106          -0.42           0.00    1    1   -2   -2   -1    0    0    0    0    0    0    0    0    0
 1107           0.41           0.00    1   -1   -2    0   -2    0    0    0    0    0    0    0    0    0
 1108          -0.41           0.00    0    0    0    0    0    0    2   -4    0    0    0    0    0   -2
 1109           0.02           0.39    0    0    2   -2    1    0   -5    6    0    0    0    0    0    0
 1110           0.40           0.00    1    0    2   -4    1    0    0    0    0    0    0    0    0    0
 1111          -0.40           0.00    0    1   -2   -2   -1    0    0    0    0    0    0    0    0    0
 1112          -0.39           0.00    2    0    0   -2    0    0    0   -2    0    2    0    0    0    0
 1113           0.39           0.00    0    3    2   -2    2    0    0    0    0    0    0    0    0    0
 1114           0.15          -0.24    0    0    0    0    0    0    0    1    0   -2    0    0    0    0
 1115          -0.37          -0.01    0    0    0    0    0    0    0    2    0   -2    0    0    0    0
 1116           0.37           0.00    1   -1    2    0    1    0    0    0    0    0    0    0    0    0
 1117          -0.37           0.00    0    0    2    2    0    0    0    0    0    0    0    0    0    0
 1118          -0.37           0.00    2    1    2    0    2    0    0    0    0    0    0    0    0    0
 1119          -0.31           0.06    2    0    0   -2    0    0    0   -2    0    3    0    0    0    0
 1120          -0.35           0.00    1    0    0   -2   -2    0    0    0    0    0    0    0    0    0
 1121           0.35           0.00    0    0    0    1    1    0    0    0    0    0    0    0    0    0
 1122          -0.07          -0.27    0    0    0    0    1    0    0   -4    8   -3    0    0    0    0
 1123          -0.33           0.01    0    0    0    0    0    0    2    0    0    0    0    0    0    2
 1124          -0.33           0.00    2   -1    0    0    0    0    0    0    0    0    0    0    0    0
 1125           0.07          -0.26    0    0    0    0    1    0    0    4   -8    3    0    0    0    0
 1126           0.33           0.00    0    0    0    0    0    0    0    2   -2    0    0    0    0    0
 1127           0.00          -0.32    1    0   -1    0   -2    0    0    0    0    0    0    0    0    0
 1128           0.32           0.00    1    1    0    0    1    0    0    0    0    0    0    0    0    0
 1129          -0.32           0.00    1    1    2    0    1    0    0    0    0    0    0    0    0    0
 1130           0.32           0.00    1    0   -2    2   -2    0    0    0    0    0    0    0    0    0
 1131          -0.24          -0.07    0    0    1   -1    1    0    0    0   -2    0    0    0    0    0
 1132           0.24           0.07    0    0    1   -1    0    0    0    0   -2    0    0    0    0    0
 1133           0.30           0.00    0    0    0    0    0    0    1    1    0    0    0    0    0    2
 1134           0.08          -0.22    0    0    0    0    0    0    0    0    0    1    0    0    0    0
 1135          -0.30           0.00    1    0    2    1    2    0    0    0    0    0    0    0    0    0
 1136          -0.30           0.00    2    0    2    0    0    0    0    0    0    0    0    0    0    0
 1137           0.30           0.00    0    1    0   -2    1    0    0    0    0    0    0    0    0    0
 1138           0.30           0.00    1    0    2   -1    2    0    0    0    0    0    0    0    0    0
 1139           0.00          -0.29    0    0    0    0    0    0    3   -4    0    0    0    0    0    0
 1140           0.00          -0.29    1    0   -1    0    0    0    0    0    0    0    0    0    0    0
 1141           0.20          -0.09    1    0    0    0    0    0  -18   16    0    0    0    0    0    0
 1142           0.29           0.00    1    0    0    1    0    0    0    0    0    0    0    0    0    0
 1143          -0.05          -0.24    0    0    0    0    0    0    0    0    0    2    0    0    0    1
 1144           0.29           0.00    0    0    0    1   -1    0    0    0    0    0    0    0    0    0
 1145          -0.27           0.00    1    0    0   -2    2    0    0    0    0    0    0    0    0    0
 1146          -0.19          -0.08    1    0    0    0    0    0  -10    3    0    0    0    0    0    0
 1147          -0.27           0.00    1   -1    0    0   -1    0    0    0    0    0    0    0    0    0
 1148           0.25           0.00    2    1    0    0    0    0    0    0    0    0    0    0    0    0
 1149           0.25           0.00    2    0    0   -2   -1    0    0   -2    0    2    0    0    0    0
 1150          -0.25           0.00    0    0    2    1    1    0    0    0    0    0    0    0    0    0
 1151           0.25           0.00    1    2    0   -2    0    0    0    0    0    0    0    0    0    0
 1152          -0.25           0.00    0    3    0    0    0    0    0    0    0    0    0    0    0    0
 1153          -0.01           0.23    0    0    0    0    0    0    5   -8    0    0    0    0    0   -2
 1154          -0.23           0.00    1    0   -2   -4   -1    0    0    0    0    0    0    0    0    0
 1155           0.23           0.00    0    0    0    0    0    0    0    1    0    1    0    0    0    2
 1156           0.23           0.00    4    0    2    0    2    0    0    0    0    0    0    0    0    0
 1157          -0.15          -0.07    0    0    1   -1    1    0    0   -1    0    0   -1    0    0    0
 1158          -0.23           0.00    1    0   -2    0    1    0    0    0    0    0    0    0    0    0
 1159          -0.22           0.00    2    1    2   -2    2    0    0    0    0    0    0    0    0    0
 1160           0.22           0.00    0    1    2    1    2    0    0    0    0    0    0    0    0    0
 1161          -0.22           0.00    1    1    2   -2    1    0    0    0    0    0    0    0    0    0
 1162          -0.22           0.00    1    0    4   -2    2    0    0    0    0    0    0    0    0    0
 1163           0.04          -0.17    0    0    1   -1    1    0    0   -1    0   -1    0    0    0    0
 1164          -0.01          -0.21    0    0    2   -2    0    0   -5    6    0    0    0    0    0    0
 1165           0.08          -0.14    0    0    0    0    0    0    0    2   -4    0    0    0    0    0
 1166          -0.01           0.19    0    0    0    0    0    0    0    0    0    2   -5    0    0    1
 1167           0.21           0.00    2    0   -2   -2   -1    0    0    0    0    0    0    0    0    0
 1168          -0.20           0.00    1    0   -2    1   -1    0    0    0    0    0    0    0    0    0
 1169          -0.20           0.00    2   -2    0   -2    0    0    0    0    0    0    0    0    0    0
 1170          -0.04          -0.16    0    0    0    0    0    0    8  -13    0    0    0    0    0   -2
 1171           0.19           0.00    0    2    0   -2    0    0    0    0    0    0    0    0    0    0
 1172           0.19           0.00    1    1    0    0   -1    0    0    0    0    0    0    0    0    0
 1173          -0.19           0.00    2    0   -2   -4   -1    0    0    0    0    0    0    0    0    0
 1174           0.18           0.00    0    0    0    0    0    0    5   -7    0    0    0    0    0   -2
 1175          -0.18           0.00    0    1    0    2    1    0    0    0    0    0    0    0    0    0
 1176           0.18           0.00    1    0   -4    0   -1    0    0    0    0    0    0    0    0    0
 1177           0.17           0.00    2    0    2    2    1    0    0    0    0    0    0    0    0    0
 1178          -0.12           0.06    1    0    2    0    2    0    0    1    0    0    0    0    0    0
 1179           0.13          -0.04    0    0    0    0    0    0    3   -5    0    0    0    0    0    0
 1180          -0.11           0.06    1    0   -2    0   -2    0    0    4   -8    3    0    0    0    0
 1181           0.17           0.00    0    0    2   -3    2    0    0    0    0    0    0    0    0    0
 1182          -0.17           0.00    0    0    4    0    2    0    0    0    0    0    0    0    0    0
 1183           0.16           0.00    0    0    0    0    0    0    0    4    0   -2    0    0    0    2
 1184          -0.17           0.00    1    0    0   -4   -1    0    0    0    0    0    0    0    0    0
 1185          -0.14           0.02    1    0    0   -1    1    0    0    0    0    0    0    0    0    0
 1186           0.14           0.03    0    0    0    0    0    0    0    2    0   -1    0    0    0    2
 1187           0.00           0.15    0    0    0    0    0    0    2   -1    0    0    0    0    0    2
 1188          -0.15           0.00    1    1   -2   -4   -2    0    0    0    0    0    0    0    0    0
 1189          -0.14           0.01    0    0    0    0    0    0    0    2    0    1    0    0    0    2
 1190           0.16           0.00    2    0    0   -2   -2    0    0    0    0    0    0    0    0    0
 1191          -0.06           0.10    0    0    0    0    0    0    8  -11    0    0    0    0    0   -2
 1192           0.05           0.10    0    0    0    0    0    0    0    8  -16    4    5    0    0   -2
 1193           0.02           0.13    0    0    1   -1    1    0    0   -1    0    2    0    0    0    0
 1194          -0.11           0.04    0    0    0    0    0    0    0    8  -16    4    5    0    0    2
 1195          -0.12          -0.02    0    0    1   -1    1    0   -5    7    0    0    0    0    0    0
 1196          -0.05          -0.10    0    0    0    0    0    0    0    0    0    0    2    0    0    1
 1197           0.14           0.00    1    0    2    4    2    0    0    0    0    0    0    0    0    0
 1198          -0.09           0.05    1    0    0   -2    0    0   19  -21    3    0    0    0    0    0
 1199           0.00           0.14    0    0    1    0    1    0    0    0    0    0    0    0    0    0
 1200           0.14           0.00    3    0    0   -4    0    0    0    0    0    0    0    0    0    0
 1201          -0.14           0.00    1    1   -2    0   -2    0    0    0    0    0    0    0    0    0
 1202           0.04           0.10    0    0    1   -1    1    0    0   -1    0    0    2    0    0    0
 1203          -0.06           0.08    0    0    0    0    0    0    0    3    0   -2    0    0    0    2
 1204           0.05           0.09    0    0    0    0    0    0    8  -15    0    0    0    0    0   -2
 1205          -0.14           0.00    0    1    0   -2   -1    0    0    0    0    0    0    0    0    0
 1206           0.08           0.06    0    0    0    0    0    0    0    1    2    0    0    0    0    2
 1207           0.14           0.00    0    0    0    4    1    0    0    0    0    0    0    0    0    0
 1208           0.14           0.00    0    0    2   -4    1    0    0    0    0    0    0    0    0    0
 1209           0.13           0.00    1    1    0   -4    0    0    0    0    0    0    0    0    0    0
 1210          -0.07           0.06    0    0    0    0    0    0    0    3   -2    0    0    0    0    2
 1211           0.11          -0.02    0    0    0    0    0    0    0    0    0    3    0    0    0    2
 1212          -0.13           0.00    3    0    2   -2    1    0    0    0    0    0    0    0    0    0
 1213          -0.13           0.00    0    0    0    0    0    0    0    4   -2    0    0    0    0    2
 1214          -0.13           0.00    1    1    2    2    2    0    0    0    0    0    0    0    0    0
 1215          -0.13           0.00    0    0    4   -2    1    0    0    0    0    0    0    0    0    0
 1216          -0.12           0.00    2    0    0   -2    0    0   -3    3    0    0    0    0    0    0
 1217           0.12           0.00    3    0    2    2    2    0    0    0    0    0    0    0    0    0
 1218           0.12           0.00    0    0    0    0    0    0    0    0    0    0    2    0    0    2
 1219          -0.12           0.00    2    1    0   -2   -1    0    0    0    0    0    0    0    0    0
 1220          -0.02          -0.09    0    0    0    0    0    0    4   -6    0    0    0    0    0   -1
 1221           0.02          -0.09    0    0    0    0    0    0    1   -1    0    0    0    0    0   -1
 1222           0.00          -0.12    1    0    0   -1    0    0   -3    4    0    0    0    0    0    0
 1223          -0.11           0.00    0    2   -2   -2   -2    0    0    0    0    0    0    0    0    0
 1224           0.11           0.00    2    0    0   -4   -1    0    0    0    0    0    0    0    0    0
 1225           0.07          -0.04    0    0    0    0    0    0    0    3   -4    0    0    0    0    0
 1226           0.11           0.00    0    0    2    4    1    0    0    0    0    0    0    0    0    0
 1227           0.11           0.00    0    0    0    2   -2    0    0    0    0    0    0    0    0    0
 1228          -0.11           0.00    3    0    0    0   -1    0    0    0    0    0    0    0    0    0
 1229           0.10           0.00    0    0    0    0    0    0    0    1    0   -3    0    0    0   -2
 1230          -0.10           0.00    0    0    2   -2    1    0   -3    3    0    0    0    0    0    0
 1231           0.10           0.00    0    0    0    0    0    0    6   -8    0    0    0    0    0   -2
 1232           0.10           0.00    2    1    0   -4    0    0    0    0    0    0    0    0    0    0
 1233           0.10           0.00    0    0    1   -1    1    0    0    3   -8    3    0    0    0    0
 1234           0.00           0.10    0    0    0    0    0    0    3   -2    0    0    0    0    0    2
 1235           0.00           0.10    0    0    0    0    0    0    2   -5    0    0    0    0    0   -2
 1236          -0.10           0.00    4    0    2   -2    2    0    0    0    0    0    0    0    0    0
 1237           0.10           0.00    2    0    0    2    1    0    0    0    0    0    0    0    0    0
 1238          -0.10           0.00    1   -1    0   -2   -1    0    0    0    0    0    0    0    0    0
 1239           0.10           0.00    0    0    0    0    0    0    1   -3    0    0    0    0    0   -2
]'

const coefs_iau2006_CIP_y2 = Float64[
 1240         120.56       -2301.27    0    0    0    0    1    0    0    0    0    0    0    0    0    0
 1241          -1.03        -143.27    0    0    2   -2    2    0    0    0    0    0    0    0    0    0
 1242          -0.28         -24.46    0    0    2    0    2    0    0    0    0    0    0    0    0    0
 1243           0.24          22.41    0    0    0    0    2    0    0    0    0    0    0    0    0    0
 1244          -1.19          -5.61    0    1    2   -2    2    0    0    0    0    0    0    0    0    0
 1245           3.57          -1.83    0    1    0    0    0    0    0    0    0    0    0    0    0    0
 1246           0.24          -5.02    0    0    2    0    1    0    0    0    0    0    0    0    0    0
 1247          -0.04          -3.23    1    0    2    0    2    0    0    0    0    0    0    0    0    0
 1248          -0.48           2.40    0    1   -2    2   -2    0    0    0    0    0    0    0    0    0
 1249          -0.10           1.73    0    0    2   -2    1    0    0    0    0    0    0    0    0    0
 1250          -0.02           1.33    1    0   -2    0   -2    0    0    0    0    0    0    0    0    0
 1251          -0.04           0.83    1    0    0    0    1    0    0    0    0    0    0    0    0    0
 1252          -0.05          -0.79    1    0    0    0   -1    0    0    0    0    0    0    0    0    0
 1253           0.03          -0.66    1    0    2    0    1    0    0    0    0    0    0    0    0    0
 1254           0.00          -0.64    1    0   -2   -2   -2    0    0    0    0    0    0    0    0    0
 1255           0.04           0.61    2    0   -2    0   -1    0    0    0    0    0    0    0    0    0
 1256          -0.01          -0.41    0    0    2    2    2    0    0    0    0    0    0    0    0    0
 1257          -0.01           0.35    0    2   -2    2   -2    0    0    0    0    0    0    0    0    0
 1258          -0.01          -0.33    2    0    2    0    2    0    0    0    0    0    0    0    0    0
 1259           0.01           0.31    1    0    2   -2    2    0    0    0    0    0    0    0    0    0
 1260           0.01           0.27    1    0   -2    0   -1    0    0    0    0    0    0    0    0    0
 1261          -0.07          -0.17    0    2    2   -2    2    0    0    0    0    0    0    0    0    0
 1262           0.07           0.17    1    0    0    0    0    0    0    0    0    0    0    0    0    0
 1263           0.02          -0.21    0    1    0    0    1    0    0    0    0    0    0    0    0    0
 1264           0.01           0.20    1    0    0   -2   -1    0    0    0    0    0    0    0    0    0
 1265           0.01          -0.17    1    0    0   -2    1    0    0    0    0    0    0    0    0    0
 1266           0.01          -0.16    0    1    0    0   -1    0    0    0    0    0    0    0    0    0
 1267           0.00          -0.13    1    0   -2   -2   -1    0    0    0    0    0    0    0    0    0
 1268          -0.07          -0.04    0    0    1   -1    1    0    0   -1    0   -2    5    0    0    0
 1269           0.02           0.08    0    1    2    0    2    0    0    0    0    0    0    0    0    0
]'

const coefs_iau2006_CIP_y3 = Float64[
 1270         -15.22          -1.61    0    0    0    0    1    0    0    0    0    0    0    0    0    0
 1271          -1.16          -0.01    0    0    2   -2    2    0    0    0    0    0    0    0    0    0
 1272          -0.20           0.00    0    0    2    0    2    0    0    0    0    0    0    0    0    0
 1273           0.18           0.00    0    0    0    0    2    0    0    0    0    0    0    0    0    0
 1274           0.13           0.00    0    1    0    0    0    0    0    0    0    0    0    0    0    0
]'

const coefs_iau2006_CIP_y4 = Float64[
 1275          -0.02           0.11    0    0    0    0    1    0    0    0    0    0    0    0    0    0
]'
