# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
#
# Description
# ==============================================================================
#
#   Constants to compute the Equation of Origins according to the IAU-2006
#   theory.
#
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
#
# Obtained from the files:
#
#   ftp://tai.bipm.org/iers/conv2010/chapter5/tab5.2e.txt
#
# accessed on 18 Mar 2021.
#
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #

const coefs_iau2006_EO_0 = Float64[
    1        2640.96         -0.39    0    0    0    0    1    0    0    0    0    0    0    0    0    0
    2          63.52         -0.02    0    0    0    0    2    0    0    0    0    0    0    0    0    0
    3          11.75          0.01    0    0    2   -2    3    0    0    0    0    0    0    0    0    0
    4          11.21          0.01    0    0    2   -2    1    0    0    0    0    0    0    0    0    0
    5          -4.55          0.00    0    0    2   -2    2    0    0    0    0    0    0    0    0    0
    6           2.02          0.00    0    0    2    0    3    0    0    0    0    0    0    0    0    0
    7           1.98          0.00    0    0    2    0    1    0    0    0    0    0    0    0    0    0
    8          -1.72          0.00    0    0    0    0    3    0    0    0    0    0    0    0    0    0
    9          -1.41         -0.01    0    1    0    0    1    0    0    0    0    0    0    0    0    0
   10          -1.26         -0.01    0    1    0    0   -1    0    0    0    0    0    0    0    0    0
   11          -0.63          0.00    1    0    0    0   -1    0    0    0    0    0    0    0    0    0
   12          -0.63          0.00    1    0    0    0    1    0    0    0    0    0    0    0    0    0
   13           0.46          0.00    0    1    2   -2    3    0    0    0    0    0    0    0    0    0
   14           0.45          0.00    0    1    2   -2    1    0    0    0    0    0    0    0    0    0
   15           0.36          0.00    0    0    4   -4    4    0    0    0    0    0    0    0	  0    0
   16          -0.24         -0.12    0    0    1   -1    1    0   -8   12    0    0    0    0    0    0
   17           0.32          0.00    0    0    2    0    0    0    0    0    0    0    0    0    0    0
   18           0.28          0.00    0    0    2    0    2    0    0    0    0    0    0    0    0    0
   19           0.27          0.00    1    0    2    0    3    0    0    0    0    0    0    0    0    0
   20           0.26          0.00    1    0    2    0    1    0    0    0    0    0    0    0    0    0
   21          -0.21          0.00    0    0    2   -2    0    0    0    0    0    0    0    0    0    0
   22           0.19          0.00    0    1   -2    2   -3    0    0    0    0    0    0    0    0    0
   23           0.18          0.00    0    1   -2    2   -1    0    0    0    0    0    0    0    0    0
   24          -0.10          0.05    0    0    0    0    0    0    8  -13    0    0    0    0    0   -1
   25           0.15          0.00    0    0    0    2    0    0    0    0    0    0    0    0    0    0
   26          -0.14          0.00    2    0   -2    0   -1    0    0    0    0    0    0    0    0    0
   27           0.14          0.00    1    0    0   -2    1    0    0    0    0    0    0    0    0    0
   28          -0.14          0.00    0    1    2   -2    2    0    0    0    0    0    0    0    0    0
   29           0.14          0.00    1    0    0   -2   -1    0    0    0    0    0    0    0    0    0
   30           0.13          0.00    0    0    4   -2    4    0    0    0    0    0    0    0    0    0
   31          -0.11          0.00    0    0    2   -2    4    0    0    0    0    0    0    0    0    0
   32           0.11          0.00    1    0   -2    0   -3    0    0    0    0    0    0    0    0    0
   33           0.11          0.00    1    0   -2    0   -1    0    0    0    0    0    0    0    0    0
]'

const coefs_iau2006_EO_1 = Float64[
  34          -0.87          0.00    0    0    0    0    1    0    0    0    0    0    0    0    0    0
]'
