# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
#
# Description
# ==============================================================================
#
#   Constants to compute the nutation corrections in the longitude (ΔΨ_2000) and
#   in the obliquity (Δϵ_2000).
#
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
#
# Obtained from the files:
#
#   ftp://tai.bipm.org/iers/conv2010/chapter5/tab5.3a.txt
#   ftp://tai.bipm.org/iers/conv2010/chapter5/tab5.3b.txt
#
# accessed on 18 Mar 2021.
#
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #

const coefs_iau2006_nut_lon0 = Float64[
    1   -17206424.18        3338.60    0    0    0    0    1    0    0    0    0    0    0    0    0    0
    2    -1317091.22       -1369.60    0    0    2   -2    2    0    0    0    0    0    0    0    0    0
    3     -227641.81         279.60    0    0    2    0    2    0    0    0    0    0    0    0    0    0
    4      207455.40         -69.80    0    0    0    0    2    0    0    0    0    0    0    0    0    0
    5      147587.70        1181.70    0    1    0    0    0    0    0    0    0    0    0    0    0    0
    6       71115.90         -87.20    1    0    0    0    0    0    0    0    0    0    0    0    0    0
    7      -51682.10         -52.40    0    1    2   -2    2    0    0    0    0    0    0    0    0    0
    8      -38730.20          38.00    0    0    2    0    1    0    0    0    0    0    0    0    0    0
    9      -30146.40          81.60    1    0    2    0    2    0    0    0    0    0    0    0    0    0
   10      -21582.90          11.10    0    1   -2    2   -2    0    0    0    0    0    0    0    0    0
   11      -15699.80         -16.80    1    0    0   -2    0    0    0    0    0    0    0    0    0    0
   12       12822.70          18.10    0    0    2   -2    1    0    0    0    0    0    0    0    0    0
   13      -12345.70           1.90    1    0   -2    0   -2    0    0    0    0    0    0    0    0    0
   14        6337.90         -15.00    0    0    0    2    0    0    0    0    0    0    0    0    0    0
   15        6311.00           2.70    1    0    0    0    1    0    0    0    0    0    0    0    0    0
   16        5964.50          14.90    1    0   -2   -2   -2    0    0    0    0    0    0    0    0    0
   17        5797.60         -18.90    1    0    0    0   -1    0    0    0    0    0    0    0    0    0
   18       -5161.30          12.90    1    0    2    0    1    0    0    0    0    0    0    0    0    0
   19        4772.20          -1.80    2    0    0   -2    0    0    0    0    0    0    0    0    0    0
   20       -4589.30           3.10    2    0   -2    0   -1    0    0    0    0    0    0    0    0    0
   21       -3856.60          15.80    0    0    2    2    2    0    0    0    0    0    0    0    0    0
   22       -3248.10           0.00    0    2   -2    2   -2    0    0    0    0    0    0    0    0    0
   23       -3104.60          13.10    2    0    2    0    2    0    0    0    0    0    0    0    0    0
   24        2924.30          -7.40    2    0    0    0    0    0    0    0    0    0    0    0    0    0
   25        2859.30          -0.10    1    0    2   -2    2    0    0    0    0    0    0    0    0    0
   26        2588.70          -6.60    0    0    2    0    0    0    0    0    0    0    0    0    0    0
   27       -2178.30           1.30    0    0    2   -2    0    0    0    0    0    0    0    0    0    0
   28       -2044.10           1.00    1    0   -2    0   -1    0    0    0    0    0    0    0    0    0
   29        1670.70          -1.00    0    2    0    0    0    0    0    0    0    0    0    0    0    0
   30       -1579.40          -1.60    0    2    2   -2    2    0    0    0    0    0    0    0    0    0
   31       -1516.40           1.10    1    0    0   -2   -1    0    0    0    0    0    0    0    0    0
   32       -1405.30           7.90    0    1    0    0    1    0    0    0    0    0    0    0    0    0
   33       -1287.30          -3.70    1    0    0   -2    1    0    0    0    0    0    0    0    0    0
   34        1265.40           6.30    0    1    0    0   -1    0    0    0    0    0    0    0    0    0
   35        1102.40          -1.40    2    0   -2    0    0    0    0    0    0    0    0    0    0    0
   36        1020.40           2.50    1    0   -2   -2   -1    0    0    0    0    0    0    0    0    0
   37        -308.40         512.30    0    0    1   -1    1    0    0   -1    0   -2    5    0    0    0
   38        -768.70           4.40    1    0    2    2    2    0    0    0    0    0    0    0    0    0
   39         756.60          -1.10    0    1    2    0    2    0    0    0    0    0    0    0    0    0
   40        -735.00          -0.80    1    1    0   -2    0    0    0    0    0    0    0    0    0    0
   41         714.10           0.80    0    1   -2    0   -2    0    0    0    0    0    0    0    0    0
   42        -663.70           2.50    0    0    2    2    1    0    0    0    0    0    0    0    0    0
   43         657.50          -2.40    1    0    0    2    0    0    0    0    0    0    0    0    0    0
   44         644.30          -0.70    2    0    2   -2    2    0    0    0    0    0    0    0    0    0
   45        -630.20           0.20    0    0    0    2    1    0    0    0    0    0    0    0    0    0
   46         580.00           0.20    1    0    2   -2    1    0    0    0    0    0    0    0    0    0
   47         577.40          -1.50    2    0    0   -2   -1    0    0    0    0    0    0    0    0    0
   48        -535.00           2.10    2    0    2    0    1    0    0    0    0    0    0    0    0    0
   49         494.00          -2.10    0    0    0    2   -1    0    0    0    0    0    0    0    0    0
   50         475.20          -0.30    0    1   -2    2   -1    0    0    0    0    0    0    0    0    0
   51         472.50          -0.60    1   -1    0    0    0    0    0    0    0    0    0    0    0    0
   52        -402.60         -35.30    1    0    0   -1    0    0    0    0    0    0    0    0    0    0
   53        -434.80          -1.00    0    1    0   -2    0    0    0    0    0    0    0    0    0    0
   54        -423.00           0.50    0    0    0    1    0    0    0    0    0    0    0    0    0    0
   55         406.50           0.60    2    0    0   -2    1    0    0    0    0    0    0    0    0    0
   56         405.60           0.50    1    0   -2    0    0    0    0    0    0    0    0    0    0    0
   57         144.40         240.90    0    0    0    0    0    0    0    0    0    2   -5    0    0   -1
   58         357.90           0.50    0    1    2   -2    1    0    0    0    0    0    0    0    0    0
   59        -338.90           0.50    1    1    0    0    0    0    0    0    0    0    0    0    0    0
   60         333.90          -1.30    1    0    2    0    0    0    0    0    0    0    0    0    0    0
   61        -327.60           0.10    1   -1    0   -1    0    0    0    0    0    0    0    0    0    0
   62         307.10          -0.20    2    0   -2    0   -2    0    0    0    0    0    0    0    0    0
   63        -290.10           1.50    3    0    2    0    2    0    0    0    0    0    0    0    0    0
   64        -287.80           0.80    1   -1    2    0    2    0    0    0    0    0    0    0    0    0
   65         281.90           0.70    1    1   -2   -2   -2    0    0    0    0    0    0    0    0    0
   66         264.70           1.10    0    1   -2   -2   -2    0    0    0    0    0    0    0    0    0
   67         248.10          -0.70    1    1    2    0    2    0    0    0    0    0    0    0    0    0
   68         229.40          -1.00    2    0    0    0   -1    0    0    0    0    0    0    0    0    0
   69         217.90          -0.20    2    0    0    0    1    0    0    0    0    0    0    0    0    0
   70         -46.20         160.40    0    0    0    0    0    0    0    4   -8    3    0    0    0    0
   71         206.50           0.00    0    0    0    0    0    0    3   -5    0    0    0    0    0   -2
   72         198.70          -0.60    1    0   -2    2   -1    0    0    0    0    0    0    0    0    0
   73           0.00        -198.80    0    1   -1    1   -1    0    0    0    0    0    0    0    0    0
   74        -198.10           0.00    1    0    0    0    2    0    0    0    0    0    0    0    0    0
   75         120.00          59.80    0    0    1   -1    1    0   -8   12    0    0    0    0    0    0
   76         166.00          -0.50    0    0    2    1    2    0    0    0    0    0    0    0    0    0
   77         157.50          -0.60    3    0    0    0    0    0    0    0    0    0    0    0    0    0
   78         152.10           0.90    1    0   -2   -4   -2    0    0    0    0    0    0    0    0    0
   79         148.50           0.00    0    0    0    0    0    0    1   -1    0    0    0    0    0    0
   80         144.00           0.00    0    0    0    0    0    0    0    8  -16    4    5    0    0    0
   81        -140.50           0.40    1    0    0    0   -2    0    0    0    0    0    0    0    0    0
   82        -137.80          -0.20    2    0   -2   -2   -2    0    0    0    0    0    0    0    0    0
   83        -133.80          -0.50    1    0    0   -4    0    0    0    0    0    0    0    0    0    0
   84        -133.10           0.80    1    0    2    2    1    0    0    0    0    0    0    0    0    0
   85        -131.40           0.00    1   -1    0   -1   -1    0    0    0    0    0    0    0    0    0
   86         129.00           0.00    1    1    2   -2    2    0    0    0    0    0    0    0    0    0
   87        -128.20          -0.30    2    0    0   -4    0    0    0    0    0    0    0    0    0    0
   88         128.30           0.00    0    2   -2    2   -1    0    0    0    0    0    0    0    0    0
   89        -122.30          -2.90    0    0    0    0    0    0    0    1    0   -1    0    0    0    0
   90         124.80           0.00    0    0    2   -2    3    0    0    0    0    0    0    0    0    0
   91         121.40           0.50    2    0   -2   -4   -2    0    0    0    0    0    0    0    0    0
   92        -116.60           0.00    0    0    0    0    0    0    0    0    0    2    0    0    0    2
   93        -114.60          -0.30    1    0   -4    0   -2    0    0    0    0    0    0    0    0    0
   94        -110.00           0.90    2    0    2    2    2    0    0    0    0    0    0    0    0    0
   95        -102.00          -2.50    1    0    0   -1   -1    0    0    0    0    0    0    0    0    0
   96           0.00        -104.40    1    0   -1    0   -1    0    0    0    0    0    0    0    0    0
   97         101.90          -0.10    2    0    2   -2    1    0    0    0    0    0    0    0    0    0
   98         101.40          -0.10    2    1    0   -2    0    0    0    0    0    0    0    0    0    0
   99         -97.00           0.20    1    0    0    2    1    0    0    0    0    0    0    0    0    0
  100          94.90           0.10    1   -1    0   -2    0    0    0    0    0    0    0    0    0    0
  101          93.40          -0.30    3    0    2   -2    2    0    0    0    0    0    0    0    0    0
  102          92.20          -0.10    0    0    4   -2    2    0    0    0    0    0    0    0    0    0
  103         -46.00         -43.50    0    0    0    0    1    0    0   -1    2    0    0    0    0    0
  104         -44.90          43.00    0    0    0    0    0    0    0    1   -2    0    0    0    0    0
  105         -87.50           0.10    0    1   -2    2    0    0    0    0    0    0    0    0    0    0
  106         -83.40           0.20    0    0    2   -2   -1    0    0    0    0    0    0    0    0    0
  107          81.50          -0.10    0    1    2    0    1    0    0    0    0    0    0    0    0    0
  108         -76.60           0.10    1    0    2   -2    0    0    0    0    0    0    0    0    0    0
  109         -74.20           0.10    1    1    0   -2   -1    0    0    0    0    0    0    0    0    0
  110          71.50          -0.40    0    1    0    0    2    0    0    0    0    0    0    0    0    0
  111          71.60          -0.20    2    0   -2    0    1    0    0    0    0    0    0    0    0    0
  112         -70.40           0.00    0    0    2   -1    2    0    0    0    0    0    0    0    0    0
  113         -69.40           0.50    0    0    2    4    2    0    0    0    0    0    0    0    0    0
  114         -67.30           0.20    0    1    0    2    0    0    0    0    0    0    0    0    0    0
  115          66.60          -0.30    0    0    2    0   -1    0    0    0    0    0    0    0    0    0
  116          66.70           0.10    0    1   -2    0   -1    0    0    0    0    0    0    0    0    0
  117         -65.80           0.00    0    1    2   -2    0    0    0    0    0    0    0    0    0    0
  118         -63.90          -0.20    1    0   -2   -2    0    0    0    0    0    0    0    0    0    0
  119         -42.50          21.20    0    0    0    0    0    0    8  -13    0    0    0    0    0   -1
  120           0.80          61.40    0    0    0    0    0    0    2   -3    0    0    0    0    0    0
  121         -49.10          12.80    0    0    0    0    0    0    0    0    0    2   -5    0    0    0
  122         -59.80           0.00    0    0    0    0    0    0    2   -2    0    0    0    0    0    0
  123          59.50           0.00    1   -1    0   -1   -2    0    0    0    0    0    0    0    0    0
  124         -59.00           0.40    1   -1    2    2    2    0    0    0    0    0    0    0    0    0
  125         -59.10           0.00    0    1    0    0   -2    0    0    0    0    0    0    0    0    0
  126          58.80          -0.30    2    0    0    2    0    0    0    0    0    0    0    0    0    0
  127         -58.50          -0.20    1    1    0   -2    1    0    0    0    0    0    0    0    0    0
  128         -57.80           0.10    1    0   -2    2    0    0    0    0    0    0    0    0    0    0
  129         -57.00          -0.20    1   -1   -2   -2   -2    0    0    0    0    0    0    0    0    0
  130          23.50          33.40    0    0    0    0    0    0    8  -13    0    0    0    0    0    0
  131          56.50          -0.10    0    1    0    1    0    0    0    0    0    0    0    0    0    0
  132          12.30         -41.60    0    0    0    0    0    0    0    2   -8    3    0    0    0   -2
  133          12.30         -41.50    0    0    0    0    0    0    0    6   -8    3    0    0    0    2
  134          53.50          -0.20    0    1    2    2    2    0    0    0    0    0    0    0    0    0
  135          51.70           1.60    0    0    0    0    0    0    0    3    0   -1    0    0    0    2
  136          52.80           0.00    1   -1    0    0    1    0    0    0    0    0    0    0    0    0
  137           3.10         -48.10    0    0    1   -1    1    0    0   -1    0    2   -5    0    0    0
  138         -50.20           0.30    3    0    2    0    1    0    0    0    0    0    0    0    0    0
  139          49.40          -0.20    0    0    0    4    0    0    0    0    0    0    0    0    0    0
  140          49.20          -0.30    1    0    0    2   -1    0    0    0    0    0    0    0    0    0
  141          49.30          -0.20    1   -1    0    2    0    0    0    0    0    0    0    0    0    0
  142         -48.80           0.20    2   -1    2    0    2    0    0    0    0    0    0    0    0    0
  143         -49.00           0.00    0    0    0    0    0    0    4   -6    0    0    0    0    0   -2
  144          46.70           0.10    1    1   -2   -2   -1    0    0    0    0    0    0    0    0    0
  145         -46.80           0.00    0    0    0    2    2    0    0    0    0    0    0    0    0    0
  146         -46.30           0.00    1   -1   -2    0   -2    0    0    0    0    0    0    0    0    0
  147          45.80           0.00    0    0    0    0    0    0    2   -4    0    0    0    0    0   -2
  148         -45.30          -0.10    1    0    2   -4    1    0    0    0    0    0    0    0    0    0
  149          -1.80         -43.60    0    0    2   -2    1    0   -5    6    0    0    0    0    0    0
  150          44.60           0.20    0    1   -2   -2   -1    0    0    0    0    0    0    0    0    0
  151          43.90           0.00    2    0    0   -2    0    0    0   -2    0    2    0    0    0    0
  152         -43.80           0.00    0    3    2   -2    2    0    0    0    0    0    0    0    0    0
  153         -16.60          26.90    0    0    0    0    0    0    0    1    0   -2    0    0    0    0
  154          41.30           1.30    0    0    0    0    0    0    0    2    0   -2    0    0    0    0
  155         -42.10           0.10    1   -1    2    0    1    0    0    0    0    0    0    0    0    0
  156          41.60          -0.20    0    0    2    2    0    0    0    0    0    0    0    0    0    0
  157          41.20          -0.20    2    1    2    0    2    0    0    0    0    0    0    0    0    0
  158          34.90          -6.20    2    0    0   -2    0    0    0   -2    0    3    0    0    0    0
  159          39.60           0.00    1    0    0   -2   -2    0    0    0    0    0    0    0    0    0
  160         -39.00           0.00    0    0    0    1    1    0    0    0    0    0    0    0    0    0
  161           8.40          29.80    0    0    0    0    1    0    0   -4    8   -3    0    0    0    0
  162          37.00          -0.80    0    0    0    0    0    0    2    0    0    0    0    0    0    2
  163          37.50          -0.10    2   -1    0    0    0    0    0    0    0    0    0    0    0    0
  164          -8.20          29.20    0    0    0    0    1    0    0    4   -8    3    0    0    0    0
  165         -36.80           0.00    0    0    0    0    0    0    0    2   -2    0    0    0    0    0
  166           0.00          36.40    1    0   -1    0   -2    0    0    0    0    0    0    0    0    0
  167          36.00          -0.10    1    1    2    0    1    0    0    0    0    0    0    0    0    0
  168         -36.10           0.00    1    1    0    0    1    0    0    0    0    0    0    0    0    0
  169         -35.70           0.10    1    0   -2    2   -2    0    0    0    0    0    0    0    0    0
  170          27.30           8.00    0    0    1   -1    1    0    0    0   -2    0    0    0    0    0
  171         -26.60          -7.80    0    0    1   -1    0    0    0    0   -2    0    0    0    0    0
  172         -33.90           0.00    0    0    0    0    0    0    1    1    0    0    0    0    0    2
  173          -9.10          24.80    0    0    0    0    0    0    0    0    0    1    0    0    0    0
  174          33.70          -0.10    1    0    2    1    2    0    0    0    0    0    0    0    0    0
  175          33.50          -0.20    2    0    2    0    0    0    0    0    0    0    0    0    0    0
  176         -33.50          -0.10    0    1    0   -2    1    0    0    0    0    0    0    0    0    0
  177         -33.40           0.00    1    0    2   -1    2    0    0    0    0    0    0    0    0    0
  178          -0.50          32.80    0    0    0    0    0    0    3   -4    0    0    0    0    0    0
  179           0.00          33.00    1    0   -1    0    0    0    0    0    0    0    0    0    0    0
  180         -22.60          10.10    1    0    0    0    0    0  -18   16    0    0    0    0    0    0
  181         -32.50           0.10    1    0    0    1    0    0    0    0    0    0    0    0    0    0
  182           5.10          27.20    0    0    0    0    0    0    0    0    0    2    0    0    0    1
  183         -32.10           0.10    0    0    0    1   -1    0    0    0    0    0    0    0    0    0
  184          30.90           0.10    1    0    0   -2    2    0    0    0    0    0    0    0    0    0
  185          21.90           8.90    1    0    0    0    0    0  -10    3    0    0    0    0    0    0
  186          30.10          -0.10    1   -1    0    0   -1    0    0    0    0    0    0    0    0    0
  187         -28.60           0.10    2    1    0    0    0    0    0    0    0    0    0    0    0    0
  188         -28.40           0.00    2    0    0   -2   -1    0    0   -2    0    2    0    0    0    0
  189          28.00          -0.10    0    0    2    1    1    0    0    0    0    0    0    0    0    0
  190         -27.60           0.00    1    2    0   -2    0    0    0    0    0    0    0    0    0    0
  191          27.60           0.00    0    3    0    0    0    0    0    0    0    0    0    0    0    0
  192           1.10         -26.10    0    0    0    0    0    0    5   -8    0    0    0    0    0   -2
  193          26.30           0.20    1    0   -2   -4   -1    0    0    0    0    0    0    0    0    0
  194         -26.20           0.00    0    0    0    0    0    0    0    1    0    1    0    0    0    2
  195         -25.90           0.20    4    0    2    0    2    0    0    0    0    0    0    0    0    0
  196          17.40           8.40    0    0    1   -1    1    0    0   -1    0    0   -1    0    0    0
  197          25.30           0.10    1    0   -2    0    1    0    0    0    0    0    0    0    0    0
  198          25.20           0.00    2    1    2   -2    2    0    0    0    0    0    0    0    0    0
  199         -24.50           0.10    0    1    2    1    2    0    0    0    0    0    0    0    0    0
  200          24.50           0.00    1    1    2   -2    1    0    0    0    0    0    0    0    0    0
  201          24.30          -0.10    1    0    4   -2    2    0    0    0    0    0    0    0    0    0
  202          -5.00          19.40    0    0    1   -1    1    0    0   -1    0   -1    0    0    0    0
  203           1.00          23.30    0    0    2   -2    0    0   -5    6    0    0    0    0    0    0
  204          -8.60          15.30    0    0    0    0    0    0    0    2   -4    0    0    0    0    0
  205           1.40         -21.80    0    0    0    0    0    0    0    0    0    2   -5    0    0    1
  206         -23.10           0.00    2    0   -2   -2   -1    0    0    0    0    0    0    0    0    0
  207          22.90           0.00    1    0   -2    1   -1    0    0    0    0    0    0    0    0    0
  208          22.80           0.00    2   -2    0   -2    0    0    0    0    0    0    0    0    0    0
  209         -21.90           0.00    0    0    0    0    3    0    0    0    0    0    0    0    0    0
  210           4.10          17.50    0    0    0    0    0    0    8  -13    0    0    0    0    0   -2
  211         -21.30           0.00    0    2    0   -2    0    0    0    0    0    0    0    0    0    0
  212          20.80           0.10    2    0   -2   -4   -1    0    0    0    0    0    0    0    0    0
  213         -20.80           0.10    1    1    0    0   -1    0    0    0    0    0    0    0    0    0
  214         -20.20           0.00    0    0    0    0    0    0    5   -7    0    0    0    0    0   -2
  215          19.90           0.00    0    1    0    2    1    0    0    0    0    0    0    0    0    0
  216         -19.70          -0.10    1    0   -4    0   -1    0    0    0    0    0    0    0    0    0
  217         -19.20           0.20    2    0    2    2    1    0    0    0    0    0    0    0    0    0
  218          13.10          -6.30    1    0    2    0    2    0    0    1    0    0    0    0    0    0
  219         -14.50           4.70    0    0    0    0    0    0    3   -5    0    0    0    0    0    0
  220          12.60          -6.30    1    0   -2    0   -2    0    0    4   -8    3    0    0    0    0
  221         -18.80           0.00    0    0    2   -3    2    0    0    0    0    0    0    0    0    0
  222          18.60          -0.10    0    0    4    0    2    0    0    0    0    0    0    0    0    0
  223          15.90          -2.80    1    0    0   -1    1    0    0    0    0    0    0    0    0    0
  224          18.70           0.00    1    0    0   -4   -1    0    0    0    0    0    0    0    0    0
  225         -18.40          -0.30    0    0    0    0    0    0    0    4    0   -2    0    0    0    2
  226         -15.40          -3.00    0    0    0    0    0    0    0    2    0   -1    0    0    0    2
  227           0.50         -17.30    0    0    0    0    0    0    2   -1    0    0    0    0    0    2
  228         -17.50           0.00    2    0    0   -2   -2    0    0    0    0    0    0    0    0    0
  229          17.40           0.10    1    1   -2   -4   -2    0    0    0    0    0    0    0    0    0
  230          16.30          -1.20    0    0    0    0    0    0    0    2    0    1    0    0    0    2
  231           6.20         -11.20    0    0    0    0    0    0    8  -11    0    0    0    0    0   -2
  232          -5.60         -11.70    0    0    0    0    0    0    0    8  -16    4    5    0    0   -2
  233          -2.70         -14.30    0    0    1   -1    1    0    0   -1    0    2    0    0    0    0
  234          12.50          -4.30    0    0    0    0    0    0    0    8  -16    4    5    0    0    2
  235          14.00           2.70    0    0    1   -1    1    0   -5    7    0    0    0    0    0    0
  236         -16.30           0.20    1    0    2    4    2    0    0    0    0    0    0    0    0    0
  237           5.10          11.40    0    0    0    0    0    0    0    0    0    0    2    0    0    1
  238          10.30          -6.00    1    0    0   -2    0    0   19  -21    3    0    0    0    0    0
  239           0.00         -16.20    0    0    1    0    1    0    0    0    0    0    0    0    0    0
  240         -16.10           0.00    3    0    0   -4    0    0    0    0    0    0    0    0    0    0
  241          15.90           0.00    1    1   -2    0   -2    0    0    0    0    0    0    0    0    0
  242          -4.80         -11.00    0    0    1   -1    1    0    0   -1    0    0    2    0    0    0
  243           6.70          -9.10    0    0    0    0    0    0    0    3    0   -2    0    0    0    2
  244          -6.10          -9.60    0    0    0    0    0    0    8  -15    0    0    0    0    0   -2
  245          15.60           0.00    0    1    0   -2   -1    0    0    0    0    0    0    0    0    0
  246         -15.40           0.10    0    0    0    4    1    0    0    0    0    0    0    0    0    0
  247          -8.50          -7.00    0    0    0    0    0    0    0    1    2    0    0    0    0    2
  248         -15.30          -0.10    0    0    2   -4    1    0    0    0    0    0    0    0    0    0
  249         -15.10          -0.10    1    1    0   -4    0    0    0    0    0    0    0    0    0    0
  250           8.00          -7.10    0    0    0    0    0    0    0    3   -2    0    0    0    0    2
  251         -12.70           2.10    0    0    0    0    0    0    0    0    0    3    0    0    0    2
  252          14.70           0.00    3    0    2   -2    1    0    0    0    0    0    0    0    0    0
  253          14.30          -0.30    0    0    0    0    0    0    0    4   -2    0    0    0    0    2
  254          14.40          -0.10    1    1    2    2    2    0    0    0    0    0    0    0    0    0
  255          14.10           0.00    0    0    4   -2    1    0    0    0    0    0    0    0    0    0
  256          13.80           0.00    2    0    0   -2    0    0   -3    3    0    0    0    0    0    0
  257         -13.40           0.10    3    0    2    2    2    0    0    0    0    0    0    0    0    0
  258         -13.30           0.00    0    0    0    0    0    0    0    0    0    0    2    0    0    2
  259          13.20           0.00    2    1    0   -2   -1    0    0    0    0    0    0    0    0    0
  260           2.50          10.60    0    0    0    0    0    0    4   -6    0    0    0    0    0   -1
  261           0.00          13.10    1    0    0   -1    0    0   -3    4    0    0    0    0    0    0
  262          -2.50          10.60    0    0    0    0    0    0    1   -1    0    0    0    0    0   -1
  263          12.90           0.10    0    2   -2   -2   -2    0    0    0    0    0    0    0    0    0
  264          12.80           0.00    0    0    2    0    3    0    0    0    0    0    0    0    0    0
  265         -12.30           0.00    2    0    0   -4   -1    0    0    0    0    0    0    0    0    0
  266          -7.80           4.50    0    0    0    0    0    0    0    3   -4    0    0    0    0    0
  267         -12.10           0.10    0    0    2    4    1    0    0    0    0    0    0    0    0    0
  268         -12.00           0.00    0    0    0    2   -2    0    0    0    0    0    0    0    0    0
  269          11.80          -0.10    3    0    0    0   -1    0    0    0    0    0    0    0    0    0
  270         -11.80           0.00    0    0    0    0    0    0    0    1    0   -3    0    0    0   -2
  271          11.70           0.00    0    0    2   -2    1    0   -3    3    0    0    0    0    0    0
  272         -11.70           0.00    0    0    0    0    0    0    6   -8    0    0    0    0    0   -2
  273         -11.50           0.00    2    1    0   -4    0    0    0    0    0    0    0    0    0    0
  274          11.30          -0.10    4    0    2   -2    2    0    0    0    0    0    0    0    0    0
  275         -11.40           0.00    2    0    0    2    1    0    0    0    0    0    0    0    0    0
  276         -11.40           0.00    0    0    1   -1    1    0    0    3   -8    3    0    0    0    0
  277           0.00         -11.40    0    0    0    0    0    0    3   -2    0    0    0    0    0    2
  278           0.00         -11.40    0    0    0    0    0    0    2   -5    0    0    0    0    0   -2
  279          11.30           0.00    1   -1    0   -2   -1    0    0    0    0    0    0    0    0    0
  280         -11.30           0.00    0    0    0    0    0    0    1   -3    0    0    0    0    0   -2
  281           4.60           6.60    0    0    0    0    1    0    8  -13    0    0    0    0    0    0
  282          11.00           0.00    2    1   -2   -4   -2    0    0    0    0    0    0    0    0    0
  283           2.20          -8.70    0    0    0    0    0    0    1   -2    0    0    0    0    0    0
  284          -6.80           3.90    0    0    0    0    0    0    0    2   -3    0    0    0    0    0
  285         -10.30          -0.30    1    1    0    2    0    0    0    0    0    0    0    0    0    0
  286         -10.60           0.00    0    0    2   -1    1    0    0    0    0    0    0    0    0    0
  287           8.90          -1.60    2    0    0   -2    1    0    0   -2    0    3    0    0    0    0
  288          10.50           0.00    1   -1   -2    2   -1    0    0    0    0    0    0    0    0    0
  289          -8.80           1.70    0    0    0    0    0    0    5   -8    0    0    0    0    0   -1
  290          10.40           0.00    1    2   -2   -2   -2    0    0    0    0    0    0    0    0    0
  291          10.30           0.00    1    0    0   -3    0    0    0    0    0    0    0    0    0    0
  292         -10.20           0.00    2    0    0   -2    2    0    0    0    0    0    0    0    0    0
  293         -10.20           0.00    2    0    0   -4    1    0    0    0    0    0    0    0    0    0
  294           6.80          -3.40    1    0    0    0   -1    0  -18   16    0    0    0    0    0    0
  295          10.10           0.00    2    0    2   -4    1    0    0    0    0    0    0    0    0    0
  296         -10.00          -0.10    1    0    0   -4    1    0    0    0    0    0    0    0    0    0
  297         -10.00           0.10    1   -1    2    2    1    0    0    0    0    0    0    0    0    0
  298           9.90           0.00    0    0    1   -1    1    0    0   -5    8   -3    0    0    0    0
  299           2.10          -7.80    0    0    1   -1    0    0    0   -1    0   -1    0    0    0    0
  300           8.30           1.50    0    0    0    0    0    0    0    2    0   -3    0    0    0    0
  301          -9.20          -0.50    2   -1    0   -2    0    0    0    0    0    0    0    0    0    0
  302          -4.00           5.70    0    0    0    0    1    0   -8   13    0    0    0    0    0    0
  303          -7.80          -1.80    2    0    0   -2    0    0   -6    8    0    0    0    0    0    0
  304          -9.60           0.00    1   -1   -2    0   -1    0    0    0    0    0    0    0    0    0
  305          -9.10          -0.40    2    1   -2    0   -1    0    0    0    0    0    0    0    0    0
  306           9.40           0.00    4    0    0    0    0    0    0    0    0    0    0    0    0    0
  307          -9.40           0.00    0    2    0    0    1    0    0    0    0    0    0    0    0    0
  308          -9.40           0.00    0    2   -2    2    0    0    0    0    0    0    0    0    0    0
  309          -9.40           0.00    0    1   -2    1   -2    0    0    0    0    0    0    0    0    0
  310           9.30           0.00    1    0   -4    2   -2    0    0    0    0    0    0    0    0    0
  311           8.30           1.00    0    2   -2    0   -2    0    0    0    0    0    0    0    0    0
  312          -9.20           0.10    2   -1    2    2    2    0    0    0    0    0    0    0    0    0
  313           9.20           0.10    0    1   -2   -4   -2    0    0    0    0    0    0    0    0    0
  314           7.60           1.70    0    0    0    0    1    0    0    0    0   -2    5    0    0    0
  315          -9.10           0.00    2    0    0    0    2    0    0    0    0    0    0    0    0    0
  316          -9.10           0.00    1    0   -2   -3   -2    0    0    0    0    0    0    0    0    0
  317          -7.30           1.70    0    0    0    0    1    0    0    0    0    2   -5    0    0    0
  318           2.00          -7.00    0    0    0    0    1    0    0    0    0    1    0    0    0    0
  319           8.90           0.00    0    0    0    0    0    0    3   -3    0    0    0    0    0    0
  320          -8.90           0.00    0    0    0    0    0    0    0    2    0    0    0    0    0    2
  321          -8.80           0.00    2    0    2   -2    0    0    0    0    0    0    0    0    0    0
  322           8.70           0.00    0    2    2   -2    1    0    0    0    0    0    0    0    0    0
  323           0.00          -8.60    0    0    0    0    0    0    0    6  -16    4    5    0    0   -2
  324           5.70          -2.80    1    0    0    0    1    0  -18   16    0    0    0    0    0    0
  325           8.50           0.00    1   -2    0    0    0    0    0    0    0    0    0    0    0    0
  326          -8.40           0.00    1   -1   -2   -2   -1    0    0    0    0    0    0    0    0    0
  327           8.40           0.00    0    1    2    2    1    0    0    0    0    0    0    0    0    0
  328           8.30           0.00    3    0    0    0    1    0    0    0    0    0    0    0    0    0
  329           8.30           0.00    1    0    2    0   -1    0    0    0    0    0    0    0    0    0
  330          -8.30           0.00    1    0   -2   -1   -2    0    0    0    0    0    0    0    0    0
  331           8.30           0.00    0    0    0    0    0    0    4   -4    0    0    0    0    0    0
  332          -3.50          -4.80    0    0    0    0    0    0    0    1    0    2    0    0    0    2
  333           8.20           0.00    2    1    0   -2    1    0    0    0    0    0    0    0    0    0
  334          -8.20           0.00    2   -1   -2    0   -1    0    0    0    0    0    0    0    0    0
  335           8.10          -0.10    1    0    2    2    0    0    0    0    0    0    0    0    0    0
  336           8.20           0.00    1    0    0    4    0    0    0    0    0    0    0    0    0    0
  337           7.90           0.00    2    0   -4    0   -2    0    0    0    0    0    0    0    0    0
  338           6.30          -1.60    0    0    0    0    0    0    3   -7    0    0    0    0    0   -2
  339           7.80           0.00    3    0   -2    0   -1    0    0    0    0    0    0    0    0    0
  340          -6.60          -1.20    0    0    1   -1    1    0    0   -1    0    0    1    0    0    0
  341           7.70           0.00    2    0   -2    2   -1    0    0    0    0    0    0    0    0    0
  342          -7.70           0.00    2   -1    2    0    1    0    0    0    0    0    0    0    0    0
  343           7.40          -0.30    1   -2    0   -2    0    0    0    0    0    0    0    0    0    0
  344           7.50           0.00    1    0    2   -4    0    0    0    0    0    0    0    0    0    0
  345           0.00           7.50    0    0    1    0    0    0    0    0    0    0    0    0    0    0
  346          -7.50           0.00    0    0    0    0    0    0    0    1    0    0   -1    0    0    0
  347           5.20           2.30    0    0    0    0    0    0    0    0    0    1    0    0    0    2
  348           7.40           0.00    0    2    2    0    2    0    0    0    0    0    0    0    0    0
  349          -7.40           0.00    0    0    0    0    0    0    7   -9    0    0    0    0    0   -2
  350          -7.40           0.00    0    0    0    0    0    0    0    0    2    0    0    0    0    2
  351          -1.40          -5.90    0    0    0    0    0    0    2   -4    0    0    0    0    0   -1
  352          -7.30           0.00    1   -1    2   -2    2    0    0    0    0    0    0    0    0    0
  353          -3.70           3.50    0    0    0    0    1    0    0    1   -2    0    0    0    0    0
  354           7.10           0.00    1    0    2   -4    2    0    0    0    0    0    0    0    0    0
  355          -6.90           0.00    2    0    2   -1    2    0    0    0    0    0    0    0    0    0
  356           5.40          -1.50    0    0    0    0    0    0    3   -3    0    0    0    0    0    2
  357          -0.30           6.60    0    0    0    0    0    0    4   -7    0    0    0    0    0   -2
  358          -6.80           0.00    1    1   -2    1   -1    0    0    0    0    0    0    0    0    0
  359          -1.20           5.50    0    0    0    0    0    0    2   -2    0    0    0    0    0   -1
  360           4.50          -2.20    0    0    0    0    0    0    0    8  -15    0    0    0    0    0
  361           1.10           5.60    0    0    0    0    0    0    0    0    0    0    1    0    0    0
  362          -6.50           0.00    0    1    0   -4    0    0    0    0    0    0    0    0    0    0
  363           1.30           5.20    0    0    0    0    0    0    0    0    0    1    0    0    0   -1
  364           6.40           0.00    2    1    2    0    1    0    0    0    0    0    0    0    0    0
  365          -2.80           3.60    0    0    0    0    0    0    0    1    0   -3    0    0    0    0
  366          -6.30           0.00    3   -1    2    0    2    0    0    0    0    0    0    0    0    0
  367          -6.30           0.00    2    1   -2   -2   -2    0    0    0    0    0    0    0    0    0
  368           6.30           0.00    1    1   -2    0   -1    0    0    0    0    0    0    0    0    0
  369           0.00          -6.30    1    0   -1    0   -3    0    0    0    0    0    0    0    0    0
  370           5.30          -0.90    2    0    0   -2   -1    0    0   -2    0    3    0    0    0    0
  371           6.20           0.00    1   -1    0   -2    1    0    0    0    0    0    0    0    0    0
  372           4.20           2.00    0    0    1   -1    0    0    0   -1    0    0   -1    0    0    0
  373          -6.10           0.00    1    0   -2    1    0    0    0    0    0    0    0    0    0    0
  374           6.10           0.00    0    2    0    0   -1    0    0    0    0    0    0    0    0    0
  375           6.00           0.00    2    0   -2   -2    0    0    0    0    0    0    0    0    0    0
  376          -6.00           0.00    1    0    2   -3    2    0    0    0    0    0    0    0    0    0
  377          -4.60           1.40    0    0    0    0    0    0    4   -6    0    0    0    0    0    0
  378          -1.10          -4.90    0    0    0    0    0    0    3   -5    0    0    0    0    0   -1
  379           0.60           5.40    0    0    0    0    0    0    0    0    0    1    0    0    0    1
  380           5.90           0.00    0    0    0    0    0    0    5   -5    0    0    0    0    0    0
  381           5.70           0.00    1    0    2    1    1    0    0    0    0    0    0    0    0    0
  382          -5.60           0.00    2    0    0    0   -2    0    0    0    0    0    0    0    0    0
  383          -2.60          -2.90    1    0    0   -1    1    0    0   -1    0    2    0    0    0    0
  384          -0.80          -4.70    0    0    1   -1    1    0    0   -2    2    0    0    0    0    0
  385           4.70           0.80    0    0    0    0    0    0    0    0    0    0    1    0    0    1
  386           5.40           0.00    2    0    0   -2    1    0    0   -2    0    2    0    0    0    0
  387          -2.00           3.40    0    0    0    0    0    0    0    3   -5    0    0    0    0    0
  388          -2.10          -3.20    0    0    0    0    0    0    0    0    4    0    0    0    0    2
  389           5.30           0.00    3    1    2    0    2    0    0    0    0    0    0    0    0    0
  390          -5.30           0.00    1    1    2    1    2    0    0    0    0    0    0    0    0    0
  391           5.30           0.00    1    0    0   -1    0    0    0   -1    0    1    0    0    0    0
  392          -0.60          -4.70    0    0    1   -1    1    0    0   -1    0    1    0    0    0    0
  393          -5.00           0.30    0    0    0    0    0    0    8  -10    0    0    0    0    0   -2
  394          -1.40          -3.90    0    0    0    0    0    0    5   -8    0    0    0    0    0    0
  395          -0.60           4.70    0    0    0    0    0    0    0    1   -2    0    0    0    0   -1
  396           5.10           0.00    2    0    0   -3    0    0    0    0    0    0    0    0    0    0
  397           5.10           0.00    2   -1    2   -2    2    0    0    0    0    0    0    0    0    0
  398          -5.10           0.00    1   -2    2    0    2    0    0    0    0    0    0    0    0    0
  399           5.10           0.00    0    0    0    0    0    0    0    2   -4    0    0    0    0   -2
  400           5.00           0.00    0    0    2   -2    1    0    0   -2    0    2    0    0    0    0
  401          -1.00           4.00    0    0    1   -1    1    0   -3    4    0    0    0    0    0    0
  402           4.90           0.00    3    0    0    2    0    0    0    0    0    0    0    0    0    0
  403           4.90           0.00    0    1    0    1    1    0    0    0    0    0    0    0    0    0
  404           4.80           0.00    0    1    2   -2    3    0    0    0    0    0    0    0    0    0
  405           4.80           0.00    0    1    0    1   -1    0    0    0    0    0    0    0    0    0
  406           3.00          -1.80    0    0    0    0    0    0    0    5   -4    0    0    0    0    2
  407           4.70           0.00    2    0    2    1    2    0    0    0    0    0    0    0    0    0
  408           4.70           0.00    2   -1    0    2    0    0    0    0    0    0    0    0    0    0
  409           4.70           0.00    1    1    0    1    0    0    0    0    0    0    0    0    0    0
  410          -4.70           0.00    1    1   -2    2   -1    0    0    0    0    0    0    0    0    0
  411           1.80          -2.90    0    0    0    0    0    0    0    4   -4    0    0    0    0    2
  412          -2.50           2.20    0    0    0    0    0    0    0    0    0    2    0    0    0    0
  413          -3.20           1.50    0    0    0    0    0    0    0    0    0    0    1    0    0   -1
  414          -4.60           0.00    2    0   -4   -2   -2    0    0    0    0    0    0    0    0    0
  415          -4.50           0.00    4    0    2    0    1    0    0    0    0    0    0    0    0    0
  416           4.50           0.00    1    2    2   -2    2    0    0    0    0    0    0    0    0    0
  417          -4.50           0.00    1    1    2   -4    1    0    0    0    0    0    0    0    0    0
  418          -4.50           0.00    0    1    0    2   -1    0    0    0    0    0    0    0    0    0
  419           4.50           0.00    0    0    4   -4    4    0    0    0    0    0    0    0    0    0
  420           0.00          -4.50    0    0    0    0    0    0    6   -9    0    0    0    0    0   -2
  421          -4.40           0.00    3    0   -2   -2   -2    0    0    0    0    0    0    0    0    0
  422           4.40           0.00    2    1   -2    0    0    0    0    0    0    0    0    0    0    0
  423          -4.40           0.00    0    0    4   -4    2    0    0    0    0    0    0    0    0    0
  424          -3.70          -0.70    0    0    0    0    0    0    0    4    0   -3    0    0    0    2
  425           4.30           0.00    2    0   -2   -6   -2    0    0    0    0    0    0    0    0    0
  426          -4.30           0.00    1    0    2   -3    1    0    0    0    0    0    0    0    0    0
  427           0.80           3.50    0    0    0    0    0    0    5   -7    0    0    0    0    0   -1
  428           0.70          -3.60    0    0    0    0    0    0    0    2    0    0    0    0    0    1
  429          -1.30          -3.00    0    0    0    0    0    0    0    1    0    2   -5    0    0    0
  430           4.20           0.00    2    0    0    2   -1    0    0    0    0    0    0    0    0    0
  431          -4.20           0.00    0    1    2    1    1    0    0    0    0    0    0    0    0    0
  432          -3.50          -0.70    0    0    1   -1    0    0   -5    7    0    0    0    0    0    0
  433          -0.80           3.40    0    0    0    0    0    0    3   -3    0    0    0    0    0   -1
  434           1.90          -2.30    0    0    0    0    0    0    2    1    0    0    0    0    0    2
  435           4.10           0.00    2    1    2   -2    1    0    0    0    0    0    0    0    0    0
  436          -4.00           0.00    1    0    2   -1    1    0    0    0    0    0    0    0    0    0
  437           4.00           0.00    0    0    0    0    0    0    6   -6    0    0    0    0    0    0
  438           2.60          -1.40    0    0    0    0    0    0    0    4   -3    0    0    0    0    2
  439          -0.70          -3.20    0    0    0    0    0    0    1   -1    0    0    0    0    0    1
  440          -0.80          -3.10    0    0    0    0    0    0    1   -3    0    0    0    0    0   -1
  441           3.90           0.00    1    0    4   -2    1    0    0    0    0    0    0    0    0    0
  442          -3.90           0.00    1   -1    2   -2    1    0    0    0    0    0    0    0    0    0
  443          -1.60           2.30    0    0    0    0    0    0    0    4   -6    0    0    0    0    0
  444           3.80           0.00    2    0    0   -1    0    0    0    0    0    0    0    0    0    0
  445          -3.80           0.00    2   -1    0   -2    1    0    0    0    0    0    0    0    0    0
  446           3.80           0.00    2   -2    0   -2   -1    0    0    0    0    0    0    0    0    0
  447          -3.80           0.00    1    0    2   -2   -1    0    0    0    0    0    0    0    0    0
  448           3.70           0.00    2    0    4   -2    2    0    0    0    0    0    0    0    0    0
  449           1.50           2.20    2    0    0   -2    0    0    0   -6    8    0    0    0    0    0
  450          -3.70           0.00    1   -1    0    2    1    0    0    0    0    0    0    0    0    0
  451           3.70           0.00    0    0    2    3    2    0    0    0    0    0    0    0    0    0
  452           3.10          -0.60    0    0    0    0    0    0    3   -1    0    0    0    0    0    2
  453           2.40          -1.30    0    0    0    0    0    0    0    3   -6    0    0    0    0   -2
  454           3.60           0.00    1    1    0   -1    0    0    0    0    0    0    0    0    0    0
  455          -3.60           0.00    1    0   -2    2    1    0    0    0    0    0    0    0    0    0
  456           3.60           0.00    1   -1    0    2   -1    0    0    0    0    0    0    0    0    0
  457           3.60           0.00    0    1    4   -2    2    0    0    0    0    0    0    0    0    0
  458           0.90          -2.70    0    0    1   -1    1    0    0   -1    0   -4   10    0    0    0
  459          -3.00          -0.60    0    0    0    0    0    0    0    1    0   -4    0    0    0   -2
  460           2.40          -1.20    2    0    2    0    2    0    0    2    0   -3    0    0    0    0
  461           2.40           1.20    2    0    0   -2    0    0    0   -5    6    0    0    0    0    0
  462          -2.40          -1.20    0    0    2    0    2    0    0    1    0    0    0    0    0    0
  463          -1.70          -1.90    0    0    1   -1    1    0    0   -1    0    0    0    0    2    0
  464           2.60          -0.90    2    0   -1   -1    0    0    0    3   -7    0    0    0    0    0
  465           3.50           0.00    2   -1    0    0    1    0    0    0    0    0    0    0    0    0
  466          -3.50           0.00    1    2    0    0    0    0    0    0    0    0    0    0    0    0
  467          -3.50           0.00    1   -2   -2   -2   -2    0    0    0    0    0    0    0    0    0
  468           1.10           2.40    0    0    1   -1    2    0    0   -1    0    0    2    0    0    0
  469          -0.70           2.80    0    0    1   -1    1    0   -4    5    0    0    0    0    0    0
  470           3.50           0.00    0    0    0    4   -1    0    0    0    0    0    0    0    0    0
  471          -0.30          -3.20    0    0    0    0    0    0    0    4    0   -1    0    0    0    2
  472           0.00           3.50    0    0    0    0    0    0    0    2    0   -1    0    0    0    0
  473           1.40           2.10    0    0    0    0    0    0    0    2   -4    0    0    0    0   -1
  474           0.80          -2.70    0    0    0    0    0    0    0    1    0    0    0    0    0    0
  475          -1.10          -2.40    0    0    0    0    0    0    0    0    0    2   -5    0    0   -2
  476           2.20           1.20    0    0    0    0    0    0    0    1   -8    3    0    0    0   -2
  477           3.40           0.00    1    0    0   -1   -2    0    0    0    0    0    0    0    0    0
  478           3.40           0.00    1    0    0   -2    0    0    0   -2    0    2    0    0    0    0
  479          -3.40           0.00    1   -1   -2    2    0    0    0    0    0    0    0    0    0    0
  480          -3.40           0.00    0    0    0    0    0    0    9  -11    0    0    0    0    0   -2
  481           3.30           0.00    1    0   -2    1   -2    0    0    0    0    0    0    0    0    0
  482          -3.30           0.00    0    1   -2    2    1    0    0    0    0    0    0    0    0    0
  483          -3.00          -0.30    0    0    0    0    0    0    2   -3    0    0    0    0    0   -1
  484           3.20           0.00    3    1    2   -2    2    0    0    0    0    0    0    0    0    0
  485          -3.20           0.00    2    0    2   -4    2    0    0    0    0    0    0    0    0    0
  486          -2.10           1.10    2    0    0    0    0    0    0   -2    0    3    0    0    0    0
  487           3.20           0.00    1    1    0    2    1    0    0    0    0    0    0    0    0    0
  488           2.10          -1.10    1    0    2    0    1    0    0   -2    0    3    0    0    0    0
  489          -3.20           0.00    1    0    0    4    1    0    0    0    0    0    0    0    0    0
  490           2.10          -1.10    1    0   -2    0   -1    0    0   -1    0    0    0    0    0    0
  491           3.20           0.00    1    0   -2   -6   -2    0    0    0    0    0    0    0    0    0
  492          -3.20           0.00    1    0   -4   -2   -2    0    0    0    0    0    0    0    0    0
  493           3.20           0.00    0    0    4    0    1    0    0    0    0    0    0    0    0    0
  494           1.00          -2.20    0    0    2   -2    1    0    0   -9   13    0    0    0    0    0
  495           0.00          -3.20    0    0    0    0    1    0    2   -3    0    0    0    0    0    0
  496          -1.10          -2.10    0    0    0    0    1    0    0   -2    4    0    0    0    0    0
  497          -0.40          -2.80    0    0    0    0    0    0    1    0    0    0    0    0    0    0
  498          -3.10           0.00    1   -1   -2   -4   -2    0    0    0    0    0    0    0    0    0
  499          -3.10           0.00    1   -2    2    2    2    0    0    0    0    0    0    0    0    0
  500           3.10           0.00    0    0    2   -1    0    0    0    0    0    0    0    0    0    0
  501           3.10           0.00    0    0    2   -4    2    0    0    0    0    0    0    0    0    0
  502           0.00           3.10    0    0    0    0    0    0    0    3   -6    0    0    0    0    0
  503          -0.30           2.80    0    0    1    1    1    0    0    1    0    0    0    0    0    0
  504           3.00           0.00    3    0    2    0    0    0    0    0    0    0    0    0    0    0
  505           3.00           0.00    1    1   -2    1    0    0    0    0    0    0    0    0    0    0
  506           3.00           0.00    1    1   -2   -4   -1    0    0    0    0    0    0    0    0    0
  507           0.00           3.00    0    0    1    0    2    0    0    0    0    0    0    0    0    0
  508          -0.60           2.40    0    0    0    0    0    0    4   -4    0    0    0    0    0   -1
  509          -1.90          -1.10    0    0    0    0    0    0    0    3   -8    3    0    0    0    0
  510           2.30           0.70    0    0    0    0    0    0    0    1   -2    0    0    0    0    1
  511           2.90           0.00    3   -1    0    0    0    0    0    0    0    0    0    0    0    0
  512          -2.90           0.00    2    0   -2    2    0    0    0    0    0    0    0    0    0    0
  513           2.90           0.00    2   -1    0    0   -1    0    0    0    0    0    0    0    0    0
  514           2.90           0.00    2   -1   -2    0    0    0    0    0    0    0    0    0    0    0
  515          -2.90           0.00    1    1    2   -2    0    0    0    0    0    0    0    0    0    0
  516          -2.90           0.00    1    0    2    4    1    0    0    0    0    0    0    0    0    0
  517           0.00           2.90    1    0    0   -1    1    0   -3    4    0    0    0    0    0    0
  518          -2.40           0.50    0    0    0    0    0    0    6  -10    0    0    0    0    0   -2
  519           2.90           0.00    0    0    0    0    0    0    0    3    0    0   -1    0    0    2
  520           0.60           2.30    0    0    0    0    0    0    0    0    0    3    0    0    0    1
  521          -2.80           0.00    2    0    2   -4    0    0    0    0    0    0    0    0    0    0
  522          -2.80           0.00    1    2    0   -2   -1    0    0    0    0    0    0    0    0    0
  523          -2.80           0.00    1    1   -2   -2    0    0    0    0    0    0    0    0    0    0
  524          -2.80           0.00    1    0    0    1   -1    0    0    0    0    0    0    0    0    0
  525          -2.80           0.00    0    1    2   -2   -1    0    0    0    0    0    0    0    0    0
  526          -2.80           0.00    0    0    0    0    1    0    1   -1    0    0    0    0    0    0
  527           0.40           2.40    0    0    0    0    1    0    0    0    0    0    1    0    0    0
  528           2.80           0.00    0    0    0    0    0    0    7   -7    0    0    0    0    0    0
  529           0.50          -2.30    0    0    0    0    0    0    1    1    0    0    0    0    0    1
  530          -1.80          -1.00    0    0    0    0    0    0    0    0    3    0    0    0    0    2
  531          -2.70           0.00    2    0    2    4    2    0    0    0    0    0    0    0    0    0
  532           2.70           0.00    2   -1   -2   -2   -2    0    0    0    0    0    0    0    0    0
  533          -2.70           0.00    0    1   -2   -2    0    0    0    0    0    0    0    0    0    0
  534           2.70           0.00    0    0    2   -2    1    0   -4    4    0    0    0    0    0    0
  535           2.70           0.00    0    0    2   -3    1    0    0    0    0    0    0    0    0    0
  536          -2.10          -0.60    0    0    0    0    1    0   -3    5    0    0    0    0    0    0
  537           0.00          -2.70    0    0    0    0    0    0    3   -6    0    0    0    0    0   -2
  538           2.70           0.00    0    0    0    0    0    0    0    3   -3    0    0    0    0    0
  539           1.90          -0.80    0    0    0    0    0    0    0    1   -4    0    0    0    0   -2
  540          -2.60           0.00    3    0    2   -4    2    0    0    0    0    0    0    0    0    0
  541          -2.60           0.00    3    0   -2   -2   -1    0    0    0    0    0    0    0    0    0
  542           2.60           0.00    2    1    2    2    2    0    0    0    0    0    0    0    0    0
  543           0.00          -2.60    0    0    3    0    3    0    0    0    0    0    0    0    0    0
  544           0.50           2.10    0    0    1   -1    1    0   -1    0    0    0    0    0    0    0
  545          -0.60           2.00    0    0    0    0    0    0    0    1    0    0   -2    0    0    0
  546          -2.50           0.00    2    0    0    1    0    0    0    0    0    0    0    0    0    0
  547           2.50           0.00    1   -2    0    2    0    0    0    0    0    0    0    0    0    0
  548           0.90          -1.60    0    0    1   -1    0    0    0   -1    0   -2    5    0    0    0
  549           0.60           1.90    0    0    0    0    0    0    2   -1    0    0    0    0    0    0
  550          -2.50           0.00    0    0    0    0    0    0    0    7   -8    3    0    0    0    2
  551          -1.60           0.90    0    0    0    0    0    0    0    4   -7    0    0    0    0   -2
  552          -0.40           2.10    0    0    0    0    0    0    0    2    0   -2    0    0    0    1
  553          -2.50           0.00    0    0    0    0    0    0    0    1   -1    0    0    0    0    0
  554           1.60           0.80    1    0    0   -1    0    0    0   -3    4    0    0    0    0    0
  555          -2.40           0.00    3    0    2    2    1    0    0    0    0    0    0    0    0    0
  556          -2.40           0.00    3    0   -2    0    0    0    0    0    0    0    0    0    0    0
  557           2.40           0.00    1    0    4    0    2    0    0    0    0    0    0    0    0    0
  558          -2.40           0.00    1   -1    2    4    2    0    0    0    0    0    0    0    0    0
  559          -2.40           0.00    1   -1   -2    2   -2    0    0    0    0    0    0    0    0    0
  560           0.00           2.40    0    0    1   -1    0    0    0   -1    0   -1    1    0    0    0
  561           0.00          -2.40    0    0    0    0    0    0    7  -10    0    0    0    0    0   -2
  562           0.50           1.90    0    0    0    0    0    0    6   -8    0    0    0    0    0   -1
  563           2.10           0.30    0    0    0    0    0    0    0    5   -8    3    0    0    0    0
  564          -2.30           0.00    5    0    2    0    2    0    0    0    0    0    0    0    0    0
  565          -2.30           0.00    3    1    0    0    0    0    0    0    0    0    0    0    0    0
  566           2.30           0.00    3    0   -2   -6   -2    0    0    0    0    0    0    0    0    0
  567          -2.30           0.00    2    0    0   -6    0    0    0    0    0    0    0    0    0    0
  568           2.30           0.00    1    1    2    2    1    0    0    0    0    0    0    0    0    0
  569           2.30           0.00    1    0    0    2    2    0    0    0    0    0    0    0    0    0
  570           0.00           2.30    1    0    0   -1   -1    0   -3    4    0    0    0    0    0    0
  571           1.00           1.30    1   -2    2   -2    1    0    0    0    0    0    0    0    0    0
  572           1.10          -1.20    0    0    1   -1    1    0    8  -14    0    0    0    0    0    0
  573          -0.90          -1.40    0    0    1   -1    1    0    3   -6    0    0    0    0    0    0
  574          -1.40           0.90    0    0    0    0    0    0    3   -9    4    0    0    0    0   -2
  575          -2.20           0.00    2    1    0    0   -1    0    0    0    0    0    0    0    0    0
  576          -2.20           0.00    1    2    0   -2    1    0    0    0    0    0    0    0    0    0
  577           2.20           0.00    1   -1    2    0    0    0    0    0    0    0    0    0    0    0
  578           2.20           0.00    1   -1    2   -1    2    0    0    0    0    0    0    0    0    0
  579           2.20           0.00    1   -1    0   -4    0    0    0    0    0    0    0    0    0    0
  580           2.20           0.00    0    2   -2   -2   -1    0    0    0    0    0    0    0    0    0
  581           0.90          -1.30    0    0    1   -1    1    0    0   -3    4    0    0    0    0    0
  582           1.50          -0.70    0    0    0    0    1    0    0    8  -15    0    0    0    0    0
  583          -1.30           0.90    0    0    0    0    0    0    3   -5    4    0    0    0    0    2
  584           1.40           0.80    0    0    0    0    0    0    0    8  -15    0    0    0    0   -2
  585           1.30           0.90    0    0    0    0    0    0    0    6    0    0    0    0    0    2
  586           1.60          -0.60    0    0    0    0    0    0    0    4   -5    0    0    0    0    0
  587           0.00           2.20    0    0    0    0    0    0    0    4   -7    0    0    0    0    0
  588          -1.70          -0.40    2    0    0   -2    1    0   -6    8    0    0    0    0    0    0
  589          -2.10           0.00    2    0   -2    0    2    0    0    0    0    0    0    0    0    0
  590           2.10           0.00    1    2    2    0    2    0    0    0    0    0    0    0    0    0
  591           2.10           0.00    0    1    0   -2   -2    0    0    0    0    0    0    0    0    0
  592           2.10           0.00    0    1   -2    2   -3    0    0    0    0    0    0    0    0    0
  593          -0.40           1.70    0    0    0    0    0    0    5   -5    0    0    0    0    0   -1
  594           1.60          -0.50    0    0    0    0    0    0    5   -7    0    0    0    0    0    0
  595           0.40           1.70    0    0    0    0    0    0    1    2    0    0    0    0    0    2
  596           1.80          -0.30    0    0    0    0    0    0    0    3    0   -3    0    0    0    0
  597           1.40           0.70    0    0    1   -1    0    0   -8   12    0    0    0    0    0    0
  598          -2.00           0.00    4    0    0   -2    0    0    0    0    0    0    0    0    0    0
  599           2.00           0.00    2    2    0   -2    0    0    0    0    0    0    0    0    0    0
  600          -2.00           0.00    2    1    0    0    1    0    0    0    0    0    0    0    0    0
  601           2.00           0.00    1    1    0   -2   -2    0    0    0    0    0    0    0    0    0
  602          -2.00           0.00    0    1    2    0    0    0    0    0    0    0    0    0    0    0
  603           1.70          -0.30    0    0    0    0    0    0    3    0    0    0    0    0    0    2
  604           0.70           1.30    0    0    0    0    0    0    0    5   -9    0    0    0    0    0
  605          -0.80           1.20    0    0    0    0    0    0    0    5   -9    0    0    0    0   -2
  606           0.90          -1.10    0    0    0    0    0    0    0    3    0   -3    0    0    0    2
  607           0.00          -2.00    0    0    0    0    0    0    0    2    0    0   -1    0    0    2
  608          -0.90          -1.10    0    0    0    0    0    0    0    0    0    0    0    0    2    1
  609           0.30           1.60    0    0    1   -1    0    0    0   -1    0    2    0    0    0    0
  610           1.60          -0.30    0    0    0    0    0    0    7  -11    0    0    0    0    0   -2
  611           0.80           1.10    0    0    0    0    0    0    0    1    0    1    0    0    0    0
  612          -1.90           0.00    3    0    0   -4   -1    0    0    0    0    0    0    0    0    0
  613           1.90           0.00    2    1   -2   -4   -1    0    0    0    0    0    0    0    0    0
  614          -1.90           0.00    2   -1   -2   -4   -2    0    0    0    0    0    0    0    0    0
  615          -1.90           0.00    1    1    2    0    0    0    0    0    0    0    0    0    0    0
  616          -1.90           0.00    1    0    0    1    1    0    0    0    0    0    0    0    0    0
  617           1.90           0.00    1    0    0   -2    0    0   -3    3    0    0    0    0    0    0
  618           1.90           0.00    1    0   -4    2   -1    0    0    0    0    0    0    0    0    0
  619           0.00           1.90    0    0    1   -1    1    0    0   -9   15    0    0    0    0    0
  620           0.40           1.50    0    0    0    0    1    0    0    0    0   -1    0    0    0    0
  621          -1.90           0.00    0    0    0    0    1    0   -1    1    0    0    0    0    0    0
  622           0.00           1.90    0    0    0    0    1    0   -2    3    0    0    0    0    0    0
  623           1.90           0.00    0    0    0    0    0    0    8   -8    0    0    0    0    0    0
  624           0.40          -1.50    0    0    0    0    0    0    2    0    0    0    0    0    0    1
  625           0.70          -1.20    0    0    0    0    0    0    0    5   -5    0    0    0    0    2
  626           1.90           0.00    0    0    0    0    0    0    0    3   -1    0    0    0    0    2
  627           0.00          -1.90    0    0    0    0    0    0    0    2    0    0    1    0    0    2
  628           1.80           0.00    4    0    2   -2    1    0    0    0    0    0    0    0    0    0
  629          -1.80           0.00    3    0   -2    0   -2    0    0    0    0    0    0    0    0    0
  630          -1.80           0.00    1   -1    0    0    2    0    0    0    0    0    0    0    0    0
  631           1.80           0.00    1   -1   -2    0    0    0    0    0    0    0    0    0    0    0
  632          -1.80           0.00    0    1    2   -4    1    0    0    0    0    0    0    0    0    0
  633          -1.80           0.00    0    0    2    1    0    0    0    0    0    0    0    0    0    0
  634           1.80           0.00    0    0    1   -1    1    0   -2    2    0    0    0    0    0    0
  635           1.20          -0.60    0    0    0    0    0    0    0    2    0   -2    5    0    0    2
  636          -1.10          -0.60    0    0    0    0    0    0    0    2    0    2   -5    0    0    2
  637          -1.70           0.00    1    1   -2    0    0    0    0    0    0    0    0    0    0    0
  638           1.70           0.00    1    0   -2    4   -1    0    0    0    0    0    0    0    0    0
  639          -1.70           0.00    1    0   -2   -2    1    0    0    0    0    0    0    0    0    0
  640          -1.70           0.00    0    2    2   -2    0    0    0    0    0    0    0    0    0    0
  641          -1.70           0.00    0    2    0   -2    1    0    0    0    0    0    0    0    0    0
  642           1.70           0.00    0    1    2    4    2    0    0    0    0    0    0    0    0    0
  643           1.70           0.00    0    1   -4    2   -2    0    0    0    0    0    0    0    0    0
  644           1.40          -0.30    0    0    0    0    0    0    5   -3    0    0    0    0    0    2
  645           0.50           1.20    0    0    0    0    0    0    0    3    0    2   -5    0    0    2
  646          -1.70           0.00    0    0    0    0    0    0    0    3   -5    0    0    0    0   -2
  647          -1.70           0.00    0    0    0    0    0    0    0    2    0   -4    0    0    0   -2
  648           1.60           0.00    3    0    0   -2   -1    0    0    0    0    0    0    0    0    0
  649           1.60           0.00    2    0    0   -2    1    0   -3    3    0    0    0    0    0    0
  650          -1.60           0.00    2    0   -2    2   -2    0    0    0    0    0    0    0    0    0
  651          -1.60           0.00    2   -1    2    2    1    0    0    0    0    0    0    0    0    0
  652          -1.60           0.00    1    0    0   -6    0    0    0    0    0    0    0    0    0    0
  653          -1.60           0.00    1    0   -2   -3   -1    0    0    0    0    0    0    0    0    0
  654          -1.60           0.00    1    0   -2   -4    0    0    0    0    0    0    0    0    0    0
  655           1.60           0.00    0    1    0   -4   -1    0    0    0    0    0    0    0    0    0
  656           1.60           0.00    0    1   -2   -4   -1    0    0    0    0    0    0    0    0    0
  657           1.00          -0.60    0    0    0    0    1    0    3   -7    4    0    0    0    0    0
  658          -0.30           1.30    0    0    0    0    0    0    6   -6    0    0    0    0    0   -1
  659          -0.30          -1.30    0    0    0    0    0    0    2   -2    0    0    0    0    0    1
  660          -0.50          -1.10    0    0    0    0    0    0    2   -3    0    0    0    0    0   -2
  661          -1.10           0.50    0    0    0    0    0    0    0   11    0    0    0    0    0    2
  662          -1.10           0.50    0    0    0    0    0    0    0    6  -15    0    0    0    0   -2
  663           0.60          -1.00    0    0    0    0    0    0    0    4   -8    0    0    0    0   -2
  664          -0.50          -1.10    0    0    0    0    0    0    0    3    0    1    0    0    0    2
  665          -0.40          -1.20    0    0    0    0    0    0    0    3    0   -2    0    0    0    0
  666          -1.50           0.00    4    0    2    2    2    0    0    0    0    0    0    0    0    0
  667           0.60          -0.90    2    0    0   -2    0    0    0   -2    0    4   -3    0    0    0
  668          -1.50           0.00    2    0    0   -2    0    0    0   -2    0    3   -1    0    0    0
  669          -1.50           0.00    2    0   -2   -3   -2    0    0    0    0    0    0    0    0    0
  670           1.50           0.00    2   -1    0   -4    0    0    0    0    0    0    0    0    0    0
  671           1.50           0.00    1    0    2    0    3    0    0    0    0    0    0    0    0    0
  672          -1.50           0.00    0    1   -2    1   -1    0    0    0    0    0    0    0    0    0
  673           1.50           0.00    0    0    4   -2    4    0    0    0    0    0    0    0    0    0
  674          -1.50           0.00    0    0    2   -2    4    0    0    0    0    0    0    0    0    0
  675           0.00           1.50    0    0    2   -2    2    0   -8   11    0    0    0    0    0    0
  676           0.00           1.50    0    0    1   -1    2    0    0   -2    2    0    0    0    0    0
  677          -1.50           0.00    0    0    0    3    0    0    0    0    0    0    0    0    0    0
  678           1.50           0.00    0    0    0    0    1    0    0    1    0   -1    0    0    0    0
  679           0.30           1.20    0    0    0    0    0    0    7   -9    0    0    0    0    0   -1
  680           1.20          -0.30    0    0    0    0    0    0    4   -7    0    0    0    0    0   -1
  681           0.30           1.20    0    0    0    0    0    0    3   -3    0    0    0    0    0    1
  682           0.60          -0.90    0    0    0    0    0    0    0    6   -6    0    0    0    0    2
  683           0.90           0.60    0    0    0    0    0    0    0    6  -11    0    0    0    0    0
  684           0.30           1.20    0    0    0    0    0    0    0    5    0   -2    0    0    0    2
  685           1.50           0.00    0    0    0    0    0    0    0    2    0    0   -2    0    0    0
  686           1.10           0.40    0    0    0    0    0    0    0    2    0   -4    0    0    0    0
  687           0.00           1.50    0    0    0    0    0    0    0    0    0    0    3    0    0    2
  688          -1.10          -0.30    2    0    0   -2   -1    0   -6    8    0    0    0    0    0    0
  689           1.10          -0.30    0    0    0    0    0    0    4   -4    0    0    0    0    0    2
  690          -1.40           0.00    3    1    0   -4    0    0    0    0    0    0    0    0    0    0
  691          -1.40           0.00    3    0    0   -4    1    0    0    0    0    0    0    0    0    0
  692          -1.40           0.00    3    0    0   -6    0    0    0    0    0    0    0    0    0    0
  693           1.40           0.00    1    2   -2   -2   -1    0    0    0    0    0    0    0    0    0
  694           1.40           0.00    1    1    0   -2    2    0    0    0    0    0    0    0    0    0
  695          -1.40           0.00    0    0    4   -4    1    0    0    0    0    0    0    0    0    0
  696           0.00           1.40    0    0    1   -1    1    0    0   -1    0   -1    1    0    0    0
  697          -0.90          -0.50    0    0    0    0    1    0   -3    7   -4    0    0    0    0    0
  698           0.40           1.00    0    0    0    0    0    1    0   -4    0    0    0    0    0   -2
  699           1.40           0.00    0    0    0    0    0    0    0    6    0    0    0    0    0    0
  700          -1.40           0.00    0    0    0    0    0    0    0    1    0    0    1    0    0    2
  701           0.50          -0.90    0    0    0    0    0    0    0    1   -5    0    0    0    0   -2
  702          -1.30           0.00    2    0   -2   -4    0    0    0    0    0    0    0    0    0    0
  703           1.30           0.00    1    1    0    0    2    0    0    0    0    0    0    0    0    0
  704          -1.30           0.00    1    1    0   -4    1    0    0    0    0    0    0    0    0    0
  705           0.00          -1.30    1    0    1    0    1    0    0    0    0    0    0    0    0    0
  706          -1.30           0.00    1    0    0    2   -2    0    0    0    0    0    0    0    0    0
  707          -1.30           0.00    1    0    0   -2    0    0    0   -2    0    3    0    0    0    0
  708           1.30           0.00    1    0    0   -4   -2    0    0    0    0    0    0    0    0    0
  709          -1.30           0.00    1    0   -2   -2   -2    0    0   -2    0    2    0    0    0    0
  710           1.30           0.00    1    0   -4    0    0    0    0    0    0    0    0    0    0    0
  711           1.30           0.00    0    1    0   -1    0    0    0    0    0    0    0    0    0    0
  712          -1.30           0.00    0    0    2    6    2    0    0    0    0    0    0    0    0    0
  713          -1.30           0.00    0    0    2   -2    0    0   -3    3    0    0    0    0    0    0
  714           0.00          -1.30    0    0    1   -1    1    0    2   -4    0   -3    0    0    0    0
  715           0.40           0.90    0    0    1   -1    0    0    0   -1    0    0    2    0    0    0
  716           1.30           0.00    0    0    0    1    2    0    0    0    0    0    0    0    0    0
  717           1.30           0.00    0    0    0    0    1    0    3   -5    0    2    0    0    0    0
  718           1.30           0.00    0    0    0    0    0    0    9   -9    0    0    0    0    0    0
  719           0.30           1.00    0    0    0    0    0    0    5   -6    0    0    0    0    0    2
  720          -1.30           0.00    0    0    0    0    0    0    0    1    1    0    0    0    0    2
  721          -0.80           0.40    0    0    1   -1    1    0    0   -1    0    0    3    0    0    0
  722          -0.40           0.80    0    0    0    0    1    0    0    2   -4    0    0    0    0    0
  723           0.80          -0.40    0    0    0    0    0    0    4   -2    0    0    0    0    0    2
  724           0.40           0.80    0    0    0    0    0    0    0    7  -13    0    0    0    0   -2
  725           0.80          -0.40    0    0    0    0    0    0    0    0    0    0    3    0    0    1
  726           1.20           0.00    4    0    0   -4    0    0    0    0    0    0    0    0    0    0
  727          -1.20           0.00    3    0    0    2    1    0    0    0    0    0    0    0    0    0
  728          -1.20           0.00    3   -1    2    2    2    0    0    0    0    0    0    0    0    0
  729           1.20           0.00    3   -1    2   -2    2    0    0    0    0    0    0    0    0    0
  730          -1.20           0.00    2    1    0    2    0    0    0    0    0    0    0    0    0    0
  731          -1.20           0.00    2    0    0   -2   -1    0    0   -2    0    0    5    0    0    0
  732           1.20           0.00    1    1    0   -4   -1    0    0    0    0    0    0    0    0    0
  733           0.00          -1.20    1    0    1   -2    1    0    0    0    0    0    0    0    0    0
  734          -1.20           0.00    1    0    0   -1    2    0    0    0    0    0    0    0    0    0
  735           1.20           0.00    1   -1    0    4    0    0    0    0    0    0    0    0    0    0
  736          -1.20           0.00    1   -2    2   -2    2    0    0    0    0    0    0    0    0    0
  737           1.20           0.00    0    1    0    2    2    0    0    0    0    0    0    0    0    0
  738          -1.20           0.00    0    1   -2   -1   -2    0    0    0    0    0    0    0    0    0
  739           1.20           0.00    0    0    2    2   -1    0    0    0    0    0    0    0    0    0
  740          -1.20           0.00    0    0    2   -2    2    0   -3    3    0    0    0    0    0    0
  741           0.00           1.20    0    0    2   -2    2    0   -5    6    0    0    0    0    0    0
  742          -0.30          -0.90    0    0    1   -1    1    0    0   -1    0    3    0    0    0    0
  743          -0.30          -0.90    0    0    0    0    0    0    3   -5    0    0    0    0    0    1
  744           0.50          -0.70    0    0    0    0    0    0    0    5   -7    0    0    0    0    0
  745          -0.50          -0.70    0    0    0    0    0    0    0    1    0    3    0    0    0    2
  746          -0.90           0.30    0    0    0    0    0    0    0    0    0    4    0    0    0    2
  747          -1.20           0.00    0    0    0    0    0    0    0    0    0    2   -5    0    0    2
  748          -1.10           0.00    3    0    2   -2    0    0    0    0    0    0    0    0    0    0
  749           1.10           0.00    3   -1   -2   -1   -2    0    0    0    0    0    0    0    0    0
  750           1.10           0.00    2    0    2    2    0    0    0    0    0    0    0    0    0    0
  751          -1.10           0.00    1    2    0   -4    0    0    0    0    0    0    0    0    0    0
  752           1.10           0.00    1    0   -2    0   -3    0    0    0    0    0    0    0    0    0
  753           1.10           0.00    1   -1    2   -4    1    0    0    0    0    0    0    0    0    0
  754          -1.10           0.00    1   -1    0   -3    0    0    0    0    0    0    0    0    0    0
  755          -1.10           0.00    0    1    0    4    0    0    0    0    0    0    0    0    0    0
  756          -1.10           0.00    0    1   -2    0    0    0    0    0    0    0    0    0    0    0
  757           1.10           0.00    0    0    2   -2    1    0   -2    2    0    0    0    0    0    0
  758          -0.80          -0.30    0    0    1   -1   -1    0    0    0   -2    0    0    0    0    0
  759           1.10           0.00    0    0    0    0    1    0    0   -1    0    1    0    0    0    0
  760           0.50          -0.60    0    0    0    0    0    0    8  -13    0    0    0    0    0    1
  761           0.30           0.80    0    0    0    0    0    0    5  -10    0    0    0    0    0   -2
  762          -0.50           0.60    0    0    0    0    0    0    1    0    0    0    0    0    0    2
  763           0.80          -0.30    0    0    0    0    0    0    1   -3    0    0    0    0    0    0
  764           0.50          -0.60    0    0    0    0    0    0    0    9  -17    0    0    0    0    0
  765           0.00           1.10    0    0    0    0    0    0    0    6  -11    0    0    0    0   -2
  766           0.00           1.10    0    0    0    0    0    0    0    5   -8    0    0    0    0    0
  767           1.10           0.00    0    0    0    0    0    0    0    1   -3    0    0    0    0   -2
  768           1.00           0.00    5    0    2   -2    2    0    0    0    0    0    0    0    0    0
  769           1.00           0.00    4    0   -2   -2   -1    0    0    0    0    0    0    0    0    0
  770          -1.00           0.00    2    1    0   -4    1    0    0    0    0    0    0    0    0    0
  771          -1.00           0.00    2    1    0   -4   -1    0    0    0    0    0    0    0    0    0
  772           1.00           0.00    2    0    2    0   -1    0    0    0    0    0    0    0    0    0
  773           1.00           0.00    2    0    0    4    0    0    0    0    0    0    0    0    0    0
  774           0.60           0.40    2    0    0   -2   -1    0    0   -5    6    0    0    0    0    0
  775           0.30           0.70    2    0   -1   -1   -1    0    0   -1    0    3    0    0    0    0
  776           1.00           0.00    2    0   -4    0   -1    0    0    0    0    0    0    0    0    0
  777           1.00           0.00    1    2   -2   -4   -2    0    0    0    0    0    0    0    0    0
  778           1.00           0.00    1    1   -2    2    0    0    0    0    0    0    0    0    0    0
  779          -1.00           0.00    1    0    4   -4    2    0    0    0    0    0    0    0    0    0
  780          -1.00           0.00    0    0    4   -1    2    0    0    0    0    0    0    0    0    0
  781           0.00          -1.00    0    0    3    0    2    0    0    0    0    0    0    0    0    0
  782           0.00           1.00    0    0    1   -1    2    0    0   -1    0    2    0    0    0    0
  783           1.00           0.00    0    0    0    3    1    0    0    0    0    0    0    0    0    0
  784           0.00          -1.00    0    0    0    0    0    0    9  -12    0    0    0    0    0   -2
  785          -1.00           0.00    0    0    0    0    0    0    5   -9    0    0    0    0    0   -2
  786           0.00          -1.00    0    0    0    0    0    0    4   -4    0    0    0    0    0    1
  787           0.00          -1.00    0    0    0    0    0    0    3   -1    0    0    0    0    0    1
  788           1.00           0.00    0    0    0    0    0    0    3   -5    0    2    0    0    0    0
  789           0.50          -0.50    0    0    0    0    0    0    2   -4    0    0    0    0    0    0
  790          -1.00           0.00    0    0    0    0    0    0    1   -2    0    0    0    0    0    1
  791           1.00           0.00    0    0    0    0    0    0    0    7  -13    0    0    0    0    0
  792          -1.00           0.00    0    0    0    0    0    0    0    5   -3    0    0    0    0    2
  793          -0.30          -0.70    0    0    0    0    0    0    0    4   -8    1    5    0    0   -2
  794          -0.90           0.00    2    1   -2   -2   -1    0    0    0    0    0    0    0    0    0
  795           0.90           0.00    2    0    0    2    2    0    0    0    0    0    0    0    0    0
  796           0.50          -0.40    2    0   -1   -1   -1    0    0    3   -7    0    0    0    0    0
  797          -0.90           0.00    2   -1    0   -1    0    0    0    0    0    0    0    0    0    0
  798          -0.90           0.00    2   -2    2    0    2    0    0    0    0    0    0    0    0    0
  799          -0.90           0.00    1    3    0   -2    0    0    0    0    0    0    0    0    0    0
  800           0.90           0.00    1    0    0   -3    1    0    0    0    0    0    0    0    0    0
  801           0.90           0.00    1   -1   -2   -3   -2    0    0    0    0    0    0    0    0    0
  802           0.90           0.00    1   -2    0    0    1    0    0    0    0    0    0    0    0    0
  803          -0.90           0.00    1   -2   -2    0   -2    0    0    0    0    0    0    0    0    0
  804          -0.90           0.00    0    3    0   -2    0    0    0    0    0    0    0    0    0    0
  805           0.90           0.00    0    1    0   -2    2    0    0    0    0    0    0    0    0    0
  806           0.00           0.90    0    0    2    0    2    0    0    4   -8    3    0    0    0    0
  807           0.00           0.90    0    0    2    0    2    0    0   -4    8   -3    0    0    0    0
  808          -0.90           0.00    0    0    2    0   -2    0    0    0    0    0    0    0    0    0
  809           0.90           0.00    0    0    2   -2   -2    0    0    0    0    0    0    0    0    0
  810           0.00          -0.90    0    0    1   -1    1    0    0    1    0    0    0    0    0    0
  811           0.00           0.90    0    0    1   -1    1    0   -2    3    0    0    0    0    0    0
  812          -0.50          -0.40    0    0    0    0    2    0    0   -1    2    0    0    0    0    0
  813           0.00           0.90    0    0    0    0    0    0    7   -7    0    0    0    0    0   -1
  814           0.00           0.90    0    0    0    0    0    0    6   -7    0    0    0    0    0    0
  815          -0.90           0.00    0    0    0    0    0    0    6   -9    0    0    0    0    0   -1
  816           0.00           0.90    0    0    0    0    0    0    4   -3    0    0    0    0    0    2
  817          -0.90           0.00    0    0    0    0    0    0    0    5    0   -3    0    0    0    2
  818           0.00           0.90    0    0    0    0    0    0    0    3   -2    0    0    0    0    0
  819           0.90           0.00    0    0    0    0    0    0    0    3   -6    0    0    0    0   -1
  820           0.30           0.60    1    0    1    0    0    0    0    0    0    0    0    0    0    0
  821           0.60          -0.30    0    2   -2    0   -1    0    0    0    0    0    0    0    0    0
  822           0.30          -0.60    0    0    0    0    0    0    1   -2    0    0    0    0    0   -2
  823          -0.60           0.30    0    0    0    0    0    0    0    6   -5    0    0    0    0    2
  824           0.60          -0.30    0    0    0    0    0    0    0    2   -5    0    0    0    0   -2
  825           0.80           0.00    4    0    0    0   -1    0    0    0    0    0    0    0    0    0
  826          -0.80           0.00    3    0    2   -1    2    0    0    0    0    0    0    0    0    0
  827          -0.80           0.00    3   -1    2    0    1    0    0    0    0    0    0    0    0    0
  828           0.80           0.00    2    2    2   -2    2    0    0    0    0    0    0    0    0    0
  829          -0.80           0.00    2    0    2   -1    1    0    0    0    0    0    0    0    0    0
  830           0.30           0.50    2    0    0   -2    1    0    0   -6    8    0    0    0    0    0
  831           0.00          -0.80    2    0   -1   -1   -2    0    0   -1    0    2    0    0    0    0
  832           0.80           0.00    1    2    2   -2    1    0    0    0    0    0    0    0    0    0
  833          -0.80           0.00    1    1    0    2   -1    0    0    0    0    0    0    0    0    0
  834           0.00          -0.80    1    0    0   -2    0    0   20  -21    0    0    0    0    0    0
  835           0.80           0.00    0    2    2    0    1    0    0    0    0    0    0    0    0    0
  836          -0.80           0.00    0    0    4   -2    0    0    0    0    0    0    0    0    0    0
  837           0.80           0.00    0    0    2    0    2    0    1   -1    0    0    0    0    0    0
  838          -0.80           0.00    0    0    2    0    2    0   -1    1    0    0    0    0    0    0
  839           0.80           0.00    0    0    2   -2    1    0    0   -2    0    0    2    0    0    0
  840           0.00           0.80    0    0    2   -2    1    0    0   -8   11    0    0    0    0    0
  841           0.00           0.80    0    0    2   -2    1   -1    0    2    0    0    0    0    0    0
  842           0.30          -0.50    0    0    2   -2    0    0    0   -9   13    0    0    0    0    0
  843          -0.30           0.50    0    0    1   -1    2    0    0   -1    0   -2    5    0    0    0
  844           0.00          -0.80    0    0    1   -1    1    0    0   -1    0    0    0    2    0    0
  845           0.00          -0.80    0    0    1   -1    1    0    0   -1    0   -1    2    0    0    0
  846           0.50           0.30    0    0    1   -1    1    0    0   -1    0   -2    4    0    0    0
  847           0.80           0.00    0    0    0    1   -2    0    0    0    0    0    0    0    0    0
  848          -0.80           0.00    0    0    0    0    1    0    3   -5    0    0    0    0    0    0
  849          -0.50          -0.30    0    0    0    0    1    0    0   -8   15    0    0    0    0    0
  850           0.50           0.30    0    0    0    0    0    1    0   -4    0    0    0    0    0    0
  851           0.80           0.00    0    0    0    0    0    0    8  -12    0    0    0    0    0    0
  852          -0.80           0.00    0    0    0    0    0    0    5   -5    0    0    0    0    0    2
  853           0.00           0.80    0    0    0    0    0    0    5   -6    0    0    0    0    0    0
  854           0.80           0.00    0    0    0    0    0    0    2   -6    0    0    0    0    0   -2
  855           0.00           0.80    0    0    0    0    0    0    0    8  -15    0    0    0    0   -1
  856           0.00          -0.80    0    0    0    0    0    0    0    5   -2    0    0    0    0    2
  857          -0.50           0.30    0    0    0    0    0    0    0    5   -8    0    0    0    0   -2
  858           0.80           0.00    0    0    0    0    0    0    0    4   -4    0    0    0    0    0
  859           0.30           0.50    0    0    0    0    0    0    0    4   -8    0    0    0    0    0
  860          -0.40           0.40    0    0    0    0    0    0    0    2    2    0    0    0    0    2
  861           0.30          -0.50    0    0    0    0    0    0    0    2   -6    0    0    0    0   -2
  862          -0.40           0.40    0    0    0    0    0    0    0    1    0   -4    0    0    0    0
  863           0.00           0.80    0    0    0    0    0    0    0    0    0    0    1    0    0    2
  864          -0.70           0.00    4    0    2   -4    2    0    0    0    0    0    0    0    0    0
  865           0.70           0.00    3    1    2    0    1    0    0    0    0    0    0    0    0    0
  866           0.70           0.00    3    0   -2   -2    0    0    0    0    0    0    0    0    0    0
  867           0.70           0.00    2    0   -4    2   -2    0    0    0    0    0    0    0    0    0
  868           0.70           0.00    2   -1   -2    0   -2    0    0    0    0    0    0    0    0    0
  869           0.70           0.00    2   -2    0    0    0    0    0    0    0    0    0    0    0    0
  870           0.70           0.00    1    1    4   -2    2    0    0    0    0    0    0    0    0    0
  871          -0.70           0.00    1    1    2    1    1    0    0    0    0    0    0    0    0    0
  872           0.70           0.00    1    1    2   -4    2    0    0    0    0    0    0    0    0    0
  873           0.70           0.00    1    1    2   -4    0    0    0    0    0    0    0    0    0    0
  874           0.70           0.00    1    1    0   -1    1    0    0    0    0    0    0    0    0    0
  875           0.70           0.00    1    1    0   -3    0    0    0    0    0    0    0    0    0    0
  876           0.70           0.00    1    0    2    3    2    0    0    0    0    0    0    0    0    0
  877           0.70           0.00    1    0    2   -3    0    0    0    0    0    0    0    0    0    0
  878           0.70           0.00    1    0    0    4   -1    0    0    0    0    0    0    0    0    0
  879           0.40           0.30    1    0    0   -1    1    0    0   -3    4    0    0    0    0    0
  880           0.70           0.00    1    0    0   -2    0    0    0    1    0   -1    0    0    0    0
  881          -0.70           0.00    1    0   -2   -2   -2    0   -3    3    0    0    0    0    0    0
  882           0.70           0.00    1   -1    2   -2    0    0    0    0    0    0    0    0    0    0
  883           0.70           0.00    1   -2    0   -2   -1    0    0    0    0    0    0    0    0    0
  884          -0.70           0.00    0    2    0    2    0    0    0    0    0    0    0    0    0    0
  885           0.70           0.00    0    0    2    4    0    0    0    0    0    0    0    0    0    0
  886           0.70           0.00    0    0    2   -2    1    0    0   -2    0    3    0    0    0    0
  887          -0.70           0.00    0    0    1   -1    2    0    0    0   -2    0    0    0    0    0
  888           0.30          -0.40    0    0    1   -1    1    0    0   -1    0    0   -2    0    0    0
  889          -0.70           0.00    0    0    0    4    2    0    0    0    0    0    0    0    0    0
  890           0.00          -0.70    0    0    0    0    2    0    0    4   -8    3    0    0    0    0
  891           0.00          -0.70    0    0    0    0    2    0    0   -4    8   -3    0    0    0    0
  892          -0.30          -0.40    0    0    0    0    1    0    0   -9   17    0    0    0    0    0
  893           0.00           0.70    0    0    0    0    0    0    8   -8    0    0    0    0    0   -1
  894           0.00           0.70    0    0    0    0    0    0    8  -10    0    0    0    0    0   -1
  895           0.00          -0.70    0    0    0    0    0    0    4   -2    0    0    0    0    0    1
  896          -0.70           0.00    0    0    0    0    0    0    3   -4    0    0    0    0    0   -1
  897           0.70           0.00    0    0    0    0    0    0    3   -6    0    0    0    0    0   -1
  898          -0.70           0.00    0    0    0    0    0    0    3   -7    4    0    0    0    0    0
  899          -0.30          -0.40    0    0    0    0    0    0    1   -4    0    0    0    0    0   -2
  900           0.00           0.70    0    0    0    0    0    0    0    6    0    0    0    0    0    1
  901           0.00          -0.70    0    0    0    0    0    0    0    6   -7    0    0    0    0    2
  902           0.30          -0.40    0    0    0    0    0    0    0    4    0    0    0    0    0    0
  903          -0.70           0.00    0    0    0    0    0    0    0    4    0    0   -2    0    0    2
  904           0.00          -0.70    0    0    0    0    0    0    0    3    0    0   -2    0    0    2
  905           0.00           0.70    0    0    0    0    0    0    0    1    0   -1    0    0    0    1
  906           0.00          -0.70    0    0    0    0    0    0    0    1   -6    0    0    0    0   -2
  907           0.70           0.00    0    0    0    0    0    0    0    0    0    4   -5    0    0    2
  908          -0.70           0.00    0    0    0    0    0    0    0    0    0    0    0    2    0    2
  909           0.60           0.00    5    0    0    0    0    0    0    0    0    0    0    0    0    0
  910          -0.60           0.00    4   -1    2    0    2    0    0    0    0    0    0    0    0    0
  911          -0.60           0.00    3    0    0   -3    0    0    0    0    0    0    0    0    0    0
  912          -0.60           0.00    2    2    0   -4    0    0    0    0    0    0    0    0    0    0
  913           0.60           0.00    2    2   -2   -4   -2    0    0    0    0    0    0    0    0    0
  914          -0.60           0.00    2    1    2    1    2    0    0    0    0    0    0    0    0    0
  915           0.60           0.00    2    1    2   -4    1    0    0    0    0    0    0    0    0    0
  916           0.60           0.00    2    0    2    1    1    0    0    0    0    0    0    0    0    0
  917          -0.60           0.00    2    0    0   -2   -2    0   -3    3    0    0    0    0    0    0
  918           0.00          -0.60    2    0   -1   -1   -1    0    0   -1    0    2    0    0    0    0
  919           0.60           0.00    2    0   -2   -6   -1    0    0    0    0    0    0    0    0    0
  920          -0.60           0.00    2    0   -4   -2   -1    0    0    0    0    0    0    0    0    0
  921           0.60           0.00    2   -1    2   -1    2    0    0    0    0    0    0    0    0    0
  922          -0.60           0.00    1    0    2   -2    2    0    0   -2    0    2    0    0    0    0
  923          -0.60           0.00    1    0    0    0    0    0    0   -2    0    2    0    0    0    0
  924           0.60           0.00    1    0    0   -2    0    0    2   -2    0    0    0    0    0    0
  925           0.00          -0.60    1    0   -1    1   -1    0  -18   17    0    0    0    0    0    0
  926          -0.60           0.00    1    0   -2   -2   -3    0    0    0    0    0    0    0    0    0
  927           0.60           0.00    1   -1    2    2    0    0    0    0    0    0    0    0    0    0
  928          -0.60           0.00    1   -1    0   -4   -1    0    0    0    0    0    0    0    0    0
  929          -0.60           0.00    1   -2    2    0    1    0    0    0    0    0    0    0    0    0
  930           0.60           0.00    1   -2    0   -2    1    0    0    0    0    0    0    0    0    0
  931           0.60           0.00    0    2    2    2    2    0    0    0    0    0    0    0    0    0
  932           0.60           0.00    0    2   -2   -4   -2    0    0    0    0    0    0    0    0    0
  933          -0.60           0.00    0    1    2    3    2    0    0    0    0    0    0    0    0    0
  934           0.60           0.00    0    1    0    3    0    0    0    0    0    0    0    0    0    0
  935          -0.60           0.00    0    1    0   -4    1    0    0    0    0    0    0    0    0    0
  936          -0.60           0.00    0    0    2    0    2    0    0    1    0   -1    0    0    0    0
  937           0.60           0.00    0    0    2    0    2    0    0   -1    0    1    0    0    0    0
  938           0.00           0.60    0    0    2   -2   -1    0   -5    6    0    0    0    0    0    0
  939           0.00           0.60    0    0    1   -1    2    0    0   -1    0    1    0    0    0    0
  940           0.00          -0.60    0    0    1   -1    2    0    0   -1    0   -1    0    0    0    0
  941           0.60           0.00    0    0    0    0    1    0    2   -2    0    0    0    0    0    0
  942           0.60           0.00    0    0    0    0    0    0    8  -12    0    0    0    0    0   -2
  943           0.60           0.00    0    0    0    0    0    0    8  -16    0    0    0    0    0   -2
  944           0.00           0.60    0    0    0    0    0    0    7   -8    0    0    0    0    0    0
  945           0.30          -0.30    0    0    0    0    0    0    2   -3    0    0    0    0    0    1
  946           0.00          -0.60    0    0    0    0    0    0    0    5   -6    0    0    0    0    2
  947          -0.60           0.00    0    0    0    0    0    0    0    4   -6    0    0    0    0   -2
  948           0.00           0.60    0    0    0    0    0    0    0    4   -8    1    5    0    0    2
  949          -0.60           0.00    0    0    0    0    0    0    0    2    0   -2    0    0    0    2
  950           0.00          -0.60    0    0    0    0    0    0    0    2   -7    0    0    0    0   -2
  951           0.60           0.00    0    0    0    0    0    0    0    0    2    0    0    0    0    0
  952          -0.60           0.00    0    0    0    0    0    0    0    0    0    0    5    0    0    2
  953          -0.60           0.00    0    0    0    0    0    0    0    0    0    0    0    0    2    2
  954           0.50           0.00    4    1    2    0    2    0    0    0    0    0    0    0    0    0
  955          -0.50           0.00    4   -1   -2   -2   -2    0    0    0    0    0    0    0    0    0
  956           0.50           0.00    3    0    0   -2    1    0    0    0    0    0    0    0    0    0
  957          -0.50           0.00    3    0    0   -2    0    0    0    0    0    0    0    0    0    0
  958          -0.50           0.00    2    1    0   -2   -2    0    0    0    0    0    0    0    0    0
  959           0.50           0.00    2    1   -2    0    1    0    0    0    0    0    0    0    0    0
  960           0.50           0.00    2    1   -2   -6   -2    0    0    0    0    0    0    0    0    0
  961           0.50           0.00    2    0    4   -2    1    0    0    0    0    0    0    0    0    0
  962           0.50           0.00    2    0    0   -1    1    0    0    0    0    0    0    0    0    0
  963          -0.50           0.00    2    0    0   -2    0    0    0   -4    8   -3    0    0    0    0
  964           0.50           0.00    2    0    0   -2    0    0   -2    2    0    0    0    0    0    0
  965           0.50           0.00    2    0    0   -2   -1    0    0   -2    0    4   -5    0    0    0
  966           0.50           0.00    2    0    0   -2   -1    0   -3    3    0    0    0    0    0    0
  967           0.50           0.00    2    0    0   -3   -1    0    0    0    0    0    0    0    0    0
  968           0.00          -0.50    2    0   -1   -1   -1    0    0   -1    0    0    0    0    0    0
  969           0.50           0.00    2   -1    2   -2    1    0    0    0    0    0    0    0    0    0
  970           0.50           0.00    2   -1   -2    2   -1    0    0    0    0    0    0    0    0    0
  971           0.50           0.00    2   -2    0   -2    1    0    0    0    0    0    0    0    0    0
  972           0.50           0.00    1    1   -2    2   -2    0    0    0    0    0    0    0    0    0
  973          -0.50           0.00    1    1   -2   -3   -2    0    0    0    0    0    0    0    0    0
  974           0.00          -0.50    1    0    3    0    3    0    0    0    0    0    0    0    0    0
  975           0.00           0.50    1    0    1   -1    1    0    0   -1    0    0    0    0    0    0
  976           0.00           0.50    1    0    1   -2    0    0    0    0    0    0    0    0    0    0
  977           0.00          -0.50    1    0    0    0    0    0    0    4   -8    3    0    0    0    0
  978           0.00          -0.50    1    0    0    0    0    0    0   -4    8   -3    0    0    0    0
  979           0.50           0.00    1    0    0    0    0    0   -1    1    0    0    0    0    0    0
  980           0.50           0.00    1    0    0   -1    0    0    0   -2    2    0    0    0    0    0
  981          -0.50           0.00    1    0    0   -1   -1    0    0   -2    2    0    0    0    0    0
  982           0.00           0.50    1    0    0   -2    0    0   17  -16    0   -2    0    0    0    0
  983           0.50           0.00    1    0    0   -6   -1    0    0    0    0    0    0    0    0    0
  984           0.00          -0.50    1    0   -1    1   -1    0    0    1    0    0    0    0    0    0
  985           0.00           0.50    1    0   -1    0    1    0    0    0    0    0    0    0    0    0
  986          -0.50           0.00    1    0   -1   -1   -1    0   20  -20    0    0    0    0    0    0
  987          -0.50           0.00    1    0   -2    1    1    0    0    0    0    0    0    0    0    0
  988          -0.50           0.00    1    0   -2    0    2    0    0    0    0    0    0    0    0    0
  989           0.50           0.00    1    0   -2    0   -2    0  -10    3    0    0    0    0    0    0
  990           0.50           0.00    1    0   -2   -2   -2    0    0   -2    0    3    0    0    0    0
  991           0.50           0.00    1   -1    2    1    2    0    0    0    0    0    0    0    0    0
  992          -0.50           0.00    1   -1    0    0   -2    0    0    0    0    0    0    0    0    0
  993          -0.50           0.00    1   -1    0   -2   -2    0    0    0    0    0    0    0    0    0
  994           0.50           0.00    1   -1   -4    2   -2    0    0    0    0    0    0    0    0    0
  995           0.50           0.00    1   -2    0    0   -1    0    0    0    0    0    0    0    0    0
  996          -0.50           0.00    1   -2   -2   -2   -1    0    0    0    0    0    0    0    0    0
  997           0.50           0.00    0    3   -2   -2   -2    0    0    0    0    0    0    0    0    0
  998          -0.50           0.00    0    2    0   -4    0    0    0    0    0    0    0    0    0    0
  999           0.50           0.00    0    1    4   -2    1    0    0    0    0    0    0    0    0    0
 1000           0.50           0.00    0    1    0    4    1    0    0    0    0    0    0    0    0    0
 1001           0.50           0.00    0    0    4    2    2    0    0    0    0    0    0    0    0    0
 1002           0.50           0.00    0    0    2    3    1    0    0    0    0    0    0    0    0    0
 1003          -0.50           0.00    0    0    2   -2    2    0    0   -2    0    2    0    0    0    0
 1004           0.50           0.00    0    0    2   -2    1    0    0   -1    0    1    0    0    0    0
 1005          -0.50           0.00    0    0    2   -2    0    0    0   -2    0    2    0    0    0    0
 1006          -0.50           0.00    0    0    2   -4    0    0    0    0    0    0    0    0    0    0
 1007          -0.50           0.00    0    0    1   -1    2    0    0   -1    0    0    1    0    0    0
 1008          -0.50           0.00    0    0    1   -1    2    0   -5    7    0    0    0    0    0    0
 1009           0.00           0.50    0    0    1   -1    1    0    1   -2    0    0    0    0    0    0
 1010           0.00           0.50    0    0    1   -1    1    0   -2    1    0    0    0    0    0    0
 1011          -0.50           0.00    0    0    1   -1    0    0    0    0    0    0    0    0    0    0
 1012           0.50           0.00    0    0    0    6    0    0    0    0    0    0    0    0    0    0
 1013           0.00           0.50    0    0    0    0    1    0    5   -8    0    0    0    0    0    0
 1014           0.50           0.00    0    0    0    0    1    0    0    2   -2    0    0    0    0    0
 1015           0.00           0.50    0    0    0    0    1    0    0    0    0    0   -1    0    0    0
 1016           0.00           0.50    0    0    0    0    0    0    9   -9    0    0    0    0    0   -1
 1017           0.00           0.50    0    0    0    0    0    0    9  -11    0    0    0    0    0   -1
 1018           0.00           0.50    0    0    0    0    0    0    6  -10    0    0    0    0    0   -1
 1019           0.00          -0.50    0    0    0    0    0    0    5   -3    0    0    0    0    0    1
 1020          -0.50           0.00    0    0    0    0    0    0    4   -5    0    0    0    0    0   -1
 1021           0.00          -0.50    0    0    0    0    0    0    3   -4    0    0    0    0    0   -2
 1022           0.00          -0.50    0    0    0    0    0    0    0    6   -9    0    0    0    0    0
 1023           0.00          -0.50    0    0    0    0    0    0    0    5  -10    0    0    0    0   -2
 1024          -0.50           0.00    0    0    0    0    0    0    0    4    0   -4    0    0    0    2
 1025           0.50           0.00    0    0    0    0    0    0    0    3    0   -4    0    0    0    0
 1026          -0.50           0.00    0    0    0    0    0    0    0    2    0    0    0    0    0    0
 1027          -0.50           0.00    0    0    0    0    0    0    0    2    0   -5    0    0    0   -2
 1028           0.00           0.50    0    0    0    0    0    0    0    1    0   -2    5    0    0    2
 1029           0.50           0.00    0    0    0    0    0    0    0    1    0   -2    0    0    0   -2
 1030           0.00          -0.50    0    0    0    0    0    0    0    1    0   -3    0    0    0   -1
 1031          -0.50           0.00    0    0    0    0    0    0    0    1    0   -5    0    0    0   -2
 1032           0.00          -0.50    0    0    0    0    0    0    0    0    0    0    0    2    0    1
 1033           0.00           0.50    0    0    0    0    0    0    0    0    0    0    0    1   -2   -2
 1034           0.40           0.00    4    0    0    2    0    0    0    0    0    0    0    0    0    0
 1035           0.40           0.00    3    1    2   -2    1    0    0    0    0    0    0    0    0    0
 1036           0.40           0.00    3    0    4   -2    2    0    0    0    0    0    0    0    0    0
 1037           0.40           0.00    3    0    2    1    2    0    0    0    0    0    0    0    0    0
 1038           0.40           0.00    3    0    0    2   -1    0    0    0    0    0    0    0    0    0
 1039          -0.40           0.00    3    0    0    0    2    0    0    0    0    0    0    0    0    0
 1040           0.40           0.00    3    0    0   -1    0    0    0    0    0    0    0    0    0    0
 1041           0.40           0.00    3    0   -2    2   -1    0    0    0    0    0    0    0    0    0
 1042           0.40           0.00    3   -1    0    2    0    0    0    0    0    0    0    0    0    0
 1043           0.40           0.00    2    1    0    1    0    0    0    0    0    0    0    0    0    0
 1044          -0.40           0.00    2    1    0   -6    0    0    0    0    0    0    0    0    0    0
 1045          -0.40           0.00    2    0    4   -4    2    0    0    0    0    0    0    0    0    0
 1046           0.40           0.00    2    0    2    0    1    0    0    1    0    0    0    0    0    0
 1047          -0.40           0.00    2    0    2   -3    2    0    0    0    0    0    0    0    0    0
 1048          -0.40           0.00    2    0    0    4    1    0    0    0    0    0    0    0    0    0
 1049          -0.40           0.00    2    0    0   -2    0    0    0   -2    0    2    2    0    0    0
 1050           0.40           0.00    2    0    0   -2    0    0    0   -4    4    0    0    0    0    0
 1051           0.40           0.00    2    0    0   -3    1    0    0    0    0    0    0    0    0    0
 1052           0.40           0.00    2    0   -2   -2    1    0    0    0    0    0    0    0    0    0
 1053           0.40           0.00    2    0   -4    2   -1    0    0    0    0    0    0    0    0    0
 1054           0.40           0.00    2   -1    2    0    0    0    0    0    0    0    0    0    0    0
 1055          -0.40           0.00    2   -1    0    2    1    0    0    0    0    0    0    0    0    0
 1056           0.40           0.00    2   -1    0    2   -1    0    0    0    0    0    0    0    0    0
 1057          -0.40           0.00    2   -2    2    2    2    0    0    0    0    0    0    0    0    0
 1058          -0.10           0.30    2   -2    2   -2    2    0    0    0    0    0    0    0    0    0
 1059          -0.40           0.00    2   -2    0   -2   -2    0    0    0    0    0    0    0    0    0
 1060           0.40           0.00    1    1    2    4    2    0    0    0    0    0    0    0    0    0
 1061           0.40           0.00    1    1    0    1    1    0    0    0    0    0    0    0    0    0
 1062           0.40           0.00    1    1    0    1   -1    0    0    0    0    0    0    0    0    0
 1063           0.40           0.00    1    1   -2   -6   -2    0    0    0    0    0    0    0    0    0
 1064           0.40           0.00    1    0    2   -1    0    0    0    0    0    0    0    0    0    0
 1065          -0.40           0.00    1    0    0    0    0    0    1   -1    0    0    0    0    0    0
 1066          -0.40           0.00    1    0    0    0    0    0    0   -1    0    1    0    0    0    0
 1067          -0.40           0.00    1    0    0    0    0    0   -3    3    0    0    0    0    0    0
 1068           0.40           0.00    1    0    0   -1    1    0    0   -1    0    1    0    0    0    0
 1069          -0.40           0.00    1    0    0   -2    0    0    1   -1    0    0    0    0    0    0
 1070           0.00          -0.40    1    0    0   -2    0    0    0    4   -8    3    0    0    0    0
 1071           0.00          -0.40    1    0    0   -2    0    0    0   -4    8   -3    0    0    0    0
 1072          -0.40           0.00    1    0    0   -2    0    0   -2    2    0    0    0    0    0    0
 1073           0.40           0.00    1    0    0   -3   -1    0    0    0    0    0    0    0    0    0
 1074           0.40           0.00    1    0   -2   -6   -1    0    0    0    0    0    0    0    0    0
 1075          -0.40           0.00    1    0   -4   -2   -1    0    0    0    0    0    0    0    0    0
 1076          -0.40           0.00    1   -1    0    1    0    0    0    0    0    0    0    0    0    0
 1077           0.40           0.00    1   -1   -2   -2    0    0    0    0    0    0    0    0    0    0
 1078          -0.40           0.00    1   -1   -2   -4   -1    0    0    0    0    0    0    0    0    0
 1079          -0.40           0.00    1   -2    2    2    1    0    0    0    0    0    0    0    0    0
 1080           0.40           0.00    1   -2   -2    2   -1    0    0    0    0    0    0    0    0    0
 1081           0.40           0.00    0    2    0    0    2    0    0    0    0    0    0    0    0    0
 1082          -0.40           0.00    0    2    0    0   -2    0    0    0    0    0    0    0    0    0
 1083           0.40           0.00    0    2   -2    2   -3    0    0    0    0    0    0    0    0    0
 1084          -0.40           0.00    0    1    2    2    0    0    0    0    0    0    0    0    0    0
 1085           0.40           0.00    0    1    2   -4    2    0    0    0    0    0    0    0    0    0
 1086          -0.40           0.00    0    1   -2    4   -1    0    0    0    0    0    0    0    0    0
 1087           0.40           0.00    0    0    2    2    3    0    0    0    0    0    0    0    0    0
 1088           0.00           0.40    0    0    2   -2    1    0    0    4   -8    3    0    0    0    0
 1089          -0.40           0.00    0    0    2   -2    1    0    0    1    0   -1    0    0    0    0
 1090           0.40           0.00    0    0    2   -2    1    0    0   -3    0    3    0    0    0    0
 1091           0.00           0.40    0    0    2   -2    1    0    0   -4    8   -3    0    0    0    0
 1092           0.40           0.00    0    0    2   -2    1    0   -5    5    0    0    0    0    0    0
 1093          -0.40           0.00    0    0    2   -2    0    0   -4    4    0    0    0    0    0    0
 1094           0.40           0.00    0    0    2   -3    0    0    0    0    0    0    0    0    0    0
 1095           0.00          -0.40    0    0    1    1    0    0    0    1    0    0    0    0    0    0
 1096          -0.40           0.00    0    0    1   -1    2    0   -8   12    0    0    0    0    0    0
 1097          -0.40           0.00    0    0    1   -1    1    0    1   -3    0    0    0    0    0    0
 1098           0.00           0.40    0    0    1   -1    1    0    0   -1    0    0    0   -1    0    0
 1099           0.40           0.00    0    0    1   -1    1    0    0   -4    6    0    0    0    0    0
 1100           0.00           0.40    0    0    1   -1    1    0   -5    6    0    0    0    0    0    0
 1101           0.00           0.40    0    0    1   -1    0    0    3   -6    0    0    0    0    0    0
 1102           0.00           0.40    0    0    1   -1    0    0    0   -1    0    1    0    0    0    0
 1103           0.40           0.00    0    0    1   -1    0    0    0   -1    0    0    1    0    0    0
 1104           0.00           0.40    0    0    1   -1    0    0    0   -2    2    0    0    0    0    0
 1105           0.00          -0.40    0    0    1   -1    0    0   -3    4    0    0    0    0    0    0
 1106           0.00          -0.40    0    0    1   -1    0    0   -4    5    0    0    0    0    0    0
 1107           0.00          -0.40    0    0    1   -1   -1    0    0   -1    0   -1    0    0    0    0
 1108          -0.40           0.00    0    0    0    2    0    0    0   -1    0    1    0    0    0    0
 1109           0.00          -0.40    0    0    0    0    1    0    3   -4    0    0    0    0    0    0
 1110           0.00          -0.40    0    0    0    0    1    0    0    1    0   -2    0    0    0    0
 1111           0.40           0.00    0    0    0    0    1    0   -2    2    0    0    0    0    0    0
 1112           0.00           0.40    0    0    0    0    0    0    8   -9    0    0    0    0    0    0
 1113          -0.40           0.00    0    0    0    0    0    0    7  -10    0    0    0    0    0   -1
 1114           0.00          -0.40    0    0    0    0    0    0    5   -5    0    0    0    0    0    1
 1115           0.00          -0.40    0    0    0    0    0    0    4   -5    0    0    0    0    0   -2
 1116           0.00          -0.40    0    0    0    0    0    0    3   -6    0    0    0    0    0    0
 1117           0.00           0.40    0    0    0    0    0    0    3   -8    0    0    0    0    0   -2
 1118           0.40           0.00    0    0    0    0    0    0    2   -5    0    0    0    0    0   -1
 1119          -0.40           0.00    0    0    0    0    0    0    1    1    0    0    0    0    0    0
 1120           0.40           0.00    0    0    0    0    0    0    1   -2    0    0    0    0    0   -1
 1121           0.00          -0.40    0    0    0    0    0    0    0    7   -8    0    0    0    0    2
 1122           0.00          -0.40    0    0    0    0    0    0    0    7   -9    0    0    0    0    2
 1123           0.00           0.40    0    0    0    0    0    0    0    6  -10    0    0    0    0   -2
 1124           0.00           0.40    0    0    0    0    0    0    0    3    0    0    0    0    0    2
 1125           0.40           0.00    0    0    0    0    0    0    0    3   -8    3    0    0    0   -2
 1126           0.00           0.40    0    0    0    0    0    0    0    2    0    0   -2    0    0    1
 1127           0.40           0.00    0    0    0    0    0    0    0    2   -4    0    0    0    0    1
 1128           0.40           0.00    0    0    0    0    0    0    0    1    0    0    0    0    0   -1
 1129           0.00          -0.40    0    0    0    0    0    0    0    1    0   -1    0    0    0   -1
 1130           0.00          -0.40    0    0    0    0    0    0    0    0    0    3   -5    0    0    0
 1131          -0.40           0.00    0    0    0    0    0    0    0    0    0    2   -2    0    0    0
 1132           0.20           0.10    0    0    0    0    0    0    0    0    1    0    0    0    0    0
 1133          -0.30           0.00    5    0    2    0    1    0    0    0    0    0    0    0    0    0
 1134           0.30           0.00    4    1    2   -2    2    0    0    0    0    0    0    0    0    0
 1135           0.30           0.00    4    0   -2    0   -1    0    0    0    0    0    0    0    0    0
 1136          -0.30           0.00    4    0   -2   -2    0    0    0    0    0    0    0    0    0    0
 1137           0.30           0.00    3    1    2    2    2    0    0    0    0    0    0    0    0    0
 1138          -0.30           0.00    3    1    0   -2    0    0    0    0    0    0    0    0    0    0
 1139           0.30           0.00    3    1   -2   -6   -2    0    0    0    0    0    0    0    0    0
 1140          -0.30           0.00    3    0    0    0   -2    0    0    0    0    0    0    0    0    0
 1141          -0.30           0.00    3    0   -2   -1   -1    0    0    0    0    0    0    0    0    0
 1142          -0.30           0.00    3    0   -2   -4   -2    0    0    0    0    0    0    0    0    0
 1143           0.30           0.00    3    0   -2   -6   -1    0    0    0    0    0    0    0    0    0
 1144          -0.30           0.00    3   -1    0   -2    0    0    0    0    0    0    0    0    0    0
 1145          -0.30           0.00    3   -1    0   -3    0    0    0    0    0    0    0    0    0    0
 1146           0.30           0.00    2    2    0   -2   -1    0    0    0    0    0    0    0    0    0
 1147           0.30           0.00    2    1    2    2    1    0    0    0    0    0    0    0    0    0
 1148          -0.30           0.00    2    1    2    0    0    0    0    0    0    0    0    0    0    0
 1149          -0.30           0.00    2    1    2   -2    0    0    0    0    0    0    0    0    0    0
 1150          -0.30           0.00    2    1    2   -4    2    0    0    0    0    0    0    0    0    0
 1151           0.30           0.00    2    1    0    2    1    0    0    0    0    0    0    0    0    0
 1152           0.30           0.00    2    1    0   -3    0    0    0    0    0    0    0    0    0    0
 1153           0.30           0.00    2    1   -2    0   -2    0    0    0    0    0    0    0    0    0
 1154          -0.30           0.00    2    0    2    4    1    0    0    0    0    0    0    0    0    0
 1155           0.30           0.00    2    0    2    0    3    0    0    0    0    0    0    0    0    0
 1156           0.30           0.00    2    0    2   -2    2    0    0   -2    0    3    0    0    0    0
 1157          -0.30           0.00    2    0    2   -2   -1    0    0    0    0    0    0    0    0    0
 1158          -0.30           0.00    2    0    2   -6    1    0    0    0    0    0    0    0    0    0
 1159           0.00           0.30    2    0    1   -3    1    0   -6    7    0    0    0    0    0    0
 1160           0.30           0.00    2    0    0   -2    1    0    0   -5    6    0    0    0    0    0
 1161           0.00          -0.30    2    0    0   -2    0    0    2   -5    0    0    0    0    0    0
 1162           0.00           0.30    2    0    0   -2    0    0    0   -2    0    5   -5    0    0    0
 1163           0.30           0.00    2    0    0   -2    0    0    0   -2    0    1    5    0    0    0
 1164           0.30           0.00    2    0    0   -2    0    0    0   -2    0    0    5    0    0    0
 1165           0.30           0.00    2    0    0   -2    0    0    0   -2    0    0    2    0    0    0
 1166           0.30           0.00    2    0    0   -2    0    0   -4    4    0    0    0    0    0    0
 1167          -0.30           0.00    2    0    0   -2   -1    0    0   -2    0    3   -1    0    0    0
 1168           0.00           0.30    2    0    0   -2   -1    0    0   -6    8    0    0    0    0    0
 1169           0.30           0.00    2    0    0   -4    2    0    0    0    0    0    0    0    0    0
 1170           0.30           0.00    2    0    0   -4   -2    0    0    0    0    0    0    0    0    0
 1171           0.30           0.00    2    0    0   -6   -1    0    0    0    0    0    0    0    0    0
 1172           0.30           0.00    2    0   -1   -1    1    0    0    3   -7    0    0    0    0    0
 1173           0.00           0.30    2    0   -1   -1    0    0    0   -1    0    3    0    0    0    0
 1174           0.00           0.30    2    0   -2    0   -2    0    0    5   -9    0    0    0    0    0
 1175           0.30           0.00    2    0   -2   -2   -2    0    0   -2    0    2    0    0    0    0
 1176          -0.30           0.00    2    0   -2   -5   -2    0    0    0    0    0    0    0    0    0
 1177          -0.30           0.00    2   -1    2    4    2    0    0    0    0    0    0    0    0    0
 1178           0.30           0.00    2   -1    0   -2    2    0    0    0    0    0    0    0    0    0
 1179           0.30           0.00    2   -1   -2    0    1    0    0    0    0    0    0    0    0    0
 1180           0.30           0.00    2   -1   -2   -2   -1    0    0    0    0    0    0    0    0    0
 1181           0.30           0.00    1    3   -2   -2   -2    0    0    0    0    0    0    0    0    0
 1182           0.30           0.00    1    2    2    0    1    0    0    0    0    0    0    0    0    0
 1183          -0.30           0.00    1    2    2   -4    1    0    0    0    0    0    0    0    0    0
 1184          -0.30           0.00    1    2    0    0    1    0    0    0    0    0    0    0    0    0
 1185           0.30           0.00    1    1    0    0   -2    0    0    0    0    0    0    0    0    0
 1186          -0.30           0.00    1    1    0   -6    0    0    0    0    0    0    0    0    0    0
 1187           0.30           0.00    1    1   -2    1   -2    0    0    0    0    0    0    0    0    0
 1188          -0.30           0.00    1    1   -2   -1   -2    0    0    0    0    0    0    0    0    0
 1189           0.30           0.00    1    0    4    0    1    0    0    0    0    0    0    0    0    0
 1190          -0.30           0.00    1    0    2    1    0    0    0    0    0    0    0    0    0    0
 1191           0.30           0.00    1    0    2    0    2    0    1   -1    0    0    0    0    0    0
 1192           0.00           0.30    1    0    2    0    2    0    0    4   -8    3    0    0    0    0
 1193           0.00           0.30    1    0    2    0    2    0    0   -4    8   -3    0    0    0    0
 1194          -0.30           0.00    1    0    2    0    2    0   -1    1    0    0    0    0    0    0
 1195          -0.30           0.00    1    0    2   -2    3    0    0    0    0    0    0    0    0    0
 1196          -0.30           0.00    1    0    2   -2    2    0   -3    3    0    0    0    0    0    0
 1197           0.30           0.00    1    0    2   -4   -1    0    0    0    0    0    0    0    0    0
 1198          -0.30           0.00    1    0    2   -6    1    0    0    0    0    0    0    0    0    0
 1199           0.00           0.30    1    0    1    1    1    0    0    1    0    0    0    0    0    0
 1200          -0.30           0.00    1    0    0    3    0    0    0    0    0    0    0    0    0    0
 1201           0.30           0.00    1    0    0    0    1    0  -10    3    0    0    0    0    0    0
 1202           0.30           0.00    1    0    0    0    0    0    0    1    0   -1    0    0    0    0
 1203           0.30           0.00    1    0    0    0    0    0    0   -2    0    3    0    0    0    0
 1204           0.30           0.00    1    0    0    0   -1    0  -10    3    0    0    0    0    0    0
 1205           0.30           0.00    1    0    0   -1   -1    0    0   -3    4    0    0    0    0    0
 1206           0.30           0.00    1    0    0   -2    1    0    0   -2    0    2    0    0    0    0
 1207          -0.30           0.00    1    0    0   -2    0    0    0    2    0   -2    0    0    0    0
 1208           0.30           0.00    1    0    0   -2   -1    0    0   -2    0    2    0    0    0    0
 1209           0.30           0.00    1    0    0   -4    2    0    0    0    0    0    0    0    0    0
 1210           0.00           0.30    1    0   -1    1    0    0    0    1    0    0    0    0    0    0
 1211           0.30           0.00    1    0   -1    0   -1    0   -3    5    0    0    0    0    0    0
 1212          -0.30           0.00    1    0   -1   -1    0    0    0    8  -15    0    0    0    0    0
 1213           0.00          -0.30    1    0   -1   -2   -1    0    0    0    0    0    0    0    0    0
 1214          -0.30           0.00    1    0   -2    4   -2    0    0    0    0    0    0    0    0    0
 1215          -0.30           0.00    1    0   -2   -2   -2    0    0    1    0   -1    0    0    0    0
 1216          -0.30           0.00    1   -1    2    4    1    0    0    0    0    0    0    0    0    0
 1217           0.30           0.00    1   -1    2   -3    1    0    0    0    0    0    0    0    0    0
 1218          -0.30           0.00    1   -1    0    4    1    0    0    0    0    0    0    0    0    0
 1219           0.30           0.00    1   -1   -2    1   -1    0    0    0    0    0    0    0    0    0
 1220          -0.30           0.00    1   -2    0   -1    0    0    0    0    0    0    0    0    0    0
 1221           0.30           0.00    0    1    4   -4    4    0    0    0    0    0    0    0    0    0
 1222          -0.30           0.00    0    1    4   -4    2    0    0    0    0    0    0    0    0    0
 1223           0.30           0.00    0    1   -4    2   -1    0    0    0    0    0    0    0    0    0
 1224           0.30           0.00    0    0    4   -2    3    0    0    0    0    0    0    0    0    0
 1225           0.30           0.00    0    0    2    2    2    0    0    2    0   -2    0    0    0    0
 1226          -0.30           0.00    0    0    2    0    2    0    2   -2    0    0    0    0    0    0
 1227           0.00           0.30    0    0    2    0    2    0    2   -3    0    0    0    0    0    0
 1228           0.00           0.30    0    0    2    0    2    0   -2    3    0    0    0    0    0    0
 1229           0.30           0.00    0    0    2    0    2    0   -2    2    0    0    0    0    0    0
 1230           0.30           0.00    0    0    2   -2    1    0    1   -1    0    0    0    0    0    0
 1231          -0.30           0.00    0    0    2   -2    1    0    0   -2    0    1    0    0    0    0
 1232          -0.30           0.00    0    0    2   -2    1    0    0   -2    0    0    0    0    0    0
 1233           0.30           0.00    0    0    2   -2    1    0    0   -4    4    0    0    0    0    0
 1234           0.00           0.30    0    0    2   -2    1    0    0   -7    9    0    0    0    0    0
 1235          -0.30           0.00    0    0    2   -2    1    0    0  -10   15    0    0    0    0    0
 1236           0.00           0.30    0    0    2   -2    1    0   -8   11    0    0    0    0    0    0
 1237           0.00          -0.30    0    0    2   -2    0   -1    0    2    0    0    0    0    0    0
 1238           0.00          -0.30    0    0    1    1    2    0    0    1    0    0    0    0    0    0
 1239          -0.30           0.00    0    0    1   -1    2    0    0   -1    0    0   -1    0    0    0
 1240           0.00          -0.30    0    0    1   -1    2    0   -3    4    0    0    0    0    0    0
 1241           0.30           0.00    0    0    1   -1    1    0    0    1   -4    0    0    0    0    0
 1242           0.00           0.30    0    0    1   -1    1    0    0   -1    0    1   -3    0    0    0
 1243           0.00           0.30    0    0    1   -1    1    0   -1    2    0    0    0    0    0    0
 1244           0.30           0.00    0    0    1   -1    1    0   -4    6    0    0    0    0    0    0
 1245           0.00           0.30    0    0    1   -1    0    0    0    1    0    0    0    0    0    0
 1246           0.00           0.30    0    0    1   -1    0    0    0   -1    0    0   -2    0    0    0
 1247           0.00          -0.30    0    0    1   -1    0    0   -1    0    0    0    0    0    0    0
 1248          -0.30           0.00    0    0    1   -1    0    0   -2    2    0    0    0    0    0    0
 1249           0.30           0.00    0    0    1   -1   -1    0   -5    7    0    0    0    0    0    0
 1250           0.30           0.00    0    0    0    3    2    0    0    0    0    0    0    0    0    0
 1251          -0.30           0.00    0    0    0    2    0    0    0    2    0   -2    0    0    0    0
 1252          -0.30           0.00    0    0    0    2    0    0   -2    2    0    0    0    0    0    0
 1253           0.00          -0.30    0    0    0    0    2    0    0    0    0    1    0    0    0    0
 1254           0.30           0.00    0    0    0    0    2    0   -3    5    0    0    0    0    0    0
 1255          -0.30           0.00    0    0    0    0    1    0    0    7  -13    0    0    0    0    0
 1256          -0.30           0.00    0    0    0    0    1    0    0    2    0   -2    0    0    0    0
 1257           0.00           0.30    0    0    0    0    1    0    0   -1    0    2    0    0    0    0
 1258           0.30           0.00    0    0    0    0    1    0    0   -2    2    0    0    0    0    0
 1259           0.00           0.30    0    0    0    0    1    0   -1    2    0    0    0    0    0    0
 1260           0.00           0.30    0    0    0    0    1    0   -3    4    0    0    0    0    0    0
 1261           0.30           0.00    0    0    0    0    0    0    9  -13    0    0    0    0    0   -2
 1262          -0.30           0.00    0    0    0    0    0    0    8  -11    0    0    0    0    0   -1
 1263           0.30           0.00    0    0    0    0    0    0    8  -14    0    0    0    0    0   -2
 1264           0.00          -0.30    0    0    0    0    0    0    7  -11    0    0    0    0    0   -1
 1265           0.00          -0.30    0    0    0    0    0    0    6   -4    0    0    0    0    0    1
 1266           0.00          -0.30    0    0    0    0    0    0    6   -6    0    0    0    0    0    1
 1267          -0.30           0.00    0    0    0    0    0    0    6   -7    0    0    0    0    0   -1
 1268          -0.30           0.00    0    0    0    0    0    0    6   -8    0    0    0    0    0    0
 1269           0.00          -0.30    0    0    0    0    0    0    6   -9    0    0    0    0    0    0
 1270           0.00           0.30    0    0    0    0    0    0    5   -4    0    0    0    0    0    2
 1271          -0.30           0.00    0    0    0    0    0    0    5   -6    0    0    0    0    0   -1
 1272           0.00          -0.30    0    0    0    0    0    0    5   -6    0    0    0    0    0   -2
 1273          -0.30           0.00    0    0    0    0    0    0    5   -6   -4    0    0    0    0   -2
 1274           0.00           0.30    0    0    0    0    0    0    4   -2    0    0    0    0    0    0
 1275           0.00          -0.30    0    0    0    0    0    0    4   -5    0    0    0    0    0    0
 1276           0.30           0.00    0    0    0    0    0    0    4   -8    0    0    0    0    0   -2
 1277          -0.30           0.00    0    0    0    0    0    0    3   -1    0    0    0    0    0    0
 1278          -0.30           0.00    0    0    0    0    0    0    3   -3    0    2    0    0    0    2
 1279           0.30           0.00    0    0    0    0    0    0    3   -4    0    0    0    0    0    1
 1280           0.00           0.30    0    0    0    0    0    0    2    1    0    0    0    0    0    1
 1281          -0.30           0.00    0    0    0    0    0    0    2    0    0    0    0    0    0    0
 1282           0.30           0.00    0    0    0    0    0    0    1   -1    0    0    0    0    0   -2
 1283           0.30           0.00    0    0    0    0    0    0    1   -4    0    0    0    0    0   -1
 1284          -0.30           0.00    0    0    0    0    0    0    0    9  -17    0    0    0    0   -2
 1285           0.00           0.30    0    0    0    0    0    0    0    7   -7    0    0    0    0    2
 1286           0.00           0.30    0    0    0    0    0    0    0    7  -12    0    0    0    0   -2
 1287          -0.30           0.00    0    0    0    0    0    0    0    6   -4    0    0    0    0    2
 1288           0.00          -0.30    0    0    0    0    0    0    0    6   -8    1    5    0    0    2
 1289          -0.30           0.00    0    0    0    0    0    0    0    6   -9    0    0    0    0   -2
 1290           0.00           0.30    0    0    0    0    0    0    0    6  -10    0    0    0    0    0
 1291          -0.30           0.00    0    0    0    0    0    0    0    5    0   -4    0    0    0    2
 1292           0.30           0.00    0    0    0    0    0    0    0    5   -6    0    0    0    0    0
 1293          -0.30           0.00    0    0    0    0    0    0    0    5   -7    0    0    0    0   -2
 1294          -0.30           0.00    0    0    0    0    0    0    0    5   -8    3    0    0    0    2
 1295          -0.30           0.00    0    0    0    0    0    0    0    5   -9    0    0    0    0   -1
 1296          -0.30           0.00    0    0    0    0    0    0    0    5  -13    0    0    0    0   -2
 1297           0.30           0.00    0    0    0    0    0    0    0    5  -16    4    5    0    0   -2
 1298          -0.30           0.00    0    0    0    0    0    0    0    4   -7    0    0    0    0   -1
 1299           0.30           0.00    0    0    0    0    0    0    0    4   -8    3    0    0    0    1
 1300           0.30           0.00    0    0    0    0    0    0    0    4   -8    3    0    0    0   -1
 1301          -0.30           0.00    0    0    0    0    0    0    0    3    0   -5    0    0    0   -2
 1302           0.00          -0.30    0    0    0    0    0    0    0    3   -5    0    0    0    0   -1
 1303           0.00          -0.30    0    0    0    0    0    0    0    3   -7    0    0    0    0   -2
 1304           0.00          -0.30    0    0    0    0    0    0    0    3   -9    0    0    0    0   -2
 1305           0.30           0.00    0    0    0    0    0    0    0    2    1    0    0    0    0    2
 1306           0.30           0.00    0    0    0    0    0    0    0    2    0    2    0    0    0    2
 1307           0.00           0.30    0    0    0    0    0    0    0    2    0    0   -3    0    0    0
 1308           0.00          -0.30    0    0    0    0    0    0    0    2   -8    1    5    0    0   -2
 1309           0.00           0.30    0    0    0    0    0    0    0    1    0    1    0    0    0    1
 1310          -0.30           0.00    0    0    0    0    0    0    0    1    0    1   -5    0    0    0
 1311           0.00          -0.30    0    0    0    0    0    0    0    1    0    0    2    0    0    2
 1312          -0.30           0.00    0    0    0    0    0    0    0    1    0    0   -3    0    0    0
 1313           0.30           0.00    0    0    0    0    0    0    0    1    0   -3    5    0    0    0
 1314           0.00           0.30    0    0    0    0    0    0    0    1   -3    0    0    0    0    0
 1315           0.30           0.00    0    0    0    0    0    0    0    0    0    2   -6    3    0   -2
 1316           0.00           0.30    0    0    0    0    0    0    0    0    0    1   -2    0    0    0
 1317           0.00           0.30    0    0    0    0    0    0    0    0    0    0    0    1    0    0
 1318           0.30           0.00    0    0    0    0    0    0    0    0    0    0    0    0    0    2
 1319          -0.10           0.00    0    0    0    0    0    1    0   -3    0    0    0    0    0   -2
 1320          -0.10           0.00    0    0    0    0    0    0    0    1    0    1   -2    0    0    0
]'

const coefs_iau2006_nut_lon1 = Float64[
 1321      -17418.82           2.89    0    0    0    0    1    0    0    0    0    0    0    0    0    0
 1322        -363.71          -1.50    0    1    0    0    0    0    0    0    0    0    0    0    0    0
 1323        -163.84           1.20    0    0    2   -2    2    0    0    0    0    0    0    0    0    0
 1324         122.74           0.20    0    1    2   -2    2    0    0    0    0    0    0    0    0    0
 1325          49.46           0.00    0    1   -2    2   -2    0    0    0    0    0    0    0    0    0
 1326         -36.59           0.10    0    0    2    0    1    0    0    0    0    0    0    0    0    0
 1327         -22.77           0.20    0    0    2    0    2    0    0    0    0    0    0    0    0    0
 1328          20.12           0.00    0    0    0    0    2    0    0    0    0    0    0    0    0    0
 1329          13.66           0.00    0    0    2   -2    1    0    0    0    0    0    0    0    0    0
 1330          -8.50           0.00    0    2    0    0    0    0    0    0    0    0    0    0    0    0
 1331           7.20           0.00    0    2    2   -2    2    0    0    0    0    0    0    0    0    0
 1332           7.10           0.00    1    0    0    0    0    0    0    0    0    0    0    0    0    0
 1333           6.28           0.00    1    0    0    0   -1    0    0    0    0    0    0    0    0    0
 1334           6.28           0.00    1    0    0    0    1    0    0    0    0    0    0    0    0    0
 1335          -4.99           0.00    2    0   -2    0   -1    0    0    0    0    0    0    0    0    0
 1336          -4.19           0.00    1    0    2    0    1    0    0    0    0    0    0    0    0    0
 1337          -3.52           0.00    1    0    2    0    2    0    0    0    0    0    0    0    0    0
 1338          -2.50           0.00    0    1    0    0    1    0    0    0    0    0    0    0    0    0
 1339          -2.10           0.00    0    1    2    0    2    0    0    0    0    0    0    0    0    0
 1340          -2.10           0.00    0    1   -2    0   -2    0    0    0    0    0    0    0    0    0
 1341          -2.09           0.00    1    0   -2    0   -1    0    0    0    0    0    0    0    0    0
 1342          -1.10           0.00    0    1    0    0   -1    0    0    0    0    0    0    0    0    0
 1343           1.10           0.00    1    0   -2   -2    0    0    0    0    0    0    0    0    0    0
 1344           1.10           0.00    0    1   -2    2   -1    0    0    0    0    0    0    0    0    0
 1345           1.10           0.00    0    0    0    2   -1    0    0    0    0    0    0    0    0    0
 1346           1.10           0.00    2    0    0   -2   -1    0    0    0    0    0    0    0    0    0
 1347          -1.10           0.00    0    0    0    2    1    0    0    0    0    0    0    0    0    0
 1348          -1.10           0.00    0    0    2    2    1    0    0    0    0    0    0    0    0    0
 1349           1.08           0.00    1    0   -2   -2   -2    0    0    0    0    0    0    0    0    0
 1350           1.08           0.00    0    0    0    2    0    0    0    0    0    0    0    0    0    0
 1351          -1.07           0.00    1    0   -2    0   -2    0    0    0    0    0    0    0    0    0
 1352           1.00           0.00    1    0    2   -2    1    0    0    0    0    0    0    0    0    0
 1353          -1.00           0.00    1    0    0   -2    1    0    0    0    0    0    0    0    0    0
 1354          -1.00           0.00    1    0    0   -2   -1    0    0    0    0    0    0    0    0    0
 1355          -0.96           0.00    1    0    0   -2    0    0    0    0    0    0    0    0    0    0
 1356          -0.09           0.00    2    0    2    0    2    0    0    0    0    0    0    0    0    0
 1357          -0.09           0.00    0    0    2    2    2    0    0    0    0    0    0    0    0    0
 1358          -0.01           0.00    2    0    0   -2    0    0    0    0    0    0    0    0    0    0
]'

const coefs_iau2006_nut_obl0 = Float64[
    1        1537.70     9205233.10    0    0    0    0    1    0    0    0    0    0    0    0    0    0
    2        -458.70      573033.60    0    0    2   -2    2    0    0    0    0    0    0    0    0    0
    3         137.40       97846.10    0    0    2    0    2    0    0    0    0    0    0    0    0    0
    4         -29.10      -89749.20    0    0    0    0    2    0    0    0    0    0    0    0    0    0
    5         -17.40       22438.60    0    1    2   -2    2    0    0    0    0    0    0    0    0    0
    6          31.80       20073.00    0    0    2    0    1    0    0    0    0    0    0    0    0    0
    7          36.70       12902.60    1    0    2    0    2    0    0    0    0    0    0    0    0    0
    8         -13.20       -9592.90    0    1   -2    2   -2    0    0    0    0    0    0    0    0    0
    9        -192.40        7387.10    0    1    0    0    0    0    0    0    0    0    0    0    0    0
   10           3.90       -6898.20    0    0    2   -2    1    0    0    0    0    0    0    0    0    0
   11           0.40       -5331.10    1    0   -2    0   -2    0    0    0    0    0    0    0    0    0
   12          -0.90       -3322.80    1    0    0    0    1    0    0    0    0    0    0    0    0    0
   13           7.50        3142.90    1    0    0    0   -1    0    0    0    0    0    0    0    0    0
   14           7.80        2636.60    1    0    2    0    1    0    0    0    0    0    0    0    0    0
   15          -6.60        2554.50    1    0   -2   -2   -2    0    0    0    0    0    0    0    0    0
   16          -2.00       -2423.60    2    0   -2    0   -1    0    0    0    0    0    0    0    0    0
   17           6.80        1645.00    0    0    2    2    2    0    0    0    0    0    0    0    0    0
   18           0.00       -1387.00    0    2   -2    2   -2    0    0    0    0    0    0    0    0    0
   19           5.90        1323.80    2    0    2    0    2    0    0    0    0    0    0    0    0    0
   20          -0.30       -1233.80    1    0    2   -2    2    0    0    0    0    0    0    0    0    0
   21           0.30       -1075.80    1    0   -2    0   -1    0    0    0    0    0    0    0    0    0
   22          -4.50         855.10    0    1    0    0    1    0    0    0    0    0    0    0    0    0
   23           0.10        -800.10    1    0    0   -2   -1    0    0    0    0    0    0    0    0    0
   24          35.80        -675.00    1    0    0    0    0    0    0    0    0    0    0    0    0    0
   25          -1.40         695.30    1    0    0   -2    1    0    0    0    0    0    0    0    0    0
   26          -0.50         685.00    0    2    2   -2    2    0    0    0    0    0    0    0    0    0
   27          -2.60         641.50    0    1    0    0   -1    0    0    0    0    0    0    0    0    0
   28          -1.50         522.20    1    0   -2   -2   -1    0    0    0    0    0    0    0    0    0
   29         273.50         164.70    0    0    1   -1    1    0    0   -1    0   -2    5    0    0    0
   30           1.40         335.30    0    0    2    2    1    0    0    0    0    0    0    0    0    0
   31           1.90         326.60    1    0    2    2    2    0    0    0    0    0    0    0    0    0
   32           0.40         327.20    0    0    0    2    1    0    0    0    0    0    0    0    0    0
   33          -0.50        -325.00    0    1    2    0    2    0    0    0    0    0    0    0    0    0
   34          -0.40         307.00    0    1   -2    0   -2    0    0    0    0    0    0    0    0    0
   35           0.50         304.10    2    0    0   -2   -1    0    0    0    0    0    0    0    0    0
   36          -0.10        -304.50    1    0    2   -2    1    0    0    0    0    0    0    0    0    0
   37          -0.40        -276.80    2    0    2   -2    2    0    0    0    0    0    0    0    0    0
   38           0.90         272.00    0    0    0    2   -1    0    0    0    0    0    0    0    0    0
   39           0.30         271.90    0    1   -2    2   -1    0    0    0    0    0    0    0    0    0
   40           1.20         269.50    2    0    2    0    1    0    0    0    0    0    0    0    0    0
   41           0.10        -220.60    2    0    0   -2    1    0    0    0    0    0    0    0    0    0
   42         128.60         -77.10    0    0    0    0    0    0    0    0    0    2   -5    0    0   -1
   43           0.10        -190.00    0    1    2   -2    1    0    0    0    0    0    0    0    0    0
   44         167.90           0.00    0    1   -1    1   -1    0    0    0    0    0    0    0    0    0
   45          -8.20        -123.50    1    0    0   -2    0    0    0    0    0    0    0    0    0    0
   46           0.10         131.10    2    0   -2    0   -2    0    0    0    0    0    0    0    0    0
   47           0.40         126.60    2    0    0    0   -1    0    0    0    0    0    0    0    0    0
   48           2.90        -122.00    0    0    0    2    0    0    0    0    0    0    0    0    0    0
   49           0.70         123.20    3    0    2    0    2    0    0    0    0    0    0    0    0    0
   50           0.40         123.20    1   -1    2    0    2    0    0    0    0    0    0    0    0    0
   51          -0.30         120.70    1    1   -2   -2   -2    0    0    0    0    0    0    0    0    0
   52          -0.50         112.90    0    1   -2   -2   -2    0    0    0    0    0    0    0    0    0
   53          -0.20        -112.90    2    0    0    0    1    0    0    0    0    0    0    0    0    0
   54           0.20         107.30    1    0   -2    2   -1    0    0    0    0    0    0    0    0    0
   55          -0.30        -106.20    1    1    2    0    2    0    0    0    0    0    0    0    0    0
   56          31.90         -64.10    0    0    1   -1    1    0   -8   12    0    0    0    0    0    0
   57           0.00          89.50    0    0    0    0    0    0    3   -5    0    0    0    0    0   -2
   58          89.10           0.00    1    0   -1    0   -1    0    0    0    0    0    0    0    0    0
   59           0.00          85.40    1    0    0    0    2    0    0    0    0    0    0    0    0    0
   60          -0.20         -71.00    0    0    2    1    2    0    0    0    0    0    0    0    0    0
   61           0.00         -70.00    1   -1    0   -1   -1    0    0    0    0    0    0    0    0    0
   62          13.90         -55.30    1    0    0   -1    0    0    0    0    0    0    0    0    0    0
   63           0.00          67.20    0    2   -2    2   -1    0    0    0    0    0    0    0    0    0
   64           0.40          66.30    1    0    2    2    1    0    0    0    0    0    0    0    0    0
   65          -0.40          64.70    1    0   -2   -4   -2    0    0    0    0    0    0    0    0    0
   66           1.30         -60.90    2    0    0    0    0    0    0    0    0    0    0    0    0    0
   67          -0.20         -61.00    1    0    0    0   -2    0    0    0    0    0    0    0    0    0
   68           0.20         -59.20    2    0   -2   -2   -2    0    0    0    0    0    0    0    0    0
   69           1.10         -55.00    0    0    2    0    0    0    0    0    0    0    0    0    0    0
   70           0.00         -55.60    1    1    2   -2    2    0    0    0    0    0    0    0    0    0
   71          -0.10         -52.70    2    0    2   -2    1    0    0    0    0    0    0    0    0    0
   72          -0.20          51.80    2    0   -2   -4   -2    0    0    0    0    0    0    0    0    0
   73           1.00         -49.50    1    0    0   -1   -1    0    0    0    0    0    0    0    0    0
   74           0.00          50.50    0    0    0    0    0    0    0    0    0    2    0    0    0    2
   75           2.50          47.70    2    0    0   -2    0    0    0    0    0    0    0    0    0    0
   76           0.10          49.60    1    0    0    2    1    0    0    0    0    0    0    0    0    0
   77           0.10         -49.00    1    0   -4    0   -2    0    0    0    0    0    0    0    0    0
   78         -23.20          24.60    0    0    0    0    1    0    0   -1    2    0    0    0    0    0
   79           0.40          46.50    2    0    2    2    2    0    0    0    0    0    0    0    0    0
   80          -0.10         -44.00    0    0    2   -2   -1    0    0    0    0    0    0    0    0    0
   81          -0.10         -42.20    0    1    2    0    1    0    0    0    0    0    0    0    0    0
   82          13.30          26.90    0    0    0    0    0    0    8  -13    0    0    0    0    0   -1
   83          -0.10         -39.90    3    0    2   -2    2    0    0    0    0    0    0    0    0    0
   84          -0.10         -39.50    0    0    4   -2    2    0    0    0    0    0    0    0    0    0
   85           0.00         -39.10    1    1    0   -2   -1    0    0    0    0    0    0    0    0    0
   86          -0.10         -38.90    2    0   -2    0    1    0    0    0    0    0    0    0    0    0
   87           0.10          36.90    0    0    2    0   -1    0    0    0    0    0    0    0    0    0
   88          -0.10          34.60    0    1   -2    0   -1    0    0    0    0    0    0    0    0    0
   89           0.20         -32.60    0    1    0    0    2    0    0    0    0    0    0    0    0    0
   90          -0.10          31.60    1    1    0   -2    1    0    0    0    0    0    0    0    0    0
   91           0.00          30.40    0    0    2   -1    2    0    0    0    0    0    0    0    0    0
   92           0.20          29.40    0    0    2    4    2    0    0    0    0    0    0    0    0    0
   93           0.00         -27.90    1   -1    0    0    1    0    0    0    0    0    0    0    0    0
   94           0.10          27.50    1    0    0    2   -1    0    0    0    0    0    0    0    0    0
   95         -25.70          -1.70    0    0    1   -1    1    0    0   -1    0    2   -5    0    0    0
   96           0.00          25.80    1   -1    0   -1   -2    0    0    0    0    0    0    0    0    0
   97          19.90           5.90    0    0    0    0    0    0    0    2   -8    3    0    0    0   -2
   98           0.20          25.20    1   -1    2    2    2    0    0    0    0    0    0    0    0    0
   99           0.00         -25.30    0    1    0    0   -2    0    0    0    0    0    0    0    0    0
  100           0.20          25.00    3    0    2    0    1    0    0    0    0    0    0    0    0    0
  101          -0.10          24.40    1    0    2   -4    1    0    0    0    0    0    0    0    0    0
  102           0.10         -24.40    1   -1   -2   -2   -2    0    0    0    0    0    0    0    0    0
  103         -23.30           0.90    0    0    2   -2    1    0   -5    6    0    0    0    0    0    0
  104          -0.10          24.00    1    1   -2   -2   -1    0    0    0    0    0    0    0    0    0
  105         -18.00          -5.30    0    0    0    0    0    0    0    6   -8    3    0    0    0    2
  106          -0.10         -22.80    0    1    2    2    2    0    0    0    0    0    0    0    0    0
  107          -0.10          22.50    0    1   -2   -2   -1    0    0    0    0    0    0    0    0    0
  108           0.10          21.60    1   -1    2    0    1    0    0    0    0    0    0    0    0    0
  109           0.00         -21.30    0    0    0    0    0    0    4   -6    0    0    0    0    0   -2
  110           0.10          20.70    2   -1    2    0    2    0    0    0    0    0    0    0    0    0
  111           0.70         -20.10    0    0    0    0    0    0    0    3    0   -1    0    0    0    2
  112           0.00          20.50    0    0    0    1    1    0    0    0    0    0    0    0    0    0
  113          15.90          -4.50    0    0    0    0    1    0    0   -4    8   -3    0    0    0    0
  114           0.00          20.10    0    0    0    2    2    0    0    0    0    0    0    0    0    0
  115           0.20         -19.90    1    0    0    2    0    0    0    0    0    0    0    0    0    0
  116           0.00         -20.00    1   -1   -2    0   -2    0    0    0    0    0    0    0    0    0
  117          15.60           4.40    0    0    0    0    1    0    0    4   -8    3    0    0    0    0
  118           0.00          19.80    0    0    0    0    0    0    2   -4    0    0    0    0    0   -2
  119           0.00          18.90    1    1    0    0    1    0    0    0    0    0    0    0    0    0
  120           4.30         -14.60    0    0    1   -1    1    0    0    0   -2    0    0    0    0    0
  121          -0.10         -18.50    1    1    2    0    1    0    0    0    0    0    0    0    0    0
  122          -0.10          18.40    0    1    0   -2    1    0    0    0    0    0    0    0    0    0
  123           0.00          18.10    0    3    2   -2    2    0    0    0    0    0    0    0    0    0
  124          -1.30         -16.70    0    0    2   -2    0    0    0    0    0    0    0    0    0    0
  125           1.00          16.80    0    2    0    0    0    0    0    0    0    0    0    0    0    0
  126          -0.10         -17.60    2    1    2    0    2    0    0    0    0    0    0    0    0    0
  127         -17.60           0.00    1    0   -1    0   -2    0    0    0    0    0    0    0    0    0
  128           0.00         -17.40    0    0    0    1   -1    0    0    0    0    0    0    0    0    0
  129          14.50          -2.70    0    0    0    0    0    0    0    0    0    2    0    0    0    1
  130           0.00          17.10    1    0    0   -2   -2    0    0    0    0    0    0    0    0    0
  131           0.10         -17.00    0    0    2   -2    3    0    0    0    0    0    0    0    0    0
  132           0.00          16.20    1   -1    0    0   -1    0    0    0    0    0    0    0    0    0
  133           0.00         -16.00    0    0    0    0    0    0    2    0    0    0    0    0    0    2
  134           0.00         -15.40    1    0   -2    2   -2    0    0    0    0    0    0    0    0    0
  135           0.00         -15.10    2    0    0   -2   -1    0    0   -2    0    2    0    0    0    0
  136           0.00          14.70    0    0    0    0    0    0    1    1    0    0    0    0    0    2
  137          -0.10         -14.30    1    0    2    1    2    0    0    0    0    0    0    0    0    0
  138           0.00          14.40    1    0    2   -1    2    0    0    0    0    0    0    0    0    0
  139           0.00         -14.40    0    0    2    1    1    0    0    0    0    0    0    0    0    0
  140           0.00         -13.80    1    0   -2    0    1    0    0    0    0    0    0    0    0    0
  141         -13.80           0.00    0    0    1    0    1    0    0    0    0    0    0    0    0    0
  142           4.50          -9.30    0    0    1   -1    1    0    0   -1    0    0   -1    0    0    0
  143           0.00         -13.40    1    0    0   -2    2    0    0    0    0    0    0    0    0    0
  144          -0.10          13.10    1    0   -2   -4   -1    0    0    0    0    0    0    0    0    0
  145          10.30           2.70    0    0    1   -1    1    0    0   -1    0   -1    0    0    0    0
  146           0.00         -12.80    1    1    2   -2    1    0    0    0    0    0    0    0    0    0
  147           0.00          12.80    1    0   -2    1   -1    0    0    0    0    0    0    0    0    0
  148          11.70           0.80    0    0    0    0    0    0    0    0    0    2   -5    0    0    1
  149           0.00         -12.00    2    0   -2   -2   -1    0    0    0    0    0    0    0    0    0
  150          11.30           0.50    0    0    0    0    0    0    5   -8    0    0    0    0    0   -2
  151           0.00          11.40    0    0    0    0    0    0    0    1    0    1    0    0    0    2
  152           0.00         -11.20    1    1    0    0   -1    0    0    0    0    0    0    0    0    0
  153           0.10          10.90    4    0    2    0    2    0    0    0    0    0    0    0    0    0
  154           0.00         -10.80    2    1    2   -2    2    0    0    0    0    0    0    0    0    0
  155           0.10         -10.70    1    0    2    0    0    0    0    0    0    0    0    0    0    0
  156          -0.20          10.40    2    0   -2    0    0    0    0    0    0    0    0    0    0    0
  157           0.00          10.50    2    0   -2   -4   -1    0    0    0    0    0    0    0    0    0
  158           0.00         -10.40    1    0    4   -2    2    0    0    0    0    0    0    0    0    0
  159           0.00          10.40    0    1    2    1    2    0    0    0    0    0    0    0    0    0
  160           0.00         -10.20    0    1    0    2    1    0    0    0    0    0    0    0    0    0
  161           0.00         -10.00    1    0   -4    0   -1    0    0    0    0    0    0    0    0    0
  162           0.00           9.60    1    0    0   -4   -1    0    0    0    0    0    0    0    0    0
  163           0.10           9.40    2    0    2    2    1    0    0    0    0    0    0    0    0    0
  164          -7.60           1.70    0    0    0    0    0    0    8  -13    0    0    0    0    0   -2
  165          -7.70           1.40    0    0    1   -1    1    0    0   -1    0    2    0    0    0    0
  166           1.40          -7.50    0    0    1   -1    1    0   -5    7    0    0    0    0    0    0
  167           6.10          -2.70    0    0    0    0    0    0    0    0    0    0    2    0    0    1
  168           0.00          -8.70    0    0    0    0    0    0    5   -7    0    0    0    0    0   -2
  169          -5.90           2.60    0    0    1   -1    1    0    0   -1    0    0    2    0    0    0
  170           0.00           8.40    0    0    2   -4    1    0    0    0    0    0    0    0    0    0
  171          -2.60          -5.70    1    0    2    0    2    0    0    1    0    0    0    0    0    0
  172           0.00           8.30    0    0    2   -3    2    0    0    0    0    0    0    0    0    0
  173          -0.20          -8.10    0    1    0   -2    0    0    0    0    0    0    0    0    0    0
  174           2.70           5.50    1    0   -2    0   -2    0    0    4   -8    3    0    0    0    0
  175           4.20          -4.00    0    0    0    0    0    0    0    8  -16    4    5    0    0   -2
  176           0.00           8.10    0    1    0   -2   -1    0    0    0    0    0    0    0    0    0
  177          -0.10           8.00    0    0    0    0    0    0    0    4    0   -2    0    0    0    2
  178          -1.30           6.70    0    0    0    0    0    0    0    2    0   -1    0    0    0    2
  179           0.00          -7.90    0    0    4    0    2    0    0    0    0    0    0    0    0    0
  180           0.00           7.80    0    0    0    4    1    0    0    0    0    0    0    0    0    0
  181          -7.50          -0.20    0    0    0    0    0    0    2   -1    0    0    0    0    0    2
  182          -0.50          -7.20    0    0    0    0    0    0    0    2    0    1    0    0    0    2
  183           4.90           2.70    0    0    0    0    0    0    8  -11    0    0    0    0    0   -2
  184           0.00          -7.50    3    0    2   -2    1    0    0    0    0    0    0    0    0    0
  185           0.00          -7.50    2    0    0   -2   -2    0    0    0    0    0    0    0    0    0
  186           0.00           7.50    1    1   -2   -4   -2    0    0    0    0    0    0    0    0    0
  187           0.00          -7.20    0    0    4   -2    1    0    0    0    0    0    0    0    0    0
  188           0.10           6.90    1    0    2    4    2    0    0    0    0    0    0    0    0    0
  189          -5.60           1.40    0    0    0    0    0    0    4   -6    0    0    0    0    0   -1
  190          -5.70          -1.30    0    0    0    0    0    0    1   -1    0    0    0    0    0   -1
  191           0.00           6.90    2    1    0   -2   -1    0    0    0    0    0    0    0    0    0
  192           0.00           6.90    1    1   -2    0   -2    0    0    0    0    0    0    0    0    0
  193           4.20          -2.70    0    0    0    0    0    0    8  -15    0    0    0    0    0   -2
  194          -3.10           3.70    0    0    0    0    0    0    0    1    2    0    0    0    0    2
  195          -3.90          -2.90    0    0    0    0    0    0    0    3    0   -2    0    0    0    2
  196           0.00           6.60    3    0    0    0   -1    0    0    0    0    0    0    0    0    0
  197          -3.10          -3.50    0    0    0    0    0    0    0    3   -2    0    0    0    0    2
  198           1.10          -5.40    1    0    0   -1    1    0    0    0    0    0    0    0    0    0
  199           0.00          -6.40    2    0    0   -4   -1    0    0    0    0    0    0    0    0    0
  200           0.90           5.50    0    0    0    0    0    0    0    0    0    3    0    0    0    2
  201           0.00          -6.30    0    0    2   -2    1    0   -3    3    0    0    0    0    0    0
  202          -0.10          -6.20    0    0    0    0    0    0    0    4   -2    0    0    0    0    2
  203           0.00          -6.10    1    1    2    2    2    0    0    0    0    0    0    0    0    0
  204           0.00           6.10    0    0    2   -1    1    0    0    0    0    0    0    0    0    0
  205           0.00           6.10    0    0    1   -1    1    0    0    3   -8    3    0    0    0    0
  206           0.00           6.00    0    0    2    4    1    0    0    0    0    0    0    0    0    0
  207           3.50          -2.50    0    0    0    0    1    0    8  -13    0    0    0    0    0    0
  208           0.00           5.90    1   -1    0   -2   -1    0    0    0    0    0    0    0    0    0
  209           0.00           5.70    2    0    0    2    1    0    0    0    0    0    0    0    0    0
  210          -0.90          -4.80    2    0    0   -2    1    0    0   -2    0    3    0    0    0    0
  211           0.00           5.70    1   -1   -2    2   -1    0    0    0    0    0    0    0    0    0
  212           0.00           5.70    0    0    0    0    0    0    0    0    0    0    2    0    0    2
  213           0.10           5.60    3    0    2    2    2    0    0    0    0    0    0    0    0    0
  214           0.20          -5.40    2    1   -2    0   -1    0    0    0    0    0    0    0    0    0
  215           0.00           5.60    2    0    0   -4    1    0    0    0    0    0    0    0    0    0
  216           0.00           5.60    1    0    0   -4    1    0    0    0    0    0    0    0    0    0
  217          -0.90          -4.70    0    0    0    0    0    0    5   -8    0    0    0    0    0   -1
  218          -0.40          -5.10    1    1    0   -2    0    0    0    0    0    0    0    0    0    0
  219           0.00           5.50    0    2   -2   -2   -2    0    0    0    0    0    0    0    0    0
  220           0.00          -5.40    2    0    2   -4    1    0    0    0    0    0    0    0    0    0
  221           1.80           3.60    1    0    0    0   -1    0  -18   16    0    0    0    0    0    0
  222           0.00          -5.40    0    0    0    0    0    0    0    8  -16    4    5    0    0    2
  223           0.00           5.30    1   -1    0   -2   -2    0    0    0    0    0    0    0    0    0
  224           0.00          -5.30    0    0    1   -1    1    0    0   -5    8   -3    0    0    0    0
  225           0.00          -5.20    0    0    0    2   -2    0    0    0    0    0    0    0    0    0
  226           0.00          -5.20    0    0    0    0    0    0    0    1    0   -3    0    0    0   -2
  227           0.00           5.10    0    2    0    0    1    0    0    0    0    0    0    0    0    0
  228           3.00           2.10    0    0    0    0    1    0   -8   13    0    0    0    0    0    0
  229           0.00          -5.10    0    0    0    0    0    0    6   -8    0    0    0    0    0   -2
  230           0.00          -5.00    3    0    0    0    0    0    0    0    0    0    0    0    0    0
  231           0.00           5.00    1   -1    2    2    1    0    0    0    0    0    0    0    0    0
  232           0.00          -5.00    1   -1   -2    0   -1    0    0    0    0    0    0    0    0    0
  233           0.90          -4.10    0    0    0    0    1    0    0    0    0   -2    5    0    0    0
  234          -5.00           0.00    0    0    0    0    0    0    3   -2    0    0    0    0    0    2
  235           0.00          -4.90    4    0    2   -2    2    0    0    0    0    0    0    0    0    0
  236           4.90           0.00    0    0    0    0    0    0    2   -5    0    0    0    0    0   -2
  237           0.00          -4.90    0    0    0    0    0    0    1   -3    0    0    0    0    0   -2
  238          -3.70          -1.10    0    0    0    0    1    0    0    0    0    1    0    0    0    0
  239           0.00           4.80    2    1   -2   -4   -2    0    0    0    0    0    0    0    0    0
  240           0.90           3.90    0    0    0    0    1    0    0    0    0    2   -5    0    0    0
  241           0.00           4.70    1    0    2    0   -1    0    0    0    0    0    0    0    0    0
  242           0.00          -4.70    0    2    2   -2    1    0    0    0    0    0    0    0    0    0
  243           0.00          -4.50    2    1    0   -2    1    0    0    0    0    0    0    0    0    0
  244           0.00          -4.50    2   -1   -2    0   -1    0    0    0    0    0    0    0    0    0
  245          -1.50          -3.00    1    0    0    0    1    0  -18   16    0    0    0    0    0    0
  246           0.00           4.40    2    0    0   -2    2    0    0    0    0    0    0    0    0    0
  247           0.00           4.40    1    2   -2   -2   -2    0    0    0    0    0    0    0    0    0
  248           0.00          -4.40    1   -1   -2   -2   -1    0    0    0    0    0    0    0    0    0
  249           0.30          -4.10    1   -1    0    0    0    0    0    0    0    0    0    0    0    0
  250           0.00          -4.30    3    0    0    0    1    0    0    0    0    0    0    0    0    0
  251           0.00           4.30    2    0   -2    2   -1    0    0    0    0    0    0    0    0    0
  252           0.00          -4.30    0    1    2    2    1    0    0    0    0    0    0    0    0    0
  253           0.00           4.30    0    0    0    0    3    0    0    0    0    0    0    0    0    0
  254           0.20           4.00    1    0   -2    0    0    0    0    0    0    0    0    0    0    0
  255           0.20           4.00    0    2   -2    0   -2    0    0    0    0    0    0    0    0    0
  256           0.00           4.10    3    0   -2    0   -1    0    0    0    0    0    0    0    0    0
  257          -0.60           3.50    0    0    1   -1    1    0    0   -1    0    0    1    0    0    0
  258           0.00           4.00    1    0   -4    2   -2    0    0    0    0    0    0    0    0    0
  259           0.00          -4.00    0    1   -2    1   -2    0    0    0    0    0    0    0    0    0
  260           3.10          -0.80    0    0    0    0    0    0    2   -4    0    0    0    0    0   -1
  261           0.00           3.90    2    0    0    0    2    0    0    0    0    0    0    0    0    0
  262           0.00           3.90    2   -1    2    2    2    0    0    0    0    0    0    0    0    0
  263           0.00           3.90    2   -1    2    0    1    0    0    0    0    0    0    0    0    0
  264           0.00          -3.90    1    0    0   -4    0    0    0    0    0    0    0    0    0    0
  265           0.00          -3.90    1    0   -2   -3   -2    0    0    0    0    0    0    0    0    0
  266           0.00           3.90    0    1   -2   -4   -2    0    0    0    0    0    0    0    0    0
  267           1.90           2.00    0    0    0    0    1    0    0    1   -2    0    0    0    0    0
  268           0.00           3.80    0    0    0    0    0    0    0    2    0    0    0    0    0    2
  269          -0.20           3.50    1    1    0    0    0    0    0    0    0    0    0    0    0    0
  270           0.00          -3.60    1    1   -2    1   -1    0    0    0    0    0    0    0    0    0
  271           0.00          -3.60    1    0   -2   -1   -2    0    0    0    0    0    0    0    0    0
  272          -2.10           1.50    0    0    0    0    0    0    0    1    0    2    0    0    0    2
  273           0.70           2.80    0    0    0    0    0    0    3   -7    0    0    0    0    0   -2
  274          -2.90          -0.60    0    0    0    0    0    0    2   -2    0    0    0    0    0   -1
  275           0.00          -3.50    0    0    0    0    0    0    0    2    0    0    0    0    0    0
  276          -2.80           0.70    0    0    0    0    0    0    0    0    0    1    0    0    0   -1
  277           0.00           3.40    2    0   -4    0   -2    0    0    0    0    0    0    0    0    0
  278           0.00          -3.40    1   -1    0   -2    1    0    0    0    0    0    0    0    0    0
  279           0.00          -3.30    2    1    2    0    1    0    0    0    0    0    0    0    0    0
  280           0.50           2.80    2    0    0   -2   -1    0    0   -2    0    3    0    0    0    0
  281           0.00           3.30    1    1   -2    0   -1    0    0    0    0    0    0    0    0    0
  282           2.60          -0.70    0    0    0    0    0    0    3   -5    0    0    0    0    0   -1
  283           1.00          -2.30    0    0    0    0    0    0    0    0    0    1    0    0    0    2
  284           0.00           3.20    1   -1    2   -2    2    0    0    0    0    0    0    0    0    0
  285           0.00          -3.20    0    2    2    0    2    0    0    0    0    0    0    0    0    0
  286           0.00           3.20    0    2    0    0   -1    0    0    0    0    0    0    0    0    0
  287           0.00          -3.20    0    0    0    0    0    0    7   -9    0    0    0    0    0   -2
  288           0.00           3.20    0    0    0    0    0    0    0    0    2    0    0    0    0    2
  289           2.90          -0.30    0    0    0    0    0    0    0    0    0    1    0    0    0    1
  290           0.00          -3.10    1    0    2   -4    2    0    0    0    0    0    0    0    0    0
  291          -0.70          -2.40    0    0    0    0    0    0    3   -3    0    0    0    0    0    2
  292           0.00           3.00    2    0    2   -1    2    0    0    0    0    0    0    0    0    0
  293          -1.60           1.40    1    0    0   -1    1    0    0   -1    0    2    0    0    0    0
  294          -2.90          -0.10    0    0    0    0    0    0    4   -7    0    0    0    0    0   -2
  295           0.00          -2.90    2    0    0   -2    1    0    0   -2    0    2    0    0    0    0
  296           0.00          -2.90    1    0    2    1    1    0    0    0    0    0    0    0    0    0
  297           0.00           2.90    0    1   -2    2    0    0    0    0    0    0    0    0    0    0
  298          -2.50           0.40    0    0    1   -1    1    0    0   -2    2    0    0    0    0    0
  299           0.40          -2.50    0    0    0    0    0    0    0    0    0    0    1    0    0    1
  300           0.00          -2.80    2    1   -2   -2   -2    0    0    0    0    0    0    0    0    0
  301          -2.50           0.30    0    0    1   -1    1    0    0   -1    0    1    0    0    0    0
  302          -2.50          -0.30    0    0    0    0    0    0    0    1   -2    0    0    0    0   -1
  303           2.70           0.00    1    0   -1    0   -3    0    0    0    0    0    0    0    0    0
  304           0.00          -2.70    0    0    2   -2    1    0    0   -2    0    2    0    0    0    0
  305           0.00           2.60    3   -1    2    0    2    0    0    0    0    0    0    0    0    0
  306           0.00          -2.60    0    1    0    2   -1    0    0    0    0    0    0    0    0    0
  307           0.00          -2.60    0    1    0    1    1    0    0    0    0    0    0    0    0    0
  308           2.10           0.50    0    0    1   -1    1    0   -3    4    0    0    0    0    0    0
  309           0.00          -2.50    2    0    0    0   -2    0    0    0    0    0    0    0    0    0
  310           0.00           2.50    0    1    0    1   -1    0    0    0    0    0    0    0    0    0
  311           1.90          -0.60    0    0    0    0    0    0    0    6  -16    4    5    0    0   -2
  312           0.80           1.70    0    0    0    0    0    0    0    0    0    0    1    0    0   -1
  313           0.00          -2.40    2    0    0    2    0    0    0    0    0    0    0    0    0    0
  314           0.00           2.40    2    0    0    2   -1    0    0    0    0    0    0    0    0    0
  315          -0.10          -2.30    2    0    0   -4    0    0    0    0    0    0    0    0    0    0
  316           0.00          -2.40    1    1   -2    2   -1    0    0    0    0    0    0    0    0    0
  317           0.00           2.40    1    0    2   -3    1    0    0    0    0    0    0    0    0    0
  318          -1.90           0.50    0    0    0    0    0    0    5   -7    0    0    0    0    0   -1
  319          -0.10          -2.20    0    0    0    0    0    0    8  -10    0    0    0    0    0   -2
  320           0.00          -2.30    3    1    2    0    2    0    0    0    0    0    0    0    0    0
  321           0.00           2.30    1    1    2   -4    1    0    0    0    0    0    0    0    0    0
  322          -1.40           0.90    0    0    0    0    0    0    0    0    4    0    0    0    0    2
  323           0.00           2.20    4    0    2    0    1    0    0    0    0    0    0    0    0    0
  324           0.00          -2.20    2   -1    2   -2    2    0    0    0    0    0    0    0    0    0
  325           0.00           2.20    1    1    2    1    2    0    0    0    0    0    0    0    0    0
  326           0.00           2.20    1   -2    2    0    2    0    0    0    0    0    0    0    0    0
  327           0.00           2.20    0    1    2    1    1    0    0    0    0    0    0    0    0    0
  328          -0.20          -2.00    0    0    0    1    0    0    0    0    0    0    0    0    0    0
  329          -1.80          -0.40    0    0    0    0    0    0    3   -3    0    0    0    0    0   -1
  330           0.00           2.20    0    0    0    0    0    0    0    2   -4    0    0    0    0   -2
  331           0.00          -2.10    2    1    2   -2    1    0    0    0    0    0    0    0    0    0
  332           0.00          -2.10    1    0    4   -2    1    0    0    0    0    0    0    0    0    0
  333           0.00           2.10    1    0    2   -1    1    0    0    0    0    0    0    0    0    0
  334           0.00           2.10    1    0   -2    1   -2    0    0    0    0    0    0    0    0    0
  335           0.00           2.10    1   -1    2   -2    1    0    0    0    0    0    0    0    0    0
  336          -1.70           0.40    0    0    0    0    0    0    1   -1    0    0    0    0    0    1
  337          -0.80          -1.30    0    0    0    0    0    0    0    5   -4    0    0    0    0    2
  338          -1.30          -0.80    0    0    0    0    0    0    0    4   -4    0    0    0    0    2
  339           0.00           2.00    2   -2    0   -2   -1    0    0    0    0    0    0    0    0    0
  340           0.00          -2.00    1    2    2   -2    2    0    0    0    0    0    0    0    0    0
  341           0.00          -2.00    1    0    2   -2   -1    0    0    0    0    0    0    0    0    0
  342           0.00           2.00    1    0   -2    2    1    0    0    0    0    0    0    0    0    0
  343           0.00           2.00    1   -1    0    2   -1    0    0    0    0    0    0    0    0    0
  344           2.00           0.00    0    0    0    0    0    0    6   -9    0    0    0    0    0   -2
  345           1.60          -0.40    0    0    0    0    0    0    1   -3    0    0    0    0    0   -1
  346           1.10          -0.90    0    0    0    0    0    0    0    0    0    2   -5    0    0   -2
  347          -0.30           1.60    0    0    0    0    0    0    0    4    0   -3    0    0    0    2
  348           0.00          -1.90    3    0   -2   -2   -2    0    0    0    0    0    0    0    0    0
  349           0.00          -1.90    2    0    2    1    2    0    0    0    0    0    0    0    0    0
  350           0.00           1.90    2   -1    0   -2    1    0    0    0    0    0    0    0    0    0
  351           0.00          -1.90    1    0   -2   -2    0    0    0    0    0    0    0    0    0    0
  352           0.00           1.90    1   -1    0    2    1    0    0    0    0    0    0    0    0    0
  353           0.00           1.90    0    0    4   -4    2    0    0    0    0    0    0    0    0    0
  354          -1.00           0.90    0    0    1   -1    1    0    0   -1    0    0    0    0    2    0
  355          -1.40          -0.50    0    0    1   -1    1    0    0   -1    0   -4   10    0    0    0
  356           1.50           0.40    0    0    1   -1    1    0   -4    5    0    0    0    0    0    0
  357           0.00          -1.90    0    0    0    4    0    0    0    0    0    0    0    0    0    0
  358           0.00           1.90    0    0    0    4   -1    0    0    0    0    0    0    0    0    0
  359          -1.50          -0.40    0    0    0    0    0    0    0    2    0    0    0    0    0    1
  360           0.00           1.80    2    0   -2   -6   -2    0    0    0    0    0    0    0    0    0
  361           0.00          -1.80    2    0   -4   -2   -2    0    0    0    0    0    0    0    0    0
  362           0.00          -1.80    2   -1    0    0    1    0    0    0    0    0    0    0    0    0
  363           0.20          -1.60    0    0    0    0    0    0    2   -3    0    0    0    0    0   -1
  364          -1.10           0.70    0    0    0    0    0    0    0    2   -4    0    0    0    0   -1
  365          -0.60          -1.10    1    0    2    0    1    0    0   -2    0    3    0    0    0    0
  366           0.60           1.10    1    0   -2    0   -1    0    0   -1    0    0    0    0    0    0
  367          -1.10           0.60    0    0    0    0    1    0    0   -2    4    0    0    0    0    0
  368          -0.60          -1.10    0    0    0    0    0    0    0    4   -3    0    0    0    0    2
  369           0.00          -1.70    0    0    2    2    0    0    0    0    0    0    0    0    0    0
  370          -1.20          -0.50    0    0    2   -2    1    0    0   -9   13    0    0    0    0    0
  371           1.50           0.20    0    0    1    1    1    0    0    1    0    0    0    0    0    0
  372          -1.70           0.00    0    0    0    0    1    0    2   -3    0    0    0    0    0    0
  373           0.00          -1.60    2    0    4   -2    2    0    0    0    0    0    0    0    0    0
  374          -0.50          -1.10    2    0    2    0    2    0    0    2    0   -3    0    0    0    0
  375           0.00          -1.60    1    1    0    2    1    0    0    0    0    0    0    0    0    0
  376           0.00           1.60    1    0    0    4    1    0    0    0    0    0    0    0    0    0
  377           0.00           1.60    0    1   -2    2    1    0    0    0    0    0    0    0    0    0
  378           0.00          -1.60    0    0    4    0    1    0    0    0    0    0    0    0    0    0
  379           0.00          -1.60    0    0    2    3    2    0    0    0    0    0    0    0    0    0
  380           1.10          -0.50    0    0    1   -1    2    0    0   -1    0    0    2    0    0    0
  381          -1.30          -0.30    0    0    0    0    0    0    4   -4    0    0    0    0    0   -1
  382           0.60           1.00    0    0    0    0    0    0    0    3   -6    0    0    0    0   -2
  383           0.30          -1.30    0    0    0    0    0    0    0    1   -2    0    0    0    0    1
  384           1.20          -0.40    0    0    0    0    0    0    0    0    0    3    0    0    0    1
  385           0.00           1.50    2    0    2   -4    2    0    0    0    0    0    0    0    0    0
  386           0.00           1.50    2   -1    0    0   -1    0    0    0    0    0    0    0    0    0
  387           0.00          -1.50    1    2    0   -2   -1    0    0    0    0    0    0    0    0    0
  388           0.00           1.50    1    1   -2   -4   -1    0    0    0    0    0    0    0    0    0
  389           0.00          -1.50    1    0    0    1   -1    0    0    0    0    0    0    0    0    0
  390           1.50           0.00    1    0    0   -1    1    0   -3    4    0    0    0    0    0    0
  391           0.00           1.50    1    0    0   -1   -2    0    0    0    0    0    0    0    0    0
  392           0.00          -1.50    1   -1    0    2    0    0    0    0    0    0    0    0    0    0
  393           0.00          -1.50    0    1    4   -2    2    0    0    0    0    0    0    0    0    0
  394           0.00          -1.50    0    1    2   -2   -1    0    0    0    0    0    0    0    0    0
  395          -0.50           1.00    0    0    2    0    2    0    0    1    0    0    0    0    0    0
  396           0.00           1.50    0    0    0    0    1    0    1   -1    0    0    0    0    0    0
  397           1.30          -0.20    0    0    0    0    1    0    0    0    0    0    1    0    0    0
  398           0.00          -1.50    0    0    0    0    0    0    9  -11    0    0    0    0    0   -2
  399          -1.20          -0.30    0    0    0    0    0    0    1    1    0    0    0    0    0    1
  400          -1.40           0.10    0    0    0    0    0    0    0    4    0   -1    0    0    0    2
  401           0.20          -1.30    0    0    0    0    0    0    0    1    0   -4    0    0    0   -2
  402          -0.50           1.00    0    0    0    0    0    0    0    1   -8    3    0    0    0   -2
  403           1.10          -0.30    0    0    1   -1    1    0   -1    0    0    0    0    0    0    0
  404          -0.30           1.10    0    0    0    0    1    0   -3    5    0    0    0    0    0    0
  405           0.00          -1.40    3    0   -2   -2   -1    0    0    0    0    0    0    0    0    0
  406           0.00          -1.40    2    0    2    0    0    0    0    0    0    0    0    0    0    0
  407           0.20           1.20    2   -1    0   -2    0    0    0    0    0    0    0    0    0    0
  408           0.00           1.40    1    0    2    4    1    0    0    0    0    0    0    0    0    0
  409           0.00           1.40    1    0   -2   -6   -2    0    0    0    0    0    0    0    0    0
  410           0.00          -1.40    1   -2   -2   -2   -2    0    0    0    0    0    0    0    0    0
  411           0.00           1.40    0    1    0    2    0    0    0    0    0    0    0    0    0    0
  412           0.00          -1.40    0    0    2   -2    1    0   -4    4    0    0    0    0    0    0
  413           0.00          -1.40    0    0    2   -3    1    0    0    0    0    0    0    0    0    0
  414           1.40           0.00    0    0    1    0    2    0    0    0    0    0    0    0    0    0
  415           0.00          -1.30    3    1    2   -2    2    0    0    0    0    0    0    0    0    0
  416          -1.30           0.00    1    0    0   -1   -1    0   -3    4    0    0    0    0    0    0
  417           0.00          -1.30    1    0   -4   -2   -2    0    0    0    0    0    0    0    0    0
  418           0.00          -1.30    1   -1   -2   -4   -2    0    0    0    0    0    0    0    0    0
  419           0.00           1.30    1   -2    2    2    2    0    0    0    0    0    0    0    0    0
  420           0.00          -1.30    0    0    2   -4    2    0    0    0    0    0    0    0    0    0
  421          -0.80           0.50    0    0    1   -1    1    0    3   -6    0    0    0    0    0    0
  422          -0.20          -1.10    0    0    0    0    0    0    6  -10    0    0    0    0    0   -2
  423           0.00          -1.30    0    0    0    0    0    0    3   -1    0    0    0    0    0    2
  424           0.00          -1.30    0    0    0    0    0    0    0    3    0    0   -1    0    0    2
  425           1.10           0.20    0    0    0    0    0    0    0    2    0   -2    0    0    0    1
  426          -0.70          -0.60    0    0    1   -1    1    0    8  -14    0    0    0    0    0    0
  427          -0.40          -0.80    0    0    0    0    1    0    0    8  -15    0    0    0    0    0
  428           0.40           0.80    0    0    0    0    0    0    0    1   -4    0    0    0    0   -2
  429          -0.40           0.80    0    0    0    0    0    0    0    0    3    0    0    0    0    2
  430           0.00          -1.20    2    1    0    0   -1    0    0    0    0    0    0    0    0    0
  431           0.00           1.20    2    0    2    4    2    0    0    0    0    0    0    0    0    0
  432           0.00           1.20    1    2    0   -2    1    0    0    0    0    0    0    0    0    0
  433           0.00          -1.20    1    1    2    2    1    0    0    0    0    0    0    0    0    0
  434          -0.70          -0.50    0    0    1   -1    1    0    0   -3    4    0    0    0    0    0
  435          -1.00           0.20    0    0    0    0    0    0    6   -8    0    0    0    0    0   -1
  436           1.20           0.00    0    0    0    0    0    0    3   -6    0    0    0    0    0   -2
  437          -1.00           0.20    0    0    0    0    0    0    2    1    0    0    0    0    0    2
  438           0.20          -1.00    0    0    0    0    0    0    2    1    0    0    0    0    0    1
  439           0.00           1.10    3    0    2    2    1    0    0    0    0    0    0    0    0    0
  440           0.00           1.10    3    0    2   -4    2    0    0    0    0    0    0    0    0    0
  441           0.00          -1.10    2    1    2    2    2    0    0    0    0    0    0    0    0    0
  442           0.00           1.10    2    1    0    0    1    0    0    0    0    0    0    0    0    0
  443          -0.20           0.90    2    0    0   -2    1    0   -6    8    0    0    0    0    0    0
  444           0.00           1.10    2   -1   -2   -2   -2    0    0    0    0    0    0    0    0    0
  445          -1.10           0.00    1    0    1    0    1    0    0    0    0    0    0    0    0    0
  446           0.00          -1.10    1   -1   -2    2   -2    0    0    0    0    0    0    0    0    0
  447          -0.50           0.60    1   -2    2   -2    1    0    0    0    0    0    0    0    0    0
  448          -1.10           0.00    0    0    3    0    3    0    0    0    0    0    0    0    0    0
  449          -0.90          -0.20    0    0    0    0    0    0    5   -5    0    0    0    0    0   -1
  450           0.00           1.10    0    0    0    0    0    0    0    7   -8    3    0    0    0    2
  451          -0.40          -0.70    0    0    0    0    0    0    0    4   -7    0    0    0    0   -2
  452           0.60          -0.50    0    0    0    0    0    0    0    0    0    0    0    0    2    1
  453           0.00          -1.00    3    0    0   -4   -1    0    0    0    0    0    0    0    0    0
  454           0.00           1.00    2    0   -2    0    2    0    0    0    0    0    0    0    0    0
  455           0.00          -1.00    1    0    4    0    2    0    0    0    0    0    0    0    0    0
  456          -1.00           0.00    1    0    1   -2    1    0    0    0    0    0    0    0    0    0
  457           0.00          -1.00    1    0    0    2    2    0    0    0    0    0    0    0    0    0
  458           0.00           1.00    1    0    0    1    1    0    0    0    0    0    0    0    0    0
  459           0.00           1.00    1    0   -4    2   -1    0    0    0    0    0    0    0    0    0
  460           0.00           1.00    1   -1    2    4    2    0    0    0    0    0    0    0    0    0
  461           0.00           1.00    0    2    0   -2    1    0    0    0    0    0    0    0    0    0
  462           0.00           1.00    0    2   -2   -2   -1    0    0    0    0    0    0    0    0    0
  463           0.00          -1.00    0    1    2   -2    3    0    0    0    0    0    0    0    0    0
  464           0.00           1.00    0    1    2   -4    1    0    0    0    0    0    0    0    0    0
  465           1.00           0.00    0    0    1   -1    1    0    0   -9   15    0    0    0    0    0
  466           0.80          -0.20    0    0    0    0    1    0    0    0    0   -1    0    0    0    0
  467           0.00           1.00    0    0    0    0    1    0   -1    1    0    0    0    0    0    0
  468           1.00           0.00    0    0    0    0    1    0   -2    3    0    0    0    0    0    0
  469           1.00           0.00    0    0    0    0    0    0    7  -10    0    0    0    0    0   -2
  470           0.40           0.60    0    0    0    0    0    0    3   -5    4    0    0    0    0    2
  471          -0.40          -0.60    0    0    0    0    0    0    3   -9    4    0    0    0    0   -2
  472          -0.80          -0.20    0    0    0    0    0    0    2    0    0    0    0    0    0    1
  473           0.00           0.90    5    0    2    0    2    0    0    0    0    0    0    0    0    0
  474           0.00          -0.90    4    0    2   -2    1    0    0    0    0    0    0    0    0    0
  475           0.00           0.90    3    0   -2   -6   -2    0    0    0    0    0    0    0    0    0
  476           0.00           0.90    2    1   -2   -4   -1    0    0    0    0    0    0    0    0    0
  477           0.00          -0.90    2    0    0   -2    1    0   -3    3    0    0    0    0    0    0
  478           0.00          -0.90    1    2    2    0    2    0    0    0    0    0    0    0    0    0
  479           0.00           0.90    1    0    2   -2    0    0    0    0    0    0    0    0    0    0
  480           0.00           0.90    1    0   -2    4   -1    0    0    0    0    0    0    0    0    0
  481           0.00           0.90    1    0   -2   -2    1    0    0    0    0    0    0    0    0    0
  482           0.00          -0.90    1   -1    2   -1    2    0    0    0    0    0    0    0    0    0
  483           0.00          -0.90    1   -1    0   -1    0    0    0    0    0    0    0    0    0    0
  484           0.10           0.80    1   -1    0   -2    0    0    0    0    0    0    0    0    0    0
  485           0.00           0.90    0    1    0   -2   -2    0    0    0    0    0    0    0    0    0
  486           0.00          -0.90    0    0    1   -1    1    0   -2    2    0    0    0    0    0    0
  487          -0.50          -0.40    0    0    0    0    0    0    0    3    0   -3    0    0    0    2
  488          -0.90           0.00    0    0    0    0    0    0    0    2    0    0   -1    0    0    2
  489          -0.70          -0.20    0    0    0    0    0    0    6   -6    0    0    0    0    0   -1
  490           0.70          -0.20    0    0    0    0    0    0    1    2    0    0    0    0    0    2
  491          -0.30           0.60    0    0    0    0    0    0    0    8  -15    0    0    0    0   -2
  492           0.00           0.80    3    0    0   -2   -1    0    0    0    0    0    0    0    0    0
  493           0.00          -0.80    3    0   -2    0   -2    0    0    0    0    0    0    0    0    0
  494           0.00          -0.80    2   -1    0    0    0    0    0    0    0    0    0    0    0    0
  495           0.00          -0.80    2   -1   -2   -4   -2    0    0    0    0    0    0    0    0    0
  496           0.00           0.80    1    2   -2   -2   -1    0    0    0    0    0    0    0    0    0
  497           0.00           0.80    1    1    0   -2   -2    0    0    0    0    0    0    0    0    0
  498           0.00          -0.80    1    0   -2   -3   -1    0    0    0    0    0    0    0    0    0
  499           0.00           0.80    0    1    0   -4   -1    0    0    0    0    0    0    0    0    0
  500           0.00          -0.80    0    1   -2    1   -1    0    0    0    0    0    0    0    0    0
  501           0.00          -0.80    0    0    4   -4    4    0    0    0    0    0    0    0    0    0
  502           0.00           0.80    0    0    4   -4    1    0    0    0    0    0    0    0    0    0
  503          -0.30          -0.50    0    0    0    0    1    0    3   -7    4    0    0    0    0    0
  504           0.00          -0.80    0    0    0    0    1    0    0    1    0   -1    0    0    0    0
  505          -0.30           0.50    0    0    0    0    1    0   -3    7   -4    0    0    0    0    0
  506          -0.60           0.20    0    0    0    0    0    0    7   -9    0    0    0    0    0   -1
  507           0.20           0.60    0    0    0    0    0    0    4   -7    0    0    0    0    0   -1
  508          -0.50           0.30    0    0    0    0    0    0    3   -5    0    0    0    0    0    1
  509          -0.50          -0.30    0    0    0    0    0    0    0    5   -5    0    0    0    0    2
  510          -0.50          -0.30    0    0    0    0    0    0    0    5   -9    0    0    0    0   -2
  511           0.00          -0.80    0    0    0    0    0    0    0    3   -1    0    0    0    0    2
  512          -0.30           0.50    0    0    0    0    0    0    0    2    0    2   -5    0    0    2
  513          -0.80           0.00    0    0    0    0    0    0    0    2    0    0    1    0    0    2
  514          -0.30          -0.50    0    0    0    0    0    0    0    2    0   -2    5    0    0    2
  515           0.10           0.70    0    0    0    0    0    0    7  -11    0    0    0    0    0   -2
  516          -0.70           0.10    0    0    0    0    0    0    2   -2    0    0    0    0    0    1
  517           0.00           0.70    4    0    2    2    2    0    0    0    0    0    0    0    0    0
  518           0.00           0.70    3    0    0   -4    1    0    0    0    0    0    0    0    0    0
  519           0.10          -0.60    2    0    0   -2   -1    0   -6    8    0    0    0    0    0    0
  520           0.00          -0.70    2    0   -2   -3   -2    0    0    0    0    0    0    0    0    0
  521           0.00           0.70    2   -1    2    2    1    0    0    0    0    0    0    0    0    0
  522           0.00           0.70    1    0    0    1    0    0    0    0    0    0    0    0    0    0
  523           0.00           0.70    1   -1    0    0    2    0    0    0    0    0    0    0    0    0
  524           0.00          -0.70    0    1    2    4    2    0    0    0    0    0    0    0    0    0
  525           0.00           0.70    0    1   -2   -4   -1    0    0    0    0    0    0    0    0    0
  526           0.00           0.70    0    1   -4    2   -2    0    0    0    0    0    0    0    0    0
  527           0.70           0.00    0    0    1   -1    2    0    0   -2    2    0    0    0    0    0
  528          -0.70           0.00    0    0    1   -1    1    0    2   -4    0   -3    0    0    0    0
  529          -0.50           0.20    0    0    1   -1    1    0    0   -1    0    3    0    0    0    0
  530           0.70           0.00    0    0    1   -1    1    0    0   -1    0   -1    1    0    0    0
  531           0.00          -0.70    0    0    0    0    1    0    3   -5    0    2    0    0    0    0
  532          -0.20          -0.50    0    0    0    0    0    0    9   -9    0    0    0    0    0   -1
  533          -0.60          -0.10    0    0    0    0    0    0    3   -1    0    0    0    0    0    1
  534           0.60          -0.10    0    0    0    0    0    0    3   -3    0    0    0    0    0    1
  535           0.50          -0.20    0    0    0    0    0    0    2   -3    0    0    0    0    0   -2
  536           0.20           0.50    0    0    0    0    0    0    0   11    0    0    0    0    0    2
  537          -0.20          -0.50    0    0    0    0    0    0    0    6  -15    0    0    0    0   -2
  538           0.40           0.30    0    0    0    0    0    0    0    4   -8    0    0    0    0   -2
  539           0.50          -0.20    0    0    0    0    0    0    0    3    0    2   -5    0    0    2
  540          -0.50           0.20    0    0    0    0    0    0    0    3    0    1    0    0    0    2
  541           0.00          -0.70    0    0    0    0    0    0    0    3   -5    0    0    0    0   -2
  542           0.00          -0.70    0    0    0    0    0    0    0    2    0   -4    0    0    0   -2
  543           0.70           0.00    0    0    0    0    0    0    0    0    0    0    3    0    0    2
  544          -0.40           0.20    2    0   -1   -1   -1    0    0   -1    0    3    0    0    0    0
  545           0.20           0.40    0    0    1   -1    1    0    0   -1    0    0    3    0    0    0
  546           0.40           0.20    0    0    0    0    1    0    0    2   -4    0    0    0    0    0
  547          -0.40           0.20    0    0    0    0    0    1    0   -4    0    0    0    0    0   -2
  548           0.40          -0.20    0    0    0    0    0    0    0    6    0    0    0    0    0    2
  549          -0.40          -0.20    0    0    0    0    0    0    0    6   -6    0    0    0    0    2
  550           0.40           0.20    0    0    0    0    0    0    0    1   -5    0    0    0    0   -2
  551          -0.20          -0.40    0    0    0    0    0    0    0    0    0    0    3    0    0    1
  552           0.00           0.60    4    0   -2   -2   -1    0    0    0    0    0    0    0    0    0
  553           0.00           0.60    3    0    0    2    1    0    0    0    0    0    0    0    0    0
  554           0.00           0.60    2    1    0    0    0    0    0    0    0    0    0    0    0    0
  555           0.00          -0.60    2    1    0   -4   -1    0    0    0    0    0    0    0    0    0
  556           0.00          -0.60    2    0    0   -2   -1    0    0   -2    0    0    5    0    0    0
  557           0.00          -0.60    2    0   -2    2   -2    0    0    0    0    0    0    0    0    0
  558           0.00          -0.60    1    1    0   -2    2    0    0    0    0    0    0    0    0    0
  559           0.00           0.60    1    1    0   -4    1    0    0    0    0    0    0    0    0    0
  560           0.00           0.60    1    1    0   -4   -1    0    0    0    0    0    0    0    0    0
  561           0.00           0.60    1    0    0   -4   -2    0    0    0    0    0    0    0    0    0
  562           0.00          -0.60    1    0   -2   -2   -2    0    0   -2    0    2    0    0    0    0
  563           0.00          -0.60    1   -1    2   -4    1    0    0    0    0    0    0    0    0    0
  564           0.00          -0.60    0    1    0    1    0    0    0    0    0    0    0    0    0    0
  565           0.00           0.60    0    0    2    2   -1    0    0    0    0    0    0    0    0    0
  566           0.60           0.00    0    0    2   -2    2    0   -8   11    0    0    0    0    0    0
  567           0.00          -0.60    0    0    2   -2    1    0   -2    2    0    0    0    0    0    0
  568           0.50           0.10    0    0    1   -1    1    0   -2    3    0    0    0    0    0    0
  569           0.10          -0.50    0    0    1   -1   -1    0    0    0   -2    0    0    0    0    0
  570           0.00          -0.60    0    0    0    3    1    0    0    0    0    0    0    0    0    0
  571           0.00          -0.60    0    0    0    1    2    0    0    0    0    0    0    0    0    0
  572           0.00          -0.60    0    0    0    0    1    0    0   -1    0    1    0    0    0    0
  573           0.30           0.30    0    0    0    0    0    0    8  -13    0    0    0    0    0    1
  574          -0.50          -0.10    0    0    0    0    0    0    7   -7    0    0    0    0    0   -1
  575          -0.10          -0.50    0    0    0    0    0    0    4   -4    0    0    0    0    0    2
  576           0.10           0.50    0    0    0    0    0    0    1   -2    0    0    0    0    0    1
  577           0.50          -0.10    0    0    0    0    0    0    0    5    0   -2    0    0    0    2
  578          -0.10           0.50    0    0    0    0    0    0    0    3   -6    0    0    0    0   -1
  579           0.00           0.60    0    0    0    0    0    0    0    1    1    0    0    0    0    2
  580           0.00           0.60    0    0    0    0    0    0    0    1    0    0    1    0    0    2
  581           0.00           0.50    3   -1    2    2    2    0    0    0    0    0    0    0    0    0
  582           0.00          -0.50    3   -1    2   -2    2    0    0    0    0    0    0    0    0    0
  583           0.00           0.50    3   -1   -2   -1   -2    0    0    0    0    0    0    0    0    0
  584           0.10           0.40    2    1    0   -2    0    0    0    0    0    0    0    0    0    0
  585           0.00           0.50    2    1    0   -4    1    0    0    0    0    0    0    0    0    0
  586           0.00          -0.50    2    1   -2   -2   -1    0    0    0    0    0    0    0    0    0
  587           0.00           0.50    2    0    2    0   -1    0    0    0    0    0    0    0    0    0
  588           0.30          -0.20    2    0    0   -2    1    0    0   -6    8    0    0    0    0    0
  589          -0.20           0.30    2    0    0   -2   -1    0    0   -5    6    0    0    0    0    0
  590           0.20           0.30    2    0   -1   -1   -1    0    0    3   -7    0    0    0    0    0
  591           0.00           0.50    2    0   -4    0   -1    0    0    0    0    0    0    0    0    0
  592           0.00          -0.50    1    1    0    0    2    0    0    0    0    0    0    0    0    0
  593           0.00          -0.50    1    1    0   -4    0    0    0    0    0    0    0    0    0    0
  594           0.00          -0.50    1    0    0    2   -2    0    0    0    0    0    0    0    0    0
  595           0.00           0.50    1    0    0   -1    2    0    0    0    0    0    0    0    0    0
  596           0.00           0.50    1    0   -2    2    0    0    0    0    0    0    0    0    0    0
  597           0.00           0.50    1   -2    2   -2    2    0    0    0    0    0    0    0    0    0
  598           0.00          -0.50    1   -2    0    0    1    0    0    0    0    0    0    0    0    0
  599           0.00          -0.50    0    1    0    2    2    0    0    0    0    0    0    0    0    0
  600           0.00           0.50    0    1   -2    2   -3    0    0    0    0    0    0    0    0    0
  601           0.00          -0.50    0    1   -2   -1   -2    0    0    0    0    0    0    0    0    0
  602          -0.50           0.00    0    0    3    0    2    0    0    0    0    0    0    0    0    0
  603           0.00           0.50    0    0    2    6    2    0    0    0    0    0    0    0    0    0
  604           0.40           0.10    0    0    2    0    2    0    0    4   -8    3    0    0    0    0
  605           0.40          -0.10    0    0    2    0    2    0    0   -4    8   -3    0    0    0    0
  606           0.00           0.50    0    0    2   -2    2    0   -3    3    0    0    0    0    0    0
  607           0.50           0.00    0    0    2   -2    2    0   -5    6    0    0    0    0    0    0
  608           0.40           0.10    0    0    2   -2    1   -1    0    2    0    0    0    0    0    0
  609          -0.50           0.00    0    0    1   -1    1    0    0    1    0    0    0    0    0    0
  610          -0.40          -0.10    0    0    1   -1    1    0    0   -1    0    0    0    2    0    0
  611           0.10           0.40    0    0    0    0    1    0    3   -5    0    0    0    0    0    0
  612           0.50           0.00    0    0    0    0    0    0    9  -12    0    0    0    0    0   -2
  613           0.00          -0.50    0    0    0    0    0    0    6   -9    0    0    0    0    0   -1
  614           0.40          -0.10    0    0    0    0    0    0    5   -6    0    0    0    0    0    2
  615          -0.40           0.10    0    0    0    0    0    0    5  -10    0    0    0    0    0   -2
  616          -0.50           0.00    0    0    0    0    0    0    4   -4    0    0    0    0    0    1
  617           0.30           0.20    0    0    0    0    0    0    1    0    0    0    0    0    0    2
  618          -0.30           0.20    0    0    0    0    0    0    0    7  -13    0    0    0    0   -2
  619          -0.50           0.00    0    0    0    0    0    0    0    6  -11    0    0    0    0   -2
  620           0.10           0.40    0    0    0    0    0    0    0    5    0   -3    0    0    0    2
  621           0.20           0.30    0    0    0    0    0    0    0    2   -5    0    0    0    0   -2
  622          -0.30           0.20    0    0    0    0    0    0    0    1    0    3    0    0    0    2
  623           0.00           0.50    0    0    0    0    0    0    0    1   -3    0    0    0    0   -2
  624           0.10           0.40    0    0    0    0    0    0    0    0    0    4    0    0    0    2
  625           0.00          -0.40    5    0    2   -2    2    0    0    0    0    0    0    0    0    0
  626           0.00          -0.40    4    0    0    0    0    0    0    0    0    0    0    0    0    0
  627           0.00           0.40    4    0    0    0   -1    0    0    0    0    0    0    0    0    0
  628           0.00          -0.40    3    1    2    0    1    0    0    0    0    0    0    0    0    0
  629           0.00           0.40    3    0    2   -1    2    0    0    0    0    0    0    0    0    0
  630           0.00           0.40    3   -1    2    0    1    0    0    0    0    0    0    0    0    0
  631           0.00           0.40    2    0    2   -1    1    0    0    0    0    0    0    0    0    0
  632           0.00          -0.40    2    0    0    2    2    0    0    0    0    0    0    0    0    0
  633           0.00           0.40    2   -2    2    0    2    0    0    0    0    0    0    0    0    0
  634          -0.10           0.30    2   -2    2   -2    2    0    0    0    0    0    0    0    0    0
  635           0.00          -0.40    1    2    2   -2    1    0    0    0    0    0    0    0    0    0
  636           0.00           0.40    1    2   -2   -4   -2    0    0    0    0    0    0    0    0    0
  637           0.00           0.40    1    1    2    1    1    0    0    0    0    0    0    0    0    0
  638          -0.10           0.30    1    1    0    2    0    0    0    0    0    0    0    0    0    0
  639           0.00          -0.40    1    1    0    2   -1    0    0    0    0    0    0    0    0    0
  640           0.00          -0.40    1    1    0   -1    1    0    0    0    0    0    0    0    0    0
  641           0.00           0.40    1    0    4   -4    2    0    0    0    0    0    0    0    0    0
  642           0.00          -0.40    1    0    2    2    0    0    0    0    0    0    0    0    0    0
  643           0.00          -0.40    1    0    0    4    0    0    0    0    0    0    0    0    0    0
  644           0.00          -0.40    1    0    0   -3    1    0    0    0    0    0    0    0    0    0
  645           0.40           0.00    1    0   -1    0    1    0    0    0    0    0    0    0    0    0
  646           0.00           0.40    1   -1   -2   -3   -2    0    0    0    0    0    0    0    0    0
  647           0.00           0.40    1   -2    0   -2   -1    0    0    0    0    0    0    0    0    0
  648           0.00          -0.40    1   -2   -2    0   -2    0    0    0    0    0    0    0    0    0
  649           0.00          -0.40    0    2    2    0    1    0    0    0    0    0    0    0    0    0
  650           0.00          -0.40    0    2    0   -2    0    0    0    0    0    0    0    0    0    0
  651          -0.10           0.30    0    2   -2    0   -1    0    0    0    0    0    0    0    0    0
  652           0.00           0.40    0    0    4   -1    2    0    0    0    0    0    0    0    0    0
  653           0.00          -0.40    0    0    2    0    2    0    1   -1    0    0    0    0    0    0
  654           0.00          -0.40    0    0    2   -2    1    0    0   -2    0    3    0    0    0    0
  655           0.00          -0.40    0    0    2   -2    1    0    0   -2    0    0    2    0    0    0
  656           0.40           0.00    0    0    2   -2    1    0    0   -8   11    0    0    0    0    0
  657           0.00           0.40    0    0    2   -2   -2    0    0    0    0    0    0    0    0    0
  658           0.40           0.00    0    0    1   -1    2    0    0   -1    0    2    0    0    0    0
  659          -0.20          -0.20    0    0    1   -1    1    0    0   -1    0    0   -2    0    0    0
  660          -0.40           0.00    0    0    1   -1    1    0    0   -1    0   -1    2    0    0    0
  661           0.20          -0.20    0    0    1   -1    1    0    0   -1    0   -2    4    0    0    0
  662          -0.20           0.20    0    0    0    0    2    0    0   -1    2    0    0    0    0    0
  663          -0.10           0.30    0    0    0    0    1    0    0   -8   15    0    0    0    0    0
  664          -0.40           0.00    0    0    0    0    0    0    8   -8    0    0    0    0    0   -1
  665          -0.40           0.00    0    0    0    0    0    0    8  -10    0    0    0    0    0   -1
  666          -0.30           0.10    0    0    0    0    0    0    6  -10    0    0    0    0    0   -1
  667           0.00           0.40    0    0    0    0    0    0    5   -5    0    0    0    0    0    2
  668           0.00          -0.40    0    0    0    0    0    0    5   -9    0    0    0    0    0   -2
  669           0.00          -0.40    0    0    0    0    0    0    4   -2    0    0    0    0    0    2
  670          -0.40           0.00    0    0    0    0    0    0    4   -2    0    0    0    0    0    1
  671           0.40           0.00    0    0    0    0    0    0    4   -3    0    0    0    0    0    2
  672           0.00          -0.40    0    0    0    0    0    0    3   -4    0    0    0    0    0   -1
  673           0.00           0.40    0    0    0    0    0    0    3   -6    0    0    0    0    0   -1
  674           0.00           0.40    0    0    0    0    0    0    2   -6    0    0    0    0    0   -2
  675           0.40           0.00    0    0    0    0    0    0    0    8  -15    0    0    0    0   -1
  676           0.00          -0.40    0    0    0    0    0    0    0    6    0    0    0    0    0    0
  677           0.10           0.30    0    0    0    0    0    0    0    6   -5    0    0    0    0    2
  678          -0.40           0.00    0    0    0    0    0    0    0    5   -2    0    0    0    0    2
  679           0.00           0.40    0    0    0    0    0    0    0    5   -3    0    0    0    0    2
  680           0.20           0.20    0    0    0    0    0    0    0    2    2    0    0    0    0    2
  681          -0.10           0.30    0    0    0    0    0    0    0    2    0   -2    0    0    0    2
  682           0.40           0.00    0    0    0    0    0    0    0    0    0    0    1    0    0    2
  683          -0.10          -0.20    2    0    2    0    1    0    0    1    0    0    0    0    0    0
  684          -0.20           0.10    2    0    0   -2   -1    0    0   -6    8    0    0    0    0    0
  685          -0.10          -0.20    2    0   -1   -1    1    0    0    3   -7    0    0    0    0    0
  686           0.10          -0.20    1    0    0   -1    1    0    0   -3    4    0    0    0    0    0
  687          -0.10           0.20    1    0   -2    0   -2    0  -10    3    0    0    0    0    0    0
  688           0.20          -0.10    0    0    2   -2    1    0    0   -7    9    0    0    0    0    0
  689           0.20           0.10    0    0    1   -1    2    0    0   -1    0   -2    5    0    0    0
  690           0.20           0.10    0    0    1   -1   -1    0    0   -1    0   -1    0    0    0    0
  691          -0.20          -0.10    0    0    0    0    1    0    0    1    0   -2    0    0    0    0
  692          -0.20           0.10    0    0    0    0    1    0    0   -9   17    0    0    0    0    0
  693          -0.10          -0.20    0    0    0    0    0    0    2   -3    0    0    0    0    0    1
  694           0.20           0.10    0    0    0    0    0    0    1   -2    0    0    0    0    0   -2
  695           0.20          -0.10    0    0    0    0    0    0    1   -4    0    0    0    0    0   -2
  696           0.30           0.00    0    0    0    0    0    0    0    6    0    0    0    0    0    1
  697          -0.20          -0.10    0    0    0    0    0    0    0    6  -10    0    0    0    0   -2
  698          -0.10          -0.20    0    0    0    0    0    0    0    5   -8    0    0    0    0   -2
  699           0.20          -0.10    0    0    0    0    0    0    0    3   -5    0    0    0    0   -1
  700           0.20           0.10    0    0    0    0    0    0    0    2   -6    0    0    0    0   -2
  701           0.00           0.30    4    0    2   -4    2    0    0    0    0    0    0    0    0    0
  702           0.00          -0.30    3    0    0   -2    1    0    0    0    0    0    0    0    0    0
  703           0.00          -0.30    2    2    2   -2    2    0    0    0    0    0    0    0    0    0
  704           0.00           0.30    2    1    2    1    2    0    0    0    0    0    0    0    0    0
  705           0.00          -0.30    2    1    2   -4    1    0    0    0    0    0    0    0    0    0
  706           0.00          -0.30    2    1   -2    0    1    0    0    0    0    0    0    0    0    0
  707           0.00          -0.30    2    0    4   -2    1    0    0    0    0    0    0    0    0    0
  708           0.00          -0.30    2    0    2    1    1    0    0    0    0    0    0    0    0    0
  709           0.00           0.30    2    0    0   -2   -1    0    0   -2    0    4   -5    0    0    0
  710           0.00           0.30    2    0    0   -2   -1    0   -3    3    0    0    0    0    0    0
  711           0.00          -0.30    2    0    0   -2   -2    0   -3    3    0    0    0    0    0    0
  712           0.00           0.30    2    0    0   -3   -1    0    0    0    0    0    0    0    0    0
  713           0.30           0.00    2    0   -1   -1   -1    0    0   -1    0    2    0    0    0    0
  714           0.30           0.00    2    0   -1   -1   -1    0    0   -1    0    0    0    0    0    0
  715           0.00           0.30    2    0   -2   -6   -1    0    0    0    0    0    0    0    0    0
  716           0.00           0.30    2    0   -4    2   -2    0    0    0    0    0    0    0    0    0
  717           0.00          -0.30    2    0   -4   -2   -1    0    0    0    0    0    0    0    0    0
  718           0.00          -0.30    2   -1    2   -1    2    0    0    0    0    0    0    0    0    0
  719           0.00          -0.30    2   -1    2   -2    1    0    0    0    0    0    0    0    0    0
  720           0.00           0.30    2   -1   -2    0   -2    0    0    0    0    0    0    0    0    0
  721           0.00          -0.30    2   -2    0   -2    1    0    0    0    0    0    0    0    0    0
  722           0.00          -0.30    1    1    4   -2    2    0    0    0    0    0    0    0    0    0
  723           0.00          -0.30    1    1    2   -4    2    0    0    0    0    0    0    0    0    0
  724           0.00          -0.30    1    0    2    3    2    0    0    0    0    0    0    0    0    0
  725           0.00           0.30    1    0    2    0    3    0    0    0    0    0    0    0    0    0
  726           0.00           0.30    1    0    2   -2    2    0    0   -2    0    2    0    0    0    0
  727           0.30           0.00    1    0    1   -1    1    0    0   -1    0    0    0    0    0    0
  728           0.00           0.30    1    0    0    4   -1    0    0    0    0    0    0    0    0    0
  729           0.00          -0.30    1    0    0   -1   -1    0    0   -2    2    0    0    0    0    0
  730           0.00           0.30    1    0    0   -6   -1    0    0    0    0    0    0    0    0    0
  731           0.30           0.00    1    0   -1    1   -1    0  -18   17    0    0    0    0    0    0
  732           0.00          -0.30    1    0   -1   -1   -1    0   20  -20    0    0    0    0    0    0
  733           0.00           0.30    1    0   -2    0   -3    0    0    0    0    0    0    0    0    0
  734           0.00          -0.30    1    0   -2   -2   -2    0   -3    3    0    0    0    0    0    0
  735           0.00          -0.30    1   -1    0   -4   -1    0    0    0    0    0    0    0    0    0
  736           0.00           0.30    1   -2    2    0    1    0    0    0    0    0    0    0    0    0
  737           0.00           0.30    1   -2    0    0   -1    0    0    0    0    0    0    0    0    0
  738           0.00          -0.30    1   -2    0   -2    1    0    0    0    0    0    0    0    0    0
  739           0.00          -0.30    1   -2   -2   -2   -1    0    0    0    0    0    0    0    0    0
  740           0.00          -0.30    0    2    2    2    2    0    0    0    0    0    0    0    0    0
  741           0.00           0.30    0    2   -2   -4   -2    0    0    0    0    0    0    0    0    0
  742           0.00          -0.30    0    1    4   -2    1    0    0    0    0    0    0    0    0    0
  743           0.00           0.30    0    1    2    3    2    0    0    0    0    0    0    0    0    0
  744           0.00          -0.30    0    1    0   -2    2    0    0    0    0    0    0    0    0    0
  745           0.00           0.30    0    1    0   -4    1    0    0    0    0    0    0    0    0    0
  746           0.00          -0.30    0    0    4   -2    4    0    0    0    0    0    0    0    0    0
  747           0.00          -0.30    0    0    2    3    1    0    0    0    0    0    0    0    0    0
  748           0.00           0.30    0    0    2    0    2    0    0    1    0   -1    0    0    0    0
  749           0.00          -0.30    0    0    2    0    2    0    0   -1    0    1    0    0    0    0
  750           0.00           0.30    0    0    2    0    2    0   -1    1    0    0    0    0    0    0
  751           0.00          -0.30    0    0    2    0   -2    0    0    0    0    0    0    0    0    0
  752           0.00           0.30    0    0    2   -2    4    0    0    0    0    0    0    0    0    0
  753           0.00          -0.30    0    0    2   -2    1    0    0   -1    0    1    0    0    0    0
  754          -0.30           0.00    0    0    2   -2   -1    0   -5    6    0    0    0    0    0    0
  755           0.00           0.30    0    0    1   -1    2    0    0    0   -2    0    0    0    0    0
  756           0.30           0.00    0    0    1   -1    2    0    0   -1    0    1    0    0    0    0
  757           0.30           0.00    0    0    1   -1    1    0    1   -2    0    0    0    0    0    0
  758           0.30           0.00    0    0    1   -1    1    0   -2    1    0    0    0    0    0    0
  759           0.00           0.30    0    0    0    4    2    0    0    0    0    0    0    0    0    0
  760           0.00           0.30    0    0    0    1   -2    0    0    0    0    0    0    0    0    0
  761          -0.30           0.00    0    0    0    0    2    0    0    4   -8    3    0    0    0    0
  762          -0.30           0.00    0    0    0    0    2    0    0   -4    8   -3    0    0    0    0
  763           0.30           0.00    0    0    0    0    1    0    5   -8    0    0    0    0    0    0
  764           0.00          -0.30    0    0    0    0    1    0    2   -2    0    0    0    0    0    0
  765           0.30           0.00    0    0    0    0    1    0    0    0    0    0   -1    0    0    0
  766          -0.30           0.00    0    0    0    0    0    0    9  -11    0    0    0    0    0   -1
  767           0.00           0.30    0    0    0    0    0    0    8  -16    0    0    0    0    0   -2
  768          -0.30           0.00    0    0    0    0    0    0    5   -3    0    0    0    0    0    1
  769          -0.30           0.00    0    0    0    0    0    0    0    6   -7    0    0    0    0    2
  770           0.00           0.30    0    0    0    0    0    0    0    4    0    0   -2    0    0    2
  771           0.30           0.00    0    0    0    0    0    0    0    4   -8    1    5    0    0   -2
  772          -0.30           0.00    0    0    0    0    0    0    0    3    0    0   -2    0    0    2
  773           0.30           0.00    0    0    0    0    0    0    0    1    0   -1    0    0    0    1
  774           0.30           0.00    0    0    0    0    0    0    0    1    0   -3    0    0    0   -1
  775           0.30           0.00    0    0    0    0    0    0    0    1   -6    0    0    0    0   -2
  776           0.00          -0.30    0    0    0    0    0    0    0    0    0    4   -5    0    0    2
  777           0.00           0.30    0    0    0    0    0    0    0    0    0    0    5    0    0    2
  778           0.00           0.30    0    0    0    0    0    0    0    0    0    0    0    2    0    2
  779           0.30           0.00    0    0    0    0    0    0    0    0    0    0    0    2    0    1
  780           0.00           0.30    0    0    0    0    0    0    0    0    0    0    0    0    2    2
  781           0.00          -0.20    4    1    2    0    2    0    0    0    0    0    0    0    0    0
  782           0.00           0.20    4    0   -2    0   -1    0    0    0    0    0    0    0    0    0
  783           0.00           0.20    4   -1    2    0    2    0    0    0    0    0    0    0    0    0
  784           0.00          -0.20    4   -1   -2   -2   -2    0    0    0    0    0    0    0    0    0
  785           0.00          -0.20    3    1    2   -2    1    0    0    0    0    0    0    0    0    0
  786           0.00          -0.20    3    0    4   -2    2    0    0    0    0    0    0    0    0    0
  787           0.00          -0.20    3    0    2    1    2    0    0    0    0    0    0    0    0    0
  788           0.00          -0.20    3    0    2    0    0    0    0    0    0    0    0    0    0    0
  789           0.00          -0.20    3    0    0    2    0    0    0    0    0    0    0    0    0    0
  790           0.00           0.20    3    0    0    2   -1    0    0    0    0    0    0    0    0    0
  791           0.00           0.20    3    0    0    0    2    0    0    0    0    0    0    0    0    0
  792           0.00           0.20    3    0   -2    2   -1    0    0    0    0    0    0    0    0    0
  793           0.00          -0.20    3    0   -2   -1   -1    0    0    0    0    0    0    0    0    0
  794           0.00           0.20    3    0   -2   -6   -1    0    0    0    0    0    0    0    0    0
  795           0.00           0.20    2    2   -2   -4   -2    0    0    0    0    0    0    0    0    0
  796           0.00          -0.20    2    1    2    2    1    0    0    0    0    0    0    0    0    0
  797           0.00          -0.20    2    1    0    2    1    0    0    0    0    0    0    0    0    0
  798           0.00          -0.20    2    1    0   -2   -2    0    0    0    0    0    0    0    0    0
  799           0.00          -0.20    2    1    0   -4    0    0    0    0    0    0    0    0    0    0
  800           0.00          -0.20    2    1   -2    0    0    0    0    0    0    0    0    0    0    0
  801           0.00           0.20    2    1   -2   -6   -2    0    0    0    0    0    0    0    0    0
  802           0.00           0.20    2    0    4   -4    2    0    0    0    0    0    0    0    0    0
  803           0.00           0.20    2    0    2    4    1    0    0    0    0    0    0    0    0    0
  804           0.00           0.20    2    0    2   -2    0    0    0    0    0    0    0    0    0    0
  805           0.00          -0.20    2    0    2   -2   -1    0    0    0    0    0    0    0    0    0
  806           0.00           0.20    2    0    2   -3    2    0    0    0    0    0    0    0    0    0
  807           0.20           0.00    2    0    2   -4    0    0    0    0    0    0    0    0    0    0
  808           0.00           0.20    2    0    2   -6    1    0    0    0    0    0    0    0    0    0
  809           0.00           0.20    2    0    0    4    1    0    0    0    0    0    0    0    0    0
  810           0.00          -0.20    2    0    0   -1    1    0    0    0    0    0    0    0    0    0
  811           0.00          -0.20    2    0    0   -2    1    0    0   -5    6    0    0    0    0    0
  812           0.00          -0.20    2    0    0   -2   -1    0    0   -2    0    3   -1    0    0    0
  813           0.00          -0.20    2    0    0   -3    1    0    0    0    0    0    0    0    0    0
  814           0.00           0.20    2    0    0   -6   -1    0    0    0    0    0    0    0    0    0
  815           0.20           0.00    2    0   -1   -1   -2    0    0   -1    0    2    0    0    0    0
  816           0.00          -0.20    2    0   -2   -2    1    0    0    0    0    0    0    0    0    0
  817           0.00           0.20    2    0   -2   -2    0    0    0    0    0    0    0    0    0    0
  818           0.00           0.20    2    0   -4    2   -1    0    0    0    0    0    0    0    0    0
  819           0.00           0.20    2   -1    0    2    1    0    0    0    0    0    0    0    0    0
  820           0.00           0.20    2   -1    0    2   -1    0    0    0    0    0    0    0    0    0
  821           0.00           0.20    2   -1   -2    2   -1    0    0    0    0    0    0    0    0    0
  822           0.00           0.20    2   -1   -2   -2   -1    0    0    0    0    0    0    0    0    0
  823           0.00           0.20    2   -2    2    2    2    0    0    0    0    0    0    0    0    0
  824           0.00          -0.20    2   -2    0   -2   -2    0    0    0    0    0    0    0    0    0
  825           0.00          -0.20    1    2    2    0    1    0    0    0    0    0    0    0    0    0
  826           0.00           0.20    1    2    0    0    1    0    0    0    0    0    0    0    0    0
  827           0.00          -0.20    1    2    0   -2    0    0    0    0    0    0    0    0    0    0
  828           0.00          -0.20    1    1    2    4    2    0    0    0    0    0    0    0    0    0
  829           0.00          -0.20    1    1    0    1    1    0    0    0    0    0    0    0    0    0
  830           0.00           0.20    1    1    0    1   -1    0    0    0    0    0    0    0    0    0
  831           0.00           0.20    1    1   -2    2   -2    0    0    0    0    0    0    0    0    0
  832           0.00          -0.20    1    1   -2   -3   -2    0    0    0    0    0    0    0    0    0
  833           0.00           0.20    1    1   -2   -6   -2    0    0    0    0    0    0    0    0    0
  834           0.00          -0.20    1    0    4    0    1    0    0    0    0    0    0    0    0    0
  835          -0.20           0.00    1    0    3    0    3    0    0    0    0    0    0    0    0    0
  836           0.00           0.20    1    0    2   -4   -1    0    0    0    0    0    0    0    0    0
  837           0.00           0.20    1    0    2   -6    1    0    0    0    0    0    0    0    0    0
  838           0.20           0.00    1    0    1    1    1    0    0    1    0    0    0    0    0    0
  839           0.00          -0.20    1    0    0   -1    1    0    0   -1    0    1    0    0    0    0
  840           0.00           0.20    1    0    0   -1   -1    0    0   -3    4    0    0    0    0    0
  841           0.00          -0.20    1    0    0   -2    1    0    0   -2    0    2    0    0    0    0
  842           0.00           0.20    1    0    0   -2   -1    0    0   -2    0    2    0    0    0    0
  843           0.00           0.20    1    0    0   -3    0    0    0    0    0    0    0    0    0    0
  844           0.00           0.20    1    0    0   -3   -1    0    0    0    0    0    0    0    0    0
  845           0.20           0.00    1    0   -1    1   -1    0    0    1    0    0    0    0    0    0
  846           0.00           0.20    1    0   -1    0   -1    0   -3    5    0    0    0    0    0    0
  847           0.20           0.00    1    0   -1   -2   -1    0    0    0    0    0    0    0    0    0
  848           0.00           0.20    1    0   -2    1    1    0    0    0    0    0    0    0    0    0
  849           0.00           0.20    1    0   -2    0    2    0    0    0    0    0    0    0    0    0
  850           0.00           0.20    1    0   -2   -2   -2    0    0   -2    0    3    0    0    0    0
  851           0.00           0.20    1    0   -2   -6   -1    0    0    0    0    0    0    0    0    0
  852           0.00          -0.20    1    0   -4   -2   -1    0    0    0    0    0    0    0    0    0
  853           0.00           0.20    1   -1    2    4    1    0    0    0    0    0    0    0    0    0
  854           0.00          -0.20    1   -1    2    1    2    0    0    0    0    0    0    0    0    0
  855           0.00          -0.20    1   -1    2   -3    1    0    0    0    0    0    0    0    0    0
  856           0.00           0.20    1   -1    0    4    1    0    0    0    0    0    0    0    0    0
  857           0.00          -0.20    1   -1    0    0   -2    0    0    0    0    0    0    0    0    0
  858           0.00           0.20    1   -1   -2    1   -1    0    0    0    0    0    0    0    0    0
  859           0.00          -0.20    1   -1   -2   -4   -1    0    0    0    0    0    0    0    0    0
  860           0.00           0.20    1   -1   -4    2   -2    0    0    0    0    0    0    0    0    0
  861           0.00           0.20    1   -2    2    2    1    0    0    0    0    0    0    0    0    0
  862           0.10          -0.10    1   -2    0   -2    0    0    0    0    0    0    0    0    0    0
  863           0.00           0.20    1   -2   -2    2   -1    0    0    0    0    0    0    0    0    0
  864           0.00           0.20    0    3    0    0    0    0    0    0    0    0    0    0    0    0
  865           0.00           0.20    0    3   -2   -2   -2    0    0    0    0    0    0    0    0    0
  866           0.00          -0.20    0    2    0    0    2    0    0    0    0    0    0    0    0    0
  867           0.00          -0.20    0    1    2   -2    0    0    0    0    0    0    0    0    0    0
  868           0.00          -0.20    0    1    2   -4    2    0    0    0    0    0    0    0    0    0
  869           0.00          -0.20    0    1    0    4    1    0    0    0    0    0    0    0    0    0
  870           0.00          -0.20    0    1    0   -4    0    0    0    0    0    0    0    0    0    0
  871           0.00          -0.20    0    1   -2    4   -1    0    0    0    0    0    0    0    0    0
  872           0.00          -0.20    0    0    4    2    2    0    0    0    0    0    0    0    0    0
  873           0.00           0.20    0    0    2   -2    2    0    0   -2    0    2    0    0    0    0
  874           0.20           0.00    0    0    2   -2    1    0    0    4   -8    3    0    0    0    0
  875           0.00           0.20    0    0    2   -2    1    0    0    1    0   -1    0    0    0    0
  876           0.00           0.20    0    0    2   -2    1    0    0   -2    0    0    0    0    0    0
  877           0.00          -0.20    0    0    2   -2    1    0    0   -3    0    3    0    0    0    0
  878           0.20           0.00    0    0    2   -2    1    0    0   -4    8   -3    0    0    0    0
  879           0.00          -0.20    0    0    2   -2    1    0    0   -4    4    0    0    0    0    0
  880           0.00          -0.20    0    0    2   -2    1    0   -5    5    0    0    0    0    0    0
  881           0.20           0.00    0    0    2   -2    1    0   -8   11    0    0    0    0    0    0
  882          -0.20           0.00    0    0    1    1    2    0    0    1    0    0    0    0    0    0
  883           0.00           0.20    0    0    1   -1    2    0    0   -1    0    0    1    0    0    0
  884          -0.20           0.00    0    0    1   -1    2    0    0   -1    0   -1    0    0    0    0
  885           0.00           0.20    0    0    1   -1    2    0   -5    7    0    0    0    0    0    0
  886           0.00           0.20    0    0    1   -1    2    0   -8   12    0    0    0    0    0    0
  887           0.00           0.20    0    0    1   -1    1    0    1   -3    0    0    0    0    0    0
  888           0.00          -0.20    0    0    1   -1    1    0    0    1   -4    0    0    0    0    0
  889           0.20           0.00    0    0    1   -1    1    0    0   -1    0    1   -3    0    0    0
  890           0.20           0.00    0    0    1   -1    1    0    0   -1    0    0    0   -1    0    0
  891           0.00          -0.20    0    0    1   -1    1    0    0   -4    6    0    0    0    0    0
  892           0.20           0.00    0    0    1   -1    1    0   -5    6    0    0    0    0    0    0
  893          -0.20           0.00    0    0    0    0    1    0    3   -4    0    0    0    0    0    0
  894           0.00           0.20    0    0    0    0    1    0    0    7  -13    0    0    0    0    0
  895           0.00           0.20    0    0    0    0    1    0    0    2    0   -2    0    0    0    0
  896           0.00          -0.20    0    0    0    0    1    0    0    2   -2    0    0    0    0    0
  897           0.00          -0.20    0    0    0    0    1    0    0   -2    2    0    0    0    0    0
  898           0.00          -0.20    0    0    0    0    1    0   -2    2    0    0    0    0    0    0
  899           0.20           0.00    0    0    0    0    1    0   -3    4    0    0    0    0    0    0
  900           0.00           0.20    0    0    0    0    0    0    8  -12    0    0    0    0    0   -2
  901           0.00          -0.20    0    0    0    0    0    0    7  -10    0    0    0    0    0   -1
  902           0.20           0.00    0    0    0    0    0    0    7  -11    0    0    0    0    0   -1
  903          -0.20           0.00    0    0    0    0    0    0    6   -4    0    0    0    0    0    1
  904          -0.20           0.00    0    0    0    0    0    0    6   -6    0    0    0    0    0    1
  905          -0.20           0.00    0    0    0    0    0    0    5   -5    0    0    0    0    0    1
  906           0.00          -0.20    0    0    0    0    0    0    5   -6    0    0    0    0    0   -1
  907          -0.20           0.00    0    0    0    0    0    0    4   -2    0    0    0    0    0    0
  908           0.00          -0.20    0    0    0    0    0    0    4   -5    0    0    0    0    0   -1
  909           0.20           0.00    0    0    0    0    0    0    4   -5    0    0    0    0    0   -2
  910           0.00          -0.20    0    0    0    0    0    0    3   -4    0    0    0    0    0    1
  911           0.20           0.00    0    0    0    0    0    0    3   -4    0    0    0    0    0   -2
  912          -0.20           0.00    0    0    0    0    0    0    3   -8    0    0    0    0    0   -2
  913           0.00           0.20    0    0    0    0    0    0    2   -5    0    0    0    0    0   -1
  914           0.00           0.20    0    0    0    0    0    0    1   -2    0    0    0    0    0   -1
  915           0.00           0.20    0    0    0    0    0    0    1   -4    0    0    0    0    0   -1
  916           0.00          -0.20    0    0    0    0    0    0    0    9  -17    0    0    0    0   -2
  917          -0.20           0.00    0    0    0    0    0    0    0    7   -8    0    0    0    0    2
  918          -0.20           0.00    0    0    0    0    0    0    0    7   -9    0    0    0    0    2
  919          -0.20           0.00    0    0    0    0    0    0    0    5   -6    0    0    0    0    2
  920           0.20           0.00    0    0    0    0    0    0    0    5  -10    0    0    0    0   -2
  921           0.00           0.20    0    0    0    0    0    0    0    4    0   -4    0    0    0    2
  922           0.00          -0.20    0    0    0    0    0    0    0    4   -6    0    0    0    0   -2
  923           0.00          -0.20    0    0    0    0    0    0    0    4   -7    0    0    0    0   -1
  924           0.00          -0.20    0    0    0    0    0    0    0    4   -8    3    0    0    0    1
  925           0.00           0.20    0    0    0    0    0    0    0    4   -8    3    0    0    0   -1
  926           0.20           0.00    0    0    0    0    0    0    0    4   -8    1    5    0    0    2
  927           0.20           0.00    0    0    0    0    0    0    0    3    0    0    0    0    0    2
  928           0.00           0.20    0    0    0    0    0    0    0    3   -8    3    0    0    0   -2
  929           0.10          -0.10    0    0    0    0    0    0    0    2    1    0    0    0    0    2
  930           0.20           0.00    0    0    0    0    0    0    0    2    0    0   -2    0    0    1
  931           0.00          -0.20    0    0    0    0    0    0    0    2    0   -5    0    0    0   -2
  932           0.00          -0.20    0    0    0    0    0    0    0    2   -4    0    0    0    0    1
  933           0.20           0.00    0    0    0    0    0    0    0    2   -7    0    0    0    0   -2
  934           0.20           0.00    0    0    0    0    0    0    0    1    0    1    0    0    0    1
  935           0.00           0.20    0    0    0    0    0    0    0    1    0    0    0    0    0   -1
  936           0.20           0.00    0    0    0    0    0    0    0    1    0   -1    0    0    0   -1
  937           0.20           0.00    0    0    0    0    0    0    0    1    0   -2    5    0    0    2
  938           0.00           0.20    0    0    0    0    0    0    0    1    0   -2    0    0    0   -2
  939           0.00          -0.20    0    0    0    0    0    0    0    1    0   -5    0    0    0   -2
  940          -0.20           0.00    0    0    0    0    0    0    0    7   -7    0    0    0    0    2
  941           0.00           0.10    5    0    2    0    1    0    0    0    0    0    0    0    0    0
  942           0.00          -0.10    4    1    2   -2    2    0    0    0    0    0    0    0    0    0
  943           0.00          -0.10    3    1    2    2    2    0    0    0    0    0    0    0    0    0
  944           0.00           0.10    3    1   -2   -6   -2    0    0    0    0    0    0    0    0    0
  945           0.00          -0.10    3    0    0    0   -2    0    0    0    0    0    0    0    0    0
  946           0.00          -0.10    3    0    0   -4    0    0    0    0    0    0    0    0    0    0
  947           0.00          -0.10    3    0   -2   -4   -2    0    0    0    0    0    0    0    0    0
  948           0.00          -0.10    3   -1    0    0    0    0    0    0    0    0    0    0    0    0
  949           0.00           0.10    2    2    0   -2   -1    0    0    0    0    0    0    0    0    0
  950           0.00           0.10    2    1    2   -4    2    0    0    0    0    0    0    0    0    0
  951           0.00           0.10    2    1   -2    0   -2    0    0    0    0    0    0    0    0    0
  952           0.00          -0.10    2    0    2   -2    2    0    0   -2    0    3    0    0    0    0
  953           0.10           0.00    2    0    1   -3    1    0   -6    7    0    0    0    0    0    0
  954           0.00           0.10    2    0    0    1    0    0    0    0    0    0    0    0    0    0
  955           0.00          -0.10    2    0    0   -4    2    0    0    0    0    0    0    0    0    0
  956           0.00           0.10    2    0    0   -4   -2    0    0    0    0    0    0    0    0    0
  957           0.00          -0.10    2    0    0   -6    0    0    0    0    0    0    0    0    0    0
  958           0.00           0.10    2    0   -2   -2   -2    0    0   -2    0    2    0    0    0    0
  959           0.00          -0.10    2    0   -2   -5   -2    0    0    0    0    0    0    0    0    0
  960           0.00           0.10    2   -1    2    4    2    0    0    0    0    0    0    0    0    0
  961           0.00          -0.10    2   -1    0    2    0    0    0    0    0    0    0    0    0    0
  962           0.00          -0.10    2   -1    0   -2    2    0    0    0    0    0    0    0    0    0
  963           0.00          -0.10    2   -1   -2    0    1    0    0    0    0    0    0    0    0    0
  964           0.00          -0.10    2   -1   -2    0    0    0    0    0    0    0    0    0    0    0
  965           0.00           0.10    2   -2    0   -2    0    0    0    0    0    0    0    0    0    0
  966           0.00           0.10    1    3   -2   -2   -2    0    0    0    0    0    0    0    0    0
  967           0.00           0.10    1    2    2   -4    1    0    0    0    0    0    0    0    0    0
  968           0.00          -0.10    1    1    0    1    0    0    0    0    0    0    0    0    0    0
  969           0.00           0.10    1    1    0    0   -2    0    0    0    0    0    0    0    0    0
  970           0.00           0.10    1    1   -2    1   -2    0    0    0    0    0    0    0    0    0
  971           0.00          -0.10    1    1   -2   -1   -2    0    0    0    0    0    0    0    0    0
  972           0.00          -0.10    1    1   -2   -2    0    0    0    0    0    0    0    0    0    0
  973           0.00          -0.10    1    0    2    0    2    0    1   -1    0    0    0    0    0    0
  974           0.10           0.00    1    0    2    0    2    0    0    4   -8    3    0    0    0    0
  975           0.10           0.00    1    0    2    0    2    0    0   -4    8   -3    0    0    0    0
  976           0.00           0.10    1    0    2    0    2    0   -1    1    0    0    0    0    0    0
  977           0.00           0.10    1    0    2   -2    2    0   -3    3    0    0    0    0    0    0
  978           0.00          -0.10    1    0    0    0    1    0  -10    3    0    0    0    0    0    0
  979           0.00           0.10    1    0    0    0   -1    0  -10    3    0    0    0    0    0    0
  980           0.00          -0.10    1    0    0   -4    2    0    0    0    0    0    0    0    0    0
  981           0.00          -0.10    1    0    0   -6    0    0    0    0    0    0    0    0    0    0
  982           0.00          -0.10    1    0   -2    4   -2    0    0    0    0    0    0    0    0    0
  983           0.00           0.10    1    0   -2    1    0    0    0    0    0    0    0    0    0    0
  984           0.00          -0.10    1    0   -2   -2   -2    0    0    1    0   -1    0    0    0    0
  985           0.00          -0.10    1    0   -2   -2   -3    0    0    0    0    0    0    0    0    0
  986           0.00          -0.10    1    0   -2   -4    0    0    0    0    0    0    0    0    0    0
  987           0.00          -0.10    0    2    0    0   -2    0    0    0    0    0    0    0    0    0
  988           0.00           0.10    0    1    4   -4    2    0    0    0    0    0    0    0    0    0
  989           0.00          -0.10    0    1   -2   -2    0    0    0    0    0    0    0    0    0    0
  990           0.00           0.10    0    1   -4    2   -1    0    0    0    0    0    0    0    0    0
  991           0.00          -0.10    0    0    2    2    2    0    0    2    0   -2    0    0    0    0
  992           0.00          -0.10    0    0    2    0    3    0    0    0    0    0    0    0    0    0
  993           0.00           0.10    0    0    2    0    2    0    2   -2    0    0    0    0    0    0
  994           0.10           0.00    0    0    2    0    2    0    2   -3    0    0    0    0    0    0
  995           0.10           0.00    0    0    2    0    2    0   -2    3    0    0    0    0    0    0
  996           0.00          -0.10    0    0    2    0    2    0   -2    2    0    0    0    0    0    0
  997           0.00          -0.10    0    0    2   -2    1    0    1   -1    0    0    0    0    0    0
  998           0.00           0.10    0    0    2   -2    1    0    0   -2    0    1    0    0    0    0
  999           0.00           0.10    0    0    2   -2    1    0    0  -10   15    0    0    0    0    0
 1000           0.00           0.10    0    0    1   -1    2    0    0   -1    0    0   -1    0    0    0
 1001          -0.10           0.00    0    0    1   -1    2    0   -3    4    0    0    0    0    0    0
 1002           0.10           0.00    0    0    1   -1    1    0   -1    2    0    0    0    0    0    0
 1003           0.00          -0.10    0    0    1   -1    1    0   -4    6    0    0    0    0    0    0
 1004           0.00           0.10    0    0    1   -1   -1    0   -5    7    0    0    0    0    0    0
 1005           0.00          -0.10    0    0    0    3    2    0    0    0    0    0    0    0    0    0
 1006          -0.10           0.00    0    0    0    0    2    0    0    0    0    1    0    0    0    0
 1007           0.00          -0.10    0    0    0    0    2    0   -3    5    0    0    0    0    0    0
 1008           0.10           0.00    0    0    0    0    1    0    0   -1    0    2    0    0    0    0
 1009           0.10           0.00    0    0    0    0    1    0   -1    2    0    0    0    0    0    0
 1010           0.00           0.10    0    0    0    0    0    0    9  -13    0    0    0    0    0   -2
 1011           0.00          -0.10    0    0    0    0    0    0    8  -11    0    0    0    0    0   -1
 1012           0.00           0.10    0    0    0    0    0    0    8  -14    0    0    0    0    0   -2
 1013           0.00          -0.10    0    0    0    0    0    0    6   -7    0    0    0    0    0   -1
 1014           0.00          -0.10    0    0    0    0    0    0    5   -3    0    0    0    0    0    2
 1015           0.10           0.00    0    0    0    0    0    0    5   -4    0    0    0    0    0    2
 1016           0.10           0.00    0    0    0    0    0    0    5   -6    0    0    0    0    0   -2
 1017           0.00           0.10    0    0    0    0    0    0    4   -8    0    0    0    0    0   -2
 1018          -0.10           0.00    0    0    0    0    0    0    3    0    0    0    0    0    0    2
 1019           0.00           0.10    0    0    0    0    0    0    3   -3    0    2    0    0    0    2
 1020           0.00           0.10    0    0    0    0    0    0    1   -1    0    0    0    0    0   -2
 1021          -0.10           0.00    0    0    0    0    0    0    0    7  -12    0    0    0    0   -2
 1022           0.00           0.10    0    0    0    0    0    0    0    6   -4    0    0    0    0    2
 1023          -0.10           0.00    0    0    0    0    0    0    0    6   -8    1    5    0    0    2
 1024           0.00          -0.10    0    0    0    0    0    0    0    6   -9    0    0    0    0   -2
 1025           0.00           0.10    0    0    0    0    0    0    0    5    0   -4    0    0    0    2
 1026           0.00          -0.10    0    0    0    0    0    0    0    5   -7    0    0    0    0   -2
 1027           0.00           0.10    0    0    0    0    0    0    0    5   -8    3    0    0    0    2
 1028           0.00          -0.10    0    0    0    0    0    0    0    5   -9    0    0    0    0   -1
 1029           0.00          -0.10    0    0    0    0    0    0    0    5  -13    0    0    0    0   -2
 1030           0.00           0.10    0    0    0    0    0    0    0    5  -16    4    5    0    0   -2
 1031           0.00          -0.10    0    0    0    0    0    0    0    3    0   -5    0    0    0   -2
 1032           0.10           0.00    0    0    0    0    0    0    0    3   -7    0    0    0    0   -2
 1033           0.10           0.00    0    0    0    0    0    0    0    3   -9    0    0    0    0   -2
 1034           0.00          -0.10    0    0    0    0    0    0    0    2    0    2    0    0    0    2
 1035           0.10           0.00    0    0    0    0    0    0    0    2   -8    1    5    0    0   -2
 1036          -0.10           0.00    0    0    0    0    0    0    0    1    0    0    2    0    0    2
 1037           0.00          -0.10    0    0    0    0    0    0    0    0    0    0    0    0    0    2
]'

const coefs_iau2006_nut_obl1 = Float64[
 1038           0.20         883.03    0    0    0    0    1    0    0    0    0    0    0    0    0    0
 1039          -0.30        -303.09    0    0    2   -2    2    0    0    0    0    0    0    0    0    0
 1040           0.00         -67.70    0    1    2   -2    2    0    0    0    0    0    0    0    0    0
 1041          -0.10         -48.77    0    0    2    0    2    0    0    0    0    0    0    0    0    0
 1042           0.00          47.25    0    0    0    0    2    0    0    0    0    0    0    0    0    0
 1043           0.10          29.90    0    1   -2    2   -2    0    0    0    0    0    0    0    0    0
 1044           0.50         -18.40    0    1    0    0    0    0    0    0    0    0    0    0    0    0
 1045           0.00          -6.30    1    0    2    0    2    0    0    0    0    0    0    0    0    0
 1046           0.00          -4.20    0    2    2   -2    2    0    0    0    0    0    0    0    0    0
 1047           0.00           3.20    1    0   -2    0   -2    0    0    0    0    0    0    0    0    0
 1048           0.00           1.80    0    0    2    0    1    0    0    0    0    0    0    0    0    0
 1049           0.00          -1.10    2    0    2    0    2    0    0    0    0    0    0    0    0    0
 1050           0.00          -1.10    1    0   -2   -2   -2    0    0    0    0    0    0    0    0    0
 1051           0.00          -1.10    0    0    2    2    2    0    0    0    0    0    0    0    0    0
 1052           0.00          -1.00    2    0   -2    0   -1    0    0    0    0    0    0    0    0    0
 1053           0.00           1.00    1    0    2   -2    2    0    0    0    0    0    0    0    0    0
 1054           0.00          -0.90    0    0    2   -2    1    0    0    0    0    0    0    0    0    0
 1055           0.00          -0.20    0    1    0    0    1    0    0    0    0    0    0    0    0    0
 1056           0.00          -0.10    0    2    0    0    0    0    0    0    0    0    0    0    0    0
]'
